        page    132

; Direkte Digitale Synthese von Cosinus/Sinus-Paaren mit dem On-Chip-ROM 
;              und Taylor-Entwicklung dritten Grades
; ======================================================================
; Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
;
; Der Rechenbedarf zur Generierung von n Cos-Sin-Paaren in Puffer l:(r4)+ ist
;     37*n  Instruktionen
;

ROMStart     equ   $0100     ; Basisadresse fr das On-Chip-ROM
ROMLength    equ   256       ; Lnge des On-Chip-ROMs

OutBufStart  equ   $2000     ; Basisadresse fr Ausgabepuffer
OutBufLength equ   $2000     ; Lnge des Ausgabepuffers

n            equ   $1FFF

        org     l:$001E
PA      ds 1
PS      dc $000005555555

        org     x:$0020
K0000FF dc ROMLength-1       ; Maske fr den Index der Sinustabelle
K000100 dc ROMStart          ; Basis der Sinustabelle im y-Speicher
K000140 dc ROMStart+ROMLength/4  ; Basis der CosinusTabelle
K2PI256 dc $03243F           ; 2*3.1415926535/256
K1DIV6  dc $155555           ; 1/6

START        equ   $0040     ; Programmanfang
        
        org     p:$0
        jmp     START

        org     p:START
        ori     #3,mr        ; Interrupts nicht annehmen
        movec   #0,sp        ; hardware stack pointer lschen
        move    #4,omr       ; operating mode 4 (Sinus-ROM aktiviert)

; ROM und Ausgabepuffer initialisieren
; ====================================

        move    #>ROMLength-1,m1
        move    #>OutBufStart,r4
        move    #>OutBufLength-1,m4
        move    #>n,n4

; Code fr die Generierung von n Abtastungen
; ==========================================

        do n4,loop

        move    l:PA,a           ; Phasenakku holen
        clr     b l:PS,x         ; Phasenschritt holen
        add     x,a x:K0000FF,x0 ; Phasenaddition und Tabellenmaske
        and     x0,a             ; Maskierung modulo Tabellenlnge 256
        move    a,l:PA           ; Phasenakku speichern
        move    a1,n1            ; Index in Tabelle als Offset setzen
        move    b1,a1            ; 2*DX' durch Lschen der oberen Bits
        asr     a                ; DX' durch ShiftR
        move    x0,m1            ; Modulus fr Sinustabelle setzen
        move    x:K000100,r1     ; Basis der Sinustabelle setzen
        move    a0,y1            ; DX' => y1
        move    x:K2PI256,x1     ; 2*PI/256 => x1
        mpyr    x1,y1,a y:(r1+n1),y0 ;DX = 2*PI/256 * DX' => a, sin => y0 
        move    x:K000140,r1     ; Basis der Cosinustabelle setzen
        move    x:K1DIV6,y1      ; 1/6 => y1
        move    y:(r1+n1),x0     ; cos => x0
        mpyr    -x0,y1,b a,x1    ; -cos/6 => b, DX => x1
        mpyr    y0,y1,a  b,y1    ; -cos/6 => y1, sin/6 => a
        mpy     -y0,#1,b         ; -sin/2 => b
        macr    x1,y1,b          ; -sin/2 - DX*cos/6 => b
        move    b,y1             ; -sin/2 - DX*cos/6 => y1
        mpy     x1,y1,b          ; DX*(-sin/2 - DX*cos/6) => b
        add     x0,b             ; cos + DX*(-sin/2 - DX*cos/6) => b
        move    b,y1             ; cos + DX*(-sin/2 - DX*cos/6) => y1
        mpy     x1,y1,b  a,y1    ; DX*(cos + DX*(-sin/2 - DX*cos/6)) => b
        add     y0,b             ; sin + DX*(cos + DX*(-sin/2 - DX*cos/6)) =>b
        rnd     b                ; Rundung auf 24 Bit
        mpy     -x0,#1,a         ; -cos/2 => a
        macr    x1,y1,a          ; -cos/2 + DX*sin/6 => a
        move    a,y1             ; -cos/2 + DX*sin/6 => y1
        mpy     x1,y1,a          ; DX*(-cos/2 + DX*sin/6) => a
        sub     y0,a             ; -sin + DX*(-cos/2 + DX*sin/6) => a
        move    a,y1             ; -sin + DX*(-cos/2 + DX*sin/6) => y1
        mpy     x1,y1,a          ; DX*(-sin + DX*(-cos/2 + DX*sin/6)) => a
        add     x0,a             ; cos + DX*(cos + DX*(-sin/2 - DX*cos/6)) =>a
        rnd     a                ; Rundung auf 24 Bit
        move    ba,l:(r4)+       ; cos/sin in Puffer schreiben

loop

; Programmstopp
; =============

        debug

        end
