        page    132

; Effiziente DDS mit zwei Cos-Sin-ROMs
; =========================================
; Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
;
; Der Rechenbedarf zur Generierung von n Cos-Sin-Paaren in Puffer l:(r4)+ ist
;     4*n  Instruktionen
;
; Die Frequenz ist ein Vielfaches von  df = fs/(ROM1Length*ROM2Length), 
; wo fs die Abtastrate bedeutet.
; Zur Erzeugung der Frequenz f ist mit  nf = round(f/df)  zu setzen:
; ROM1Inkrem = mod(x(1)*nf, ROM1Length)
; ROM2Inkrem = mod(x(2)*nf, ROM2Length),
; wo x(1) und x(2) die Lsung folgender diophantischen Gleichung ist:
;      x(1)/ROM1Length + x(2)/ROM2Length = y + 1/(ROM1Length*ROM2Length)
;
; Definition der ROMs nach Bedarf
; ===============================
; Im angegebenen Beispiel sind ROM1Length = 768 und ROM2Length = 625 gerade 
; so gewhlt, dass ihr Produkt 480000 ist. Das ergibt bei fs = 48000 Hz genau 
; df = 0.1000 Hz. Dies ermglicht die Generierung von Frequenzen im Raster 
; 0.1 Hz. In diesem Fall ist x(1) = 145,  x(2) = 507. 
; Fr die Generierung von z.B.  f = 999.9 Hz ergibt sich dann
; nf = round(f/df) = 9999;
; ROM1Inkrem = mod(145*9999, 768) = 639
; ROM2Inkrem = mod(507*9999, 625) = 118
;

ROM1Start    equ   $1800     ; Basisadresse fr ROM1
ROM2Start    equ   $1C00     ; Basisadresse fr ROM2
ROM1Length   equ   768       ; Lnge von ROM1
ROM2Length   equ   625       ; Lnge von ROM2
ROM1Inkrem   equ   639       ; Adressinkrement fr ROM1 fr 999.9 Hz 
                             ; bei fs = 48000 Hz
ROM2Inkrem   equ   118       ; Adressinkrement fr ROM2 fr 999.9 Hz 
                             ; bei fs = 48000 Hz

OutBufStart  equ   $2000     ; Basisadresse fr Ausgabepuffer
OutBufLength equ   $2000     ; Lnge des Ausgabepuffers

n            equ   $1FFF

START        equ   $0040     ; Programmanfang
        
        org     p:$0
        jmp     START

        org     p:START
        ori     #3,mr        ; Interrupts nicht annehmen
        movec   #0,sp        ; hardware stack pointer lschen
        move    #0,omr       ; operating mode 0

; Zeiger fr die ROM-Adressierung initialisieren
; ==============================================

        move    #>ROM1Start,r0
        move    #>ROM1Inkrem,n0
        move    #>ROM1Length-1,m0
        move    #>ROM2Start,r1
        move    #>ROM2Inkrem,n1
        move    #>ROM2Length-1,m1
        move    #>OutBufStart+OutBufLength-1,r4
        move    #>OutBufLength-1,m4
        move    #>n,n4

; Code fr die Generierung von n Abtastungen
; ==========================================

        move  x:(r0),x1
        move  l:(r1)+n1,y

        do n4,loop
        mpy   x1,y1,a  ab,l:(r4)+
        mpy   x1,y0,b  y:(r0)+n0,x0
        macr -x0,y0,a  x:(r0),x1
        macr  x0,y1,b  l:(r1)+n1,y
loop

        move  ab,l:(r4)+

; Programmstopp
; =============

        debug

; Generierung der ROM-Tabellen
; ============================

pi      equ     3.141592654

; ROM1
freq = 2.0*pi/@cvf(ROM1Length)
amp  = 0.99999988                ; Amplitude fr Symmetrie bei 2-Komplement

        org x:ROM1Start
count   set 0
        dup ROM1Length
        dc  amp*@cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM1Start
count   set 0
        dup ROM1Length
        dc  amp*@sin(@cvf(count)*freq)
count   set count+1
        endm

; ROM2
freq = 2.0*pi/@cvf(ROM2Length)
        org x:ROM2Start
count   set 0
        dup ROM2Length
        dc  amp*@cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM2Start
count   set 0
        dup ROM2Length
        dc  amp*@sin(@cvf(count)*freq)
count   set count+1
        endm

        end
