        page    132

; Sehr effiziente DDS mit drei Cos-Sin-ROMs
; =========================================
; Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
;
; Der Rechenbedarf zur Generierung von n Cos-Sin-Paaren in Puffer l:(r4)+ ist
;      4 + 8*n  Instruktionen
;
; Die Frequenz ist ein Vielfaches von  
; df = fs/(ROM1Length*ROM2Length*ROM3Length). 
; Zur Erzeugung der Frequenz f ist zu setzen:
; ROM1Inkrem = round((x(1)*f/df)mod(ROM1Length)
; ROM2Inkrem = round((x(2)*f/df)mod(ROM2Length),
; ROM3Inkrem = round((x(3)*f/df)mod(ROM3Length),
; wo x(1), x(2) und x(3) die Lsung der diophantischen Gleichung 
; x(1)/ROM1Length + x(2)/ROM2Length + x(3)/ROM3Length = 
;                      = y + 1/(ROM1Length*ROM2Length*ROM3Length)
; fr beliebiges natrliches y ist. 
; Man findet diese z.B. in MATLAB mit
;      x = diophant([ROM1Length,ROM2Length,ROM3Length]) 
;
;
; Definition der ROMs nach Bedarf
; ===============================
; Im angegebenen Beispiel sind 
; ROM1Length = 36, ROM2Length = 25 und ROM3Length = 49 gerade so gewhlt, 
; dass ihr Produkt 44100 ist. Das ergibt bei fs = 44100 Hz genau df = 1.000 Hz. 
; Das ermglicht die Generierung von Frequenzen im Raster 1.000 Hz. 
; In diesem Fall ist x(1) = 1, x(2) = 9, x(3) = 30.  
; Z.B. ergibt sich fr die Generierung von f = 999 Hz :
; ROM1Inkrem = round(( 1*999)mod(36) = 27
; ROM2Inkrem = round(( 9*999)mod(25) = 16
; ROM3Inkrem = round((30*999)mod(49) = 31

ROM1Start    equ   $0040     ; Basisadresse fr ROM1
ROM2Start    equ   $0020     ; Basisadresse fr ROM2
ROM3Start    equ   $0080     ; Basisadresse fr ROM3
ROM1Length   equ   36        ; Lnge von ROM1
ROM2Length   equ   25        ; Lnge von ROM2
ROM3Length   equ   49        ; Lnge von ROM3
ROM1Inkrem   equ   27        ; Adressinkrement fr ROM1 fr 999 Hz 
                             ; bei fs = 44100 Hz
ROM2Inkrem   equ   16        ; Adressinkrement fr ROM2 fr 999 Hz 
                             ; bei fs = 44100 Hz
ROM3Inkrem   equ   31        ; Adressinkrement fr ROM3 fr 999 Hz 
                             ; bei fs = 44100 Hz

OutBufStart  equ   $2000     ; Basisadresse fr Ausgabepuffer
OutBufLength equ   $2000     ; Lnge des Ausgabepuffers

n            equ   $2000     ; Anzahl zu berechnender Samples

START        equ   $0040     ; Programmanfang
        
        org     p:$0
        jmp     START

        org     p:START
        ori     #3,mr        ; Interrupts nicht annehmen
        movec   #0,sp        ; hardware stack pointer lschen
        move    #0,omr       ; operating mode 0

; Zeiger fr die ROM-Adressierung initialisieren
; ==============================================

        move    #>ROM1Start,r0
        move    #>ROM1Inkrem,n0
        move    #>ROM1Length-1,m0
        move    #>ROM2Start,r1
        move    #>ROM2Inkrem,n1
        move    #>ROM2Length-1,m1
        move    #>ROM3Start,r2
        move    #>ROM3Inkrem,n2
        move    #>ROM3Length-1,m2
        move    #>OutBufStart+OutBufLength-1,r4
        move    #>OutBufLength-1,m4
        move    #>n,n4

; Code fr die Generierung von n Abtastungen
; ==========================================

        move  x:(r0)+n0,x1
        move  l:(r1)+n1,y

        do n4,loop
        mpy   x1,y1,a  ab,l:(r4)+
        mpy   x1,y0,b  y:(r0)+n0,x0
        macr -x0,y0,a  y:(r2),y0
        macr  x0,y1,b  a,x1
        mpy   x1,y0,b  b,x0 
        mpy  -x0,y0,a  x:(r2)+n2,y1
        macr  x1,y1,a  x:(r0),x1
        macr  x0,y1,b  l:(r1)+n1,y
loop

        move  ab,l:(r4)+

; Programmstopp
; =============

        debug

; Generierung der ROM-Tabellen
; ============================

pi      equ     3.141592654

; ROM1
freq = 2.0*pi/@cvf(ROM1Length)

        org x:ROM1Start
count   set 0
        dup ROM1Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM1Start
count   set 0
        dup ROM1Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

; ROM2
freq = 2.0*pi/@cvf(ROM2Length)
        org x:ROM2Start
count   set 0
        dup ROM2Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM2Start
count   set 0
        dup ROM2Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

; ROM3
freq = 2.0*pi/@cvf(ROM3Length)
        org x:ROM3Start
count   set 0
        dup ROM3Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM3Start
count   set 0
        dup ROM3Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

        end 
