        page    132

; Sehr effiziente DDS mit vier Cos-Sin-ROMs
; =========================================
; Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
;
; Der Rechenbedarf zur Generierung von n Cos-Sin-Paaren in Puffer l:(r4)+ ist
;      4 + 12*n  Instruktionen
;
; Die Frequenz ist ein Vielfaches von 
; df = fs/(ROM1Length*ROM2Length*ROM3Length*ROM4Length). 
; Zur Erzeugung der Frequenz f ist zu setzen:
; ROM1Inkrem = round((x(1)*f/df)mod(ROM1Length)
; ROM2Inkrem = round((x(2)*f/df)mod(ROM2Length),
; ROM3Inkrem = round((x(3)*f/df)mod(ROM3Length),
; ROM4Inkrem = round((x(4)*f/df)mod(ROM4Length),
; wo x(1), x(2), x(3) und x(4) die Lsung der diophantischen Gleichung 
; x(1)/ROM1Length + x(2)/ROM2Length + x(3)/ROM3Length + x(4)/ROM3Length = 
;       = y + 1/(ROM1Length*ROM2Length*ROM3Length*ROM4Length)
; fr beliebiges natrliches y ist. 
; Man findet diese z.B. in MATLAB mit
;      x = diophant([ROM1Length,ROM2Length,ROM3Length,ROM4Length]) 

;
; Definition der ROMs nach Bedarf
; ===============================
; Im angegebenen Beispiel sind 
; ROM1Length = 109, ROM2Length = 107, ROM3Length = 103 und ROM4Length = 101 
; so gewhlt, dass die Einstellgenauigkeit der Frequenz mit df = fs/121330189
; mglichst fein ist bei einem ROM-Bedarf von < 1k Worten. 
; Bei fs = 48000 Hz ist dann df < 0.0004 Hz.  
; In diesem Fall ist x(1) = 42, x(2) = 29, x(3) = 15, x(4) = 20.  
; Z.B. ergibt sich fr die Generierung von f = 444.4444 Hz mit fs = 48000 Hz :
; ROM1Inkrem = round((42*444.4444/48000*121330189)mod(109) = 38
; ROM2Inkrem = round((29*444.4444/48000*121330189)mod(107) = 69
; ROM3Inkrem = round((15*444.4444/48000*121330189)mod(103) = 98
; ROM4Inkrem = round((20*444.4444/48000*121330189)mod(101) = 91
; Die tatschlich realisierte Frequenz ist 444.4446 Hz.

ROM1Start    equ   $1E00     ; Basisadresse fr ROM1
ROM2Start    equ   $1E80     ; Basisadresse fr ROM2
ROM3Start    equ   $1F00     ; Basisadresse fr ROM3
ROM4Start    equ   $1F80     ; Basisadresse fr ROM4
ROM1Length   equ   109       ; Lnge von ROM1
ROM2Length   equ   107       ; Lnge von ROM2
ROM3Length   equ   103       ; Lnge von ROM3
ROM4Length   equ   101       ; Lnge von ROM3
ROM1Inkrem   equ   38        ; Adressinkrement fr ROM1 fr 444.4444 Hz 
                             ; bei fs = 48000 Hz
ROM2Inkrem   equ   69        ; Adressinkrement fr ROM2 fr 444.4444 Hz 
                             ; bei fs = 48000 Hz
ROM3Inkrem   equ   98        ; Adressinkrement fr ROM3 fr 444.4444 Hz 
                             ; bei fs = 48000 Hz
ROM4Inkrem   equ   91        ; Adressinkrement fr ROM4 fr 444.4444 Hz 
                             ; bei fs = 48000 Hz

OutBufStart  equ   $2000     ; Basisadresse fr Ausgabepuffer
OutBufLength equ   $2000     ; Lnge des Ausgabepuffers

n            equ   $2000     ; Anzahl zu berechnender Samples

START        equ   $0040     ; Programmanfang
        
        org     p:$0
        jmp     START

        org     p:START
        ori     #3,mr        ; mask interrupts
        movec   #0,sp        ; clear hardware stack pointer
        move    #0,omr       ; operating mode 0

; Zeiger fr die ROM-Adressierung initialisieren
; ==============================================

        move    #>ROM1Start,r0
        move    #>ROM1Inkrem,n0
        move    #>ROM1Length-1,m0
        move    #>ROM2Start,r1
        move    #>ROM2Inkrem,n1
        move    #>ROM2Length-1,m1
        move    #>ROM3Start,r2
        move    #>ROM3Inkrem,n2
        move    #>ROM3Length-1,m2
        move    #>ROM4Start,r3
        move    #>ROM4Inkrem,n3
        move    #>ROM4Length-1,m3
        move    #>OutBufStart+OutBufLength-1,r4
        move    #>OutBufLength-1,m4
        move    #>n,n4

; Code fr die Generierung von n Abtastungen
; ==========================================

        move  x:(r0)+n0,x1
        move  l:(r1)+n1,y

        do n4,loop
        mpy   x1,y1,a  ab,l:(r4)+
        mpy   x1,y0,b  y:(r0)+n0,x0
        macr -x0,y0,a  y:(r2),y0
        macr  x0,y1,b  a,x1
        mpy   x1,y0,b  b,x0 
        mpy  -x0,y0,a  x:(r2)+n2,y1
        macr  x1,y1,a  y:(r3),y0
        macr  x0,y1,b  a,x1
        mpy   x1,y0,b  b,x0 
        mpy  -x0,y0,a  x:(r3)+n3,y1
        macr  x1,y1,a  x:(r0),x1
        macr  x0,y1,b  l:(r1)+n1,y
loop

        move  ab,l:(r4)+

; Programmstopp
; =============

        debug

; Generierung der ROM-Tabellen
; ============================

pi      equ     3.141592654

; ROM1
freq = 2.0*pi/@cvf(ROM1Length)

        org x:ROM1Start
count   set 0
        dup ROM1Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM1Start
count   set 0
        dup ROM1Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

; ROM2
freq = 2.0*pi/@cvf(ROM2Length)
        org x:ROM2Start
count   set 0
        dup ROM2Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM2Start
count   set 0
        dup ROM2Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

; ROM3
freq = 2.0*pi/@cvf(ROM3Length)
        org x:ROM3Start
count   set 0
        dup ROM3Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM3Start
count   set 0
        dup ROM3Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

; ROM4
freq = 2.0*pi/@cvf(ROM4Length)
        org x:ROM4Start
count   set 0
        dup ROM4Length
        dc  @cos(@cvf(count)*freq)
count   set count+1
        endm

        org y:ROM4Start
count   set 0
        dup ROM4Length
        dc  @sin(@cvf(count)*freq)
count   set count+1
        endm

        end 

