function y = audiodenoise(schw,x)
% y = audiodenoise(x,schw)
% Denoising nach FFT-cut-Methode
%  schw:  Schwelle, unter der Frequenzanteile auf 0 gesetzt werden.
%  x   :  Eingabesignal
%  y   :  Ausgabesignal
% Wird das Ausgabesignal nicht einer Variablen zugewiesen, so 
% erfolgt eine Audioausgabe ber die Soundkarte.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1 schw = 3;   end;
if nargin<2 x = cos(2*pi*880/8000*(0:16383)) + randn(1,16384); end;
fsiz = 13;                       % FontSize
fs   = 8000;                     % Abtastrate

% Signalverarbeitung
% ==================
n  = length(x);                  % Anzahl der Abtastungen
t  = (0:n-1)/fs;                 % Zeitbereich
w  = (0:n-1);                    % Frequenzbereich in Hz (2pi)
z  = fft(x);                     % FFT davon 
mittel= mean(abs(z));            % mittlere Amplitude des Spektrums
zcut  = z.*(abs(z)>mittel*schw); % DENOISE-Operation im Frequenzbereich
y  = real(ifft(zcut));           % iFFT

if nargout<1
   xx = x/max(abs(x)+eps);
   sound(xx,fs); pause(2)
   yy = y/max(abs(y)+eps);
   sound(yy,fs); pause(2) 
end