function [x,y,z] = audiohochtast(f,g)
%  [x,y,z] = audiohochtast(f,g)
%  audiohochtast demonstriert die Spektren vor und nach dem Einfgen 
%  von Nullen mit und ohne anschliessender Interpolation fr ein 
%  Sinus-Signal bei der Abtastrate 8 kHz.
%  Parameter:
%  f :  Sinusfrequenzen  0 <= f <= 1 in Hz
%       f = [f1, f2,..., fn] ergibt ein Mehrtonsignal.
%  g :  Grad des Halbbandfilters  fir1(g,1/2) zur Interpolation
%  x :  das ursprngliche Signal
%  y :  das hochgetastete Signal
%  z :  das hochgetastete Signal nach Tiefpassfilterung

%  Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
%  Defaults
%  ========
if nargin<2  g = 10;   end
if nargin<1  f = 3000; end
fs = 8000;                        % Abtastrate in Hz
lw = 2.5;                         % LineWidth
ms = 8;                           % MarkerSize
cm = vga;                         % ColorMap
%
%  Signalerzeugung, Nullen einfgen, Filtern
%  =========================================
t = (1:8192)/fs;                  % Zeitbereich
for kt=1:length(t)  x(kt) = (sum(sin(pi*f*t(kt))))/length(f); end % Signal
y = [nullein(x,1),0];             % Hochtastung durch Einfgung von Nullen
b = 2*fir1(g,1/2);                % Entwurf des Interpolations-Halbbandfilters
z = filter(b,1,y);                % Filtern
%
%  Darstellung des Frequenzganges
%  ==============================
fh1 = fullscreen('Interpolationsfilter');
filterplot(b)
yl = get(gca,'ylim');
for k=1:length(f)
   line(f(k)/fs*[1 1],yl,'LineWidth',lw,'Color',cm(k+2,:))
   line(1-f(k)/fs*[1 1],yl,'LineStyle',':','LineWidth',lw,'Color',cm(k+2,:))
end
%
%  Darstellung des Zeitbereiches (Ausschnitt)
%  ==========================================
fh2 = fullscreen('Zeitbereich');
tk1 = 4000:4050;
tk2 = 8000:8100;
plot(2*tk1,x(tk1))
line(tk2,y(tk2-1),'Color','g')
line(tk2,z(tk2+g/2-1),'Color','r')
legend('Ursprung','Hochtastung','gefiltert')
line(2*tk1,x(tk1),'Color','b','Marker','o','MarkerSize',ms)
line(tk2,y(tk2-1),'Color','g','Marker','x','MarkerSize',ms)
line(tk2,z(tk2+g/2-1),'Color','r','Marker','.','MarkerSize',ms)
%
%  Audio
%  =====
sound(x,8000);  pause(2)
sound(y,16000); pause(2)
sound(z,16000); pause(2)
