function y = audiokomp3(tab,r,x,f1,f2)
% audiokomp3(lut,r,x,f1,f2)
%
% !!! in Arbeit !!!
% hier wird das analytische Signal in Stufen gedreht und der Realteil 
% der kleinsten Amplitude in Abschnitten der Lnge m ausgewhlt.
% Besser ist evtl. die Abspaltung des untersten Teilbandes und 
% explizite Drehung dieses Teilbandes auf minimale Amplitude.
%
% Audiokompression fr Sprachsignale der Abtastrate  fs = 8000 Hz
% tab :  LUT
% r   :  Klangfarbenfilter ( -1<r<0 : Tiefenanhebung; 0<r<1 Hhenanhebung) 
% x   :  Eingangssignal
% f1  :  untere Bandpassgrenze [Hz]
% f2  :  obere Bandpassgrenze [Hz]
% y   :  Ausgangssignal
%
% Wird x nicht angegeben, so wird ein Ton von 880 Hz mit in quidistanten 
% Stufen ansteigender Amplitude erzeugt und das Resultat angezeigt.
%
% Prinzip:
% 1. elliptisches Bandpassfilter mit Durchlass ug...og
% 2. Klangfarbfilter whlbar (FIR, g = 5)
% 3. Kompression durch Phasendrehung
% 4. klassische Kompression:
%    Der Absolutwert des Signals (0...1) wird mithilfe einer Tabelle LUT
%    gewandelt in ein bersteuerungssignal (>=1), welches anschliessend 
%    tiefpassgefiltert wird. Das Eingangssignal wird entsprechend verzgert 
%    durch das Tiefpasssignal dividiert:
%
%      ------> Verzgerung ---------
%     |                             |
%   --|                            DIV -->
%     |                             |
%      --> ABS --> LUT --> IIR-TP --


% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Konstanten und Defaults
% =======================
fs = 8000;                                  % Abtastrate
fsiz = 12;                                  % Fontgrsse
gh = 10;                                    % Grad des Hilbertfilters
c  = 0.011;                                 % Tiefpassgrenze
gtp= 4;                                     % Tiefpassfiltergrad
q  = 8;
if nargin<1  tab = 0; end
lut = tab;
if length(tab)<2
   q   = 5;
   lut = raisedcosine([1,q],50); 
end
if nargin<2  r = 0; end                     % flacher Frequenzgang
if nargin<3
   n = 16384;                               % Inputlnge
   x = cos(2*pi*880/fs*(0:n-1));            % Ton a'
   x = 0.1*x.*round((1:n)/2000);            % Amplitudentreppe
end
if nargin<4  f1 = 300;  end                 % untere Bandpassgrenze 300 Hz
if nargin<5  f2 = 2400; end                 % obere Bandpassgrenze 2400 Hz
m  = 2*round(3.5*fs/f1);                    % Anzahl der Abtastungen fr Mittelwert
k  = mod(length(x),m);
if k>0  x  = [x, zeros(1,m-k)]; end         % Zero-Padding
n  = length(x);                             % Anzahl der Abtastungen
%
% Bandpassfilter
% ==============
ug = f1/fs*2;                               % untere Bandpassgrenze
og = f2/fs*2;                               % obere Bandpassgrenze
[b,a]= ellip(4,1,70,[ug,og]);               % IIR-Filterentwurf               
delb = grpdelay(b,a,ug:0.1:og,2);           % Gruppenlaufzeit
y1   = filter(b,a,x);                       % Filtern
y1   = y1/max(abs(y1));                     % Normierung
%
% Klangfarbenfilter
% =================
bk = 0.5*(1+r)*[0 0 1 0 0] - r*fir1(4,0.2); % FIR-Filterentwurf
bk = bk/sum(bk);                            % Normierung
y2 = filter(bk,1,y1);                       % Filtern
y2 = y2/max(abs(y2));                       % Normierung
%
% Kompression
% ===========
bh  = remez(gh,[ug,og],[1 1],'Hilbert');    % Hilbertfilterentwurf

y20 = delay(y2,gh/2);                       % Phasendrehung 0
y21 = filter(bh,1,y2);                      % Phasendrehung 90
y22 = filter(bh,1,y21);                     % Phasendrehung 180
y23 = filter(bh,1,y22);                     % Phasendrehung 270

mx(1,:) = max(abs(reshape(y20,m,n/m)));     % Amplitude
mx(2,:) = max(abs(reshape(y21,m,n/m)));     % Amplitude
mx(3,:) = max(abs(reshape(y22,m,n/m)));     % Amplitude
mx(4,:) = max(abs(reshape(y23,m,n/m)));     % Amplitude

mmx = min(mx);
ix  = 1*(mx(2,:)==mmx) + 2*(mx(3,:)==mmx) + 3*(mx(4,:)==mmx);
ax = [ix(1)*ones(1,m/2), raisedcosine(ix,m), ix(end)*ones(1,m/2)];
%if length(ax)<length(y2a) ax = [ax, ax(end)*ones(1,length(y2a)-length(ax))]; end

y2b = (ax<1).*(1-ax).*y20        + ...
      (ax<2).*(1-abs(ax-1)).*y21 + ...
      (abs(ax-2)<1).*(1-abs(ax-2)).*y22 + ...
      (abs(ax-2)<1).*(1-abs(ax-2)).*y22 + ...
      (ax>2).*(3-ax).*y23;
y2b = y2b/max(abs(y2b));                    % Normierung

y3  = lut(ceil((length(lut)-1)*(abs(y2b)+eps)));
[bb,aa] = butter(gtp,c);                    % Tiefpassfilterentwurf
del = round(mean(grpdelay(bb,aa,0:c/10:c,2)));
y4 = abs(filter(bb,aa,y3)+eps);             % IIR-Tiefpass
y6 = delay(real(y2b),del)./y4;              % Dynamik-Kompression
%
% Ausgabe
% =======
y  = y6/max(abs(y6));                       % Normierung
%
if nargout>0  break; end                    % keine Graphik, kein Audio
%
% Darstellung
% ===========
fh1 = fullscreen('Phase');
plot(ax)

fh2 = fullscreen('Signal ohne/mit Phasendrehung');
plot(1:length(y2b),abs(real(y2b)),'r',1:length(y20),abs(real(y20)),'b')

fh3 = fullscreen('Gesamtfilter');
filterplot({{b;a};bk},0,1,0,-80,15+30*(r>0.7)*r^4,1,16,1)
title('Bandpass plus Klangfarbfilter','FontSize',fsiz)

if length(tab)>1                            % zur Kontrolle: LUT
   fh5 = fullscreen('LUT','w');
   plot((0:length(lut)-1)/length(lut),lut)
end

fh4 = fullscreen('Signale','w',1);
oh  = plot(1:n,[delay(y2,del);delay(y3,del);y4;y6]);
set(oh(3),'LineWidth',2)
set(oh(4),'Color','m')
line([0 0; n n],max(abs(delay(y2,del)))*[-1 +1;-1 +1],'LineStyle',':','Color','b')
line([0 0; n n],max(abs(y6))*[-1 +1;-1 +1],'LineStyle',':','Color','m')
legend('Bandpasssignal','LUT-Signal','Divisor','Ausgangssignal')
%
% Audioausgabe
% ============
sound( x/max(abs(x)),fs); pause(2)
sound(y2,fs); pause(2)
sound(y,fs); pause(2)

