%Audioausgabe%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Zur Audioausgabe von abgetasteten Signalen, die als MATLAB-Vektoren vorliegen, 
% dient die Funktion sound. soundsc ist eine Version, die das Signal so skaliert, 
% dass gerade keine bersteuerung auftritt:
%
help sound
help soundsc
%
% Soundkarten reagieren unterschiedlich auf die berlappende Ausgabe mit sound. 
% In den folgenden Beispielen wird die berlappung durch Einfgung von Pausen 
% (Anhalten der MATLAB-Interpretation fr n Sekunden) verhindert.
%
%% Der folgende Block muss zuerst ausgefhrt werden.
%% Danach ist die Reihenfolge beliebig:
%
fs = 8000;                  % Abtstrate und Frequenzen in Hertz
c2 = 523; d=587; e=659; f=689; g=784; a=880; h=988; c3=1047;
is = 2^(1/12);              % Intervall Halbtonschritt  %<'Interpreter','none'>
n  = 16384;                 % Lnge der Sequenzen (EDU-Limitierung!)
zp = 2*pi;                  % zwei pi
t  = (1:n)/fs;              % Zeitbereich
%
% Reine Sinus-Tne:
%
y1=0.3*sin(zp*c2*t); sound(y1,fs); pause(3);
y2=0.2*sin(zp*e*t);  sound(y2,fs); pause(3);
y3=0.3*sin(zp*g*t);  sound(y3,fs); pause(3);
%
% Alle zusammen als Ackord:
%
y=y1+y2+y3+0.1*sin(zp*c3*t);  soundsc(y,fs); pause(3);
%
% Ausklingender Sinus    \fontname{Courier}sin\omegat \cdot e^{-t/\tau}:
%
y1=sin(zp*c2*t).*exp(-2.5*t); sound(y1,fs); pause(3);
y2=sin(zp*e*t).*exp(-2.5*t);  sound(y2,fs); pause(3);
y3=sin(zp*g*t).*exp(-2.5*t);  sound(y3,fs); pause(3);
%
% Ausklingender Ackord
%
y=(y1+y2+y3+sin(zp*c3*t).*exp(-2.5*t))/3; soundsc(0.5*y,fs); pause(3);
%
% Dasselbe mit wesentlich kleinerem \tau :
%
y3=sin(zp*g*t).*exp(-15*t);  sound(y3,fs); pause(3);
y3=sin(zp*c3*t).*exp(-15*t); sound(y3,fs); pause(3);
y=sin(zp*100*t).*exp(-25*t); sound(y,fs); pause(3);
y=sin(zp*50*t).*exp(-50*t);  sound(y,fs); pause(3);
%
% Nachfolgend alle Tne der temperierten Oktave:
%
y1=sin(zp*c2*t).*exp(-2.5*t);    sound(y1,fs); % c2
%
y1=sin(zp*c2*is*t).*exp(-2.5*t); sound(y1,fs); % cis, des
%
y1=sin(zp*d*t).*exp(-2.5*t);     sound(y1,fs); % d
%
y1=sin(zp*d*is*t).*exp(-2.5*t);  sound(y1,fs); % dis, es  
%
y1=sin(zp*e*t).*exp(-2.5*t);     sound(y1,fs); % e
%
y1=sin(zp*f*t).*exp(-2.5*t);     sound(y1,fs); % f
%
y1=sin(zp*f*is*t).*exp(-2.5*t);  sound(y1,fs); % fis, ges
%
y1=sin(zp*g*t).*exp(-2.5*t);     sound(y1,fs); % g
%
y1=sin(zp*g*is*t).*exp(-2.5*t);  sound(y1,fs); % gis, as
%
y1=sin(zp*a*t).*exp(-2.5*t);     sound(y1,fs); % a
%
y1=sin(zp*a*is*t).*exp(-2.5*t);  sound(y1,fs); % ais, b
%
y1=sin(zp*h*t).*exp(-2.5*t);     sound(y1,fs); % h
%
y1=sin(zp*c3*t).*exp(-2.5*t);    sound(y1,fs); % c3  
%
% Amplitudenmodulation mit Schmalbandrauschen:
%
[kb,ka]=cheby1(4,1,0.005);
r1 = randn(1,n)/5;
rf=10*filter(kb,ka,r1);
y1=rf.*sin(zp*c2*t); soundsc(y1,8000); pause(3);
y2=rf.*sin(zp*e*t);  soundsc(y2,8000); pause(3);
y3=rf.*sin(zp*g*t);  soundsc(y3,8000); pause(3);
y=(y1+y2+y3+rf.*sin(zp*c3*t)/2);  soundsc(y,8000); pause(3);
y=rf.*sin(zp*100*t).*exp(-2.5*t); soundsc(y,fs);   pause(3);
%
% Frequenzmodulation:
%
y=sin(zp*(1000+10*sin(zp*100*t)).*t);  soundsc(y,fs); pause(3);
y=sin(zp*(1000+1.5*sin(zp*333*t)).*t); soundsc(y,fs); pause(3);
y=sin(zp*(100+700*sin(zp*0.8*t)).*t);  soundsc(y,fs); pause(3);
%
% Xylophon: Sequenz von 16 Anschlgen c3
%
tt=(1:1000)/fs;
y1=sin(zp*c3*tt).*exp(-15*tt);
y=zeros(1,n);
for k=1:16 y=y+[zeros(1,1000*(k-1)+1),y1,zeros(1,n-1000*k-1)]; end;
soundsc(y,fs); pause(3);
%
% Xylophon: Sequenz von Anschlgen \fontname{Courier}c d e f g g g g a f a f g f f f;
%
tt = (1:1000)/fs;
yc2= sin(zp*c2*tt).*exp(-15*tt);
yd = sin(zp*d*tt).*exp(-15*tt);
ye = sin(zp*e*tt).*exp(-15*tt);
yf = sin(zp*f*tt).*exp(-15*tt);
yg = sin(zp*g*tt).*exp(-15*tt);
ya = sin(zp*a*tt).*exp(-15*tt);
yh = sin(zp*h*tt).*exp(-15*tt);
yc3= sin(zp*c3*tt).*exp(-15*tt);
y  = zeros(1,n);
k=1;  y=y+[zeros(1,1000*(k-1)+1),yc2,zeros(1,n-1000*k-1)];
k=2;  y=y+[zeros(1,1000*(k-1)+1),yd,zeros(1,n-1000*k-1)];
k=3;  y=y+[zeros(1,1000*(k-1)+1),ye,zeros(1,n-1000*k-1)];
k=4;  y=y+[zeros(1,1000*(k-1)+1),yf,zeros(1,n-1000*k-1)];
k=5;  y=y+[zeros(1,1000*(k-1)+1),yg,zeros(1,n-1000*k-1)];
k=6;  y=y+[zeros(1,1000*(k-1)+1),yg,zeros(1,n-1000*k-1)];
k=7;  y=y+[zeros(1,1000*(k-1)+1),yg,zeros(1,n-1000*k-1)];
k=8;  y=y+[zeros(1,1000*(k-1)+1),yg,zeros(1,n-1000*k-1)];
k=9;  y=y+[zeros(1,1000*(k-1)+1),ya,zeros(1,n-1000*k-1)];
k=10; y=y+[zeros(1,1000*(k-1)+1),yf,zeros(1,n-1000*k-1)];
k=11; y=y+[zeros(1,1000*(k-1)+1),ya,zeros(1,n-1000*k-1)];
k=12; y=y+[zeros(1,1000*(k-1)+1),yf,zeros(1,n-1000*k-1)];
k=13; y=y+[zeros(1,1000*(k-1)+1),yg,zeros(1,n-1000*k-1)];
k=14; y=y+[zeros(1,1000*(k-1)+1),yf,zeros(1,n-1000*k-1)];
k=15; y=y+[zeros(1,1000*(k-1)+1),yf,zeros(1,n-1000*k-1)];
k=16; y=y+[zeros(1,1000*(k-1)+1),yf,zeros(1,n-1000*k-1)];
soundsc(y,fs); pause(3);
%
% Frequenzmodulation (ausklingend):
%
y = sin(2*pi*(440+0.4*sin(2*pi*1016.9*t)).*t).*exp(-2*t); soundsc(y,fs); pause(3);
%
% Frequenzmodulation (Variante des oberen)
%
y = sin(2*pi*(1440+1.0*cos(2*pi*441*t)).*t).*exp(-2*t); soundsc(y,fs); pause(3);
%
% Ausklingendes gefiltertes Rauschen  (Simulation eines Schusses):
%
y = filter(remez(62,[0,0.1,0.2,0.3,0.4,1],[0,0,1,1,0,0]),1,randn(1,16384).*exp(-5*t)); 
soundsc(y,fs); pause(3);
%
