function ddsoutquant(n,r,p,p0)
% ddsoutquant(n,r,p0,p)
% Darstellung der Quantisierung der Kreisfunktion 
% mit je n Bits fr den Real- bzw. Imaginrteil.
%
% Eine Animation markiert fortlaufend die Ausgabepunkte fr 
% die Anfangsphase p0 und den Phasenschritt p in Grad.
% Die Animation kann mit der Faste s (stop) angehalten werden.
% r = 0  :  volle Amplitude (1.0)
% r > 0  :  Amplitude r
% r < 0  :  um einen Quantisierungsschritt reduzierte Amplitude

% Defaults
% ========
if nargin<4  p0 =  0;  end
if nargin<3   p =  35; end
if nargin<2   r = -1;  end
if nargin<1   n =  6;  end

% Konstanten
% ==========
ms = 18;                           % MarkerSize
fsiz = 20;                         % FontSize fr Buttons
k  = 1024;                         % Anzahl der Kreispunkte
b  = 2^(n-1);                      % Niveaus im 2-Komplement
b1 = 1/b;                          % Niveau-Abstand im 2-Komplement
mx = 1 - b1;                       % Maximum im 2-Komplement
a  = 2*pi*(0:k-1)/k;               % die Winkel der Kreispunkte
s  = exp(i*a);                     % Kreis
if r>0  s = r*s; end               % Kreisradius
if r<0  s = mx*s; end              % Kreisradius
n1 = (-1:b1:mx);                   % Hilfsvektor
n2 = ones(1,2^n);                  % Hilfsvektor

v     = 1;
ix(1) = 1;
xd(1) = max([min([round(real(s(1))*b)*b1,mx]),-1]);
yd(1) = max([min([round(imag(s(1))*b)*b1,mx]),-1]);
for w = 2:k
   xx = max([min([round(real(s(w))*b)*b1,mx]),-1]);
   yy = max([min([round(imag(s(w))*b)*b1,mx]),-1]);
   if xx~=xd(v) | yy~=yd(v)
      if xx==xd(1) & yy==yd(1)
         ix(w) = 1;
      else
         v = v + 1;
         xd(v) = xx;
         yd(v) = yy;
      end
   end
   ix(w) = v;
end

% Graphik
% =======
fh = fullscreen('Quantisierung');
l1 = line([n1;n1],[-n2;mx*n2],'Color',0.7*[1 1 1]);
l2 = line([-n2;mx*n2],[n1;n1],'Color',0.7*[1 1 1]);
l3 = line(real(s),imag(s));
for kk=1:max(ix)
   l4(kk) = line(xd(kk),yd(kk),'Marker','.','MarkerSize',ms,'LineStyle','none','Color','g');
end
l5 = line(0,0,'Marker','o','MarkerSize',ms/2,'LineStyle','none','Color','k');
axis(1.01*[-1 1 -1 1]); axis square; axis off
apos = get(gca,'Position');
apos(1,1) = 0;
set(gca,'Position',apos)
text(1.2,0.8,'Ende der Interaktion','FontSize',fsiz,'FontWeight','bold','Color','r')
text(1.2,0.4,'Input-Dialog','FontSize',fsiz,'FontWeight','bold','Color','b')


% Interaktion
% ===========
set(fh,'KeyPressFcn','set(gcf,''UserData'',get(gcf,''CurrentCharacter''))')
stop = 0;
w    = p0;
in   = 1;
while ~stop
   ia = in;
   in = ix(1 + mod(round(k*w/360),k));
   set(l4(ia),'Color','g')
   set(l4(in),'Color','r')
   drawnow
   w = w + p;
   waitforbuttonpress;   
   cp = get(gca,'CurrentPoint');
   if sum((cp(1,1:2)-[1.48 0.8]).^2)<0.08  stop = 1; end
   if sum((cp(1,1:2)-[1.48 0.4]).^2)<0.08
      intxt = inputdlg('p ,  p0  in Grad','Eingabe');
      if ~isempty(intxt) & length(intxt{1})>0
         par = eval(strcat('[',intxt{1},']'));
         if isreal(par)
            p   = par(1);
            w   = par(2);
         end
      end
   end
end

set([l1 l2],'UserData',10*fh+1)
set([l4 l5],'UserData',10*fh+3)
set(l3,'UserData',10*fh+2)
set(fh,'KeyPressFcn','sichtbarkeit');
