function b = decbandpass(g,k,bw,wt,sf)
% b = decbandpass(g,k,bw,wt,sf)
% Es wird ein zum Dezimatiosfaktor k passendes Halbbandfilter entworfen 
% mit Durchlass bei  Abtastfrequenz/4  und Sperrung aller Aliasfrequenzen.
% g  :  nicht zu unterschreitender Filtergrad
% k  :  Dezimationsfaktor (muss ungerade sein!)
% bw :  Bandbreite des Durchlasses (und der Sperrgebiete)
% wt = 0 :  Der Entwurf erfolgt durch explizites Vorgeben der Nullstellen
% wt > 0 :  Der Entwurf erfolgt durch REMEZ mit dem Gewicht wt im Durchlassbereich. 
% sf :  die Sperrgebiete sind  sf*bw  breit (nur wirksam bei REMEZ)
% Ausgegeben werden die Filterkoeffizienten. Der Filtergrad kann grsser als g sein.

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<5  sf = 1;       end
if nargin<4  wt = 0;       end
if nargin<2   k = 3;       end;
if nargin<3  bw = 1/k/10;  end;
if nargin<1   g = 20;      end;
if mod(k,2)==0  error('k muss ungerade sein.'); end;

% Konstante
% =========
g = 4*ceil(g/4);

% Filterentwurf
% =============
if wt>0                          % Entwurf mit REMEZ
   a = ones(1,k)*sf*bw/2;
   aa = [a,a(k:-1:1)];
   aa((k+1)/2) = aa((k+1)/2)/sf; % Durchlassbereich 
   ff = (1:2:2*k)/k/2;           % Mitten der Sperr- und Durchlassbereiche
   j = 1;
   for i = 1:k
       f(j) = ff(i) - aa(j);
       j = j + 1;
       f(j) = ff(i) + aa(j);
       j = j + 1;
   end;
   d = zeros(1,2*k);
   d(k)   = 1;
   d(k+1) = 1;
   gew = ones(1,k);
   gew((k+1)/2) = wt;
   b = remez(g,f,d,gew);
   fr= freqz(b,1,2);
   b = b/abs(fr(2));
else                           % Entwurf durch Setzen der Nullstellen
   n  = ceil(g/2/(k-1));
   g  = 2*(k-1)*n;
   if n==1  q = 0; else  q  = ((1:n)-(n+1)/2)/(n-1)*sf*bw; end
   ff = (1:2:k-2)/k/2;
   ns = [];
   for i=1:(k-1)/2  ns = [ns ff(i)+q]; end
   ns = [ns  1-reverse(ns)];
   ns = flach([ns;-ns]')';
   [b,a] = z2koef(ns);
   b  = real(b + reverse(b))/2;
end
