function demolinphas
% demolinphas
% Vergleich linearphasiges FIR-Filter 
% mit nicht linearphasigem IIR-Filter

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
fsiz = 13;                             % FontSize
n=512;                                 % Anzahl Abtastschritte
t=(1:n)/n;                             % Zeitbereich 1 sec
s1=ones(1,n/4);
s0=zeros(1,n/4);
s=[s1,s0,s1,s0];                       % Rechtecksignal
[b,a]=cheby1(2,1,0.07);                % IIR-Filter von Grad 2

h(2) = fullscreen('Betrags-Frequenzgang');
bb=fir1(30,0.1);                       % FIR-Filter von Grad 30
subplot(1,2,1);                        % (dessen Phasengang ist linear)
filterplot(bb);                        % dessen Amplituden-Frequenzgang
title('FIR-Filter','FontSize',fsiz);
subplot(1,2,2);                        % (dessen Phasengang ist nicht linear)
filterplot({{b;a}});                   % dessen Amplituden-Frequenzgang
title('IIR-Filter','FontSize',fsiz);

h(1) = fullscreen('Phasen-Frequenzgang');
subplot(1,2,1);
w = (0:n-1)/n;
plot(w,unwrap(angle(freqz(bb,1,n))));  % Phasengang (FIR) ohne 2*pi-Sprnge (unwrap)
title('Phasengang des FIR-Filters','FontSize',fsiz)
subplot(1,2,2);
plot(w,angle(freqz(b,a,n)));           % Phasengang (IIR)          
title('Phasengang des IIR-Filters','FontSize',fsiz)

h(3) = fullscreen('Zeitbereich');
subplot(1,1,1);
plot(t,s,t,1.12*filter(b,a,s),t,filter(bb,1,s));
legend(sprintf('Input: Rechteck'),sprintf('mit IIR gefiltert'),sprintf('mit FIR gefiltert'));
title('Wirkung nichtlinearen Phasengangs','FontSize',fsiz);
xlabel('Zeitbereich','FontSize',fsiz-1);
ylabel('Signal','FontSize',fsiz-1);
set(h(3),'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
set(h(3),'KeyPressFcn','hervorhebung')
