function denoise(n,a,schw)
% denoise(n,a,schw)
% Denoising nach FFT-cut-Methode
%  n   :  Anzahl der Abtastschritte
%  a   :  Amplituden vektor fr ein Dreitonsignal, z.B. [1 1/2 1/3]
%  schw:  Schwelle, unter der Frequenzanteile auf 0 gesetzt werden.
% Gezeigt wird ein Sinus-Signal plus Rauschen fr n Samples:
% (1)  Original
% (2)  nach Denoising

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1    n = 600; end;
if nargin<2    a = [1 1/2 1/3]; end;
if nargin<3 schw = 3;   end;
fsiz = 13;                    % FontSize

% Signalverarbeitung
% ==================
t  = (0:n-1)/n;               % Zeitbereich: 1 Sekunde in n Punkten
w  = (0:n-1);                 % Frequenzbereich in Hz (2pi)
r  = 2*rand(1,n)-1;           % n Pseudozufallszahlen -1..+1
sig= a(1)*(sin(2*pi*50*t)+a(2)*sin(2*pi*60*t)+a(3)*sin(2*pi*15*t)); %Signal
s  = r + sig;                 % Signal plus Rauschen
y  = fft(s);                  % FFT davon 
ffts  = abs(y);               % Spektrum
mittel= mean(ffts);           % mittlere Amplitude des Spektrums
ycut  = y.*(ffts>mittel*schw);% DENOISE-Operation im Frequenzbereich
scut  = real(ifft(ycut));     % iFFT

% Darstellung
% ===========
h(1) = fullscreen('S+N/Z');
plot(t(1:200),s(1:200));     
xlabel('Zeit [sec]','FontSize',fsiz);
title('Signal plus Rauschen','FontSize',fsiz);

h(2) = fullscreen('S+N/F');
plot(w,ffts);                
xlabel('Frequenz [Hz]','FontSize',fsiz);
title('Spektrum von Signal plus Rauschen','FontSize',fsiz);

h(3) = fullscreen('Denoise/F');
plot(w,ffts,'g',w,abs(ycut),'r');
line([0, n-1],mittel*schw*[1 1],'LineStyle',':','Color',0.7*[1 1 1])
legend('Original','nach Cut','Schwelle');
xlabel('Frequenz [Hz]','FontSize',fsiz);
title('Spektrum von Signal plus Rauschen vor und nach Cut','FontSize',fsiz);

h(4) = fullscreen('Denoise/Z');
plot(t,r,'g',t,sig-scut,'r');
legend('Rauschen','Signal - Cut');
xlabel('Zeit [sec]','FontSize',fsiz);
title('Rauschen vor und nach Denoising','FontSize',fsiz);
