        page    132
;***************************************************************************
;
; DIGOSZBS.ASM :  Zwei Digitale Oszillatoren nach der Rekursion
;
;                 z(k) = c * z(k-1) - z(k-2)
;
; wo  c = 2 * cos(2*pi*frq)  und  z(1) = sin(p)   z(2) = sin(p+2*pi*freq) .
;
; Die Parameter fr die beiden Oszillatoren sind anstelle von freq und p
; freq1, p1  bzw.  freq2, p2
;
; Die Arithmetik wird mit 24 Bits durchgefhrt.
; Ausgabe der beiden generierten Signale auf den Kanlen L und R.
;
;****************************************************************************
;
; Oszillator-Parameter
; ====================
frq1         equ   0.123456789     ; Frequenz relativ zur Abtastfrequenz
frq2         equ   3*frq1/2        ; Frequenz relativ zur Abtastfrequenz
p1           equ   0.00            ; Anfangsphase zu frq1 (1.0 entspricht 2*pi))
p2           equ   0.1133557799    ; Anfangsphase zu frq2 (1.0 entspricht 2*pi))
pi           equ   3.1415926535
sp11         equ   @sin(p1)        ; Startwert 1
sp21         equ   @sin(p2)        ; Startwert 2
sp12         equ   @sin(p1+2*pi*frq1) ; Folgewert 1
sp22         equ   @sin(p2+2*pi*frq2) ; Folgewert 2
w1           equ   @cos(2*pi*frq1) ; Winkelschritt
w2           equ   @cos(2*pi*frq2) ; Winkelschritt
;****************************************************************************
DefaultCTRL     equ     $000000       ; Steuervariable nach Belieben nutzbar
DefaultADACTRL  equ     $383400       ; Mikroverstrker AUS, 48 kHz-Sampling, Stereo
DefaultADAOUT   equ     $C00000       ; alle Ausgnge EIN, keine Abschwchung
DefaultADAIN    equ     $10F000       ; Verstrkung L und R: 22.5 dB, Monitor: -96 dB
DefaultDSPCLK   equ     $261009       ; PLL-Einstellung des DSP auf x:$FFFD
;                            ^^-------- DSP-Taktfrequenz ($09+1)*4.000 MHz
CTRL_WD_34      equ     $A20000       ; IMMED_3STATE+XTAL2_SELECT+BITS_64+CODEC_MASTER
;*****************************************************************************
;  Defined Constants used to construct data for the CONTROL TIME SLOTS
;****************************************************************************
IMMED_3STATE    equ     $800000 ;1=SCLK & FS 3-state immediately
XTAL2_SELECT    equ     $200000 ;REQUIRED as this is the only clock
                                ;  source on the board
BITS_64         equ     $000000 ; 64 bits per frame
BITS_128        equ     $040000 ;128 bits per frame
BITS_256        equ     $080000 ;256 bits per frame
CODEC_MASTER    equ     $020000 ;1 == codec generates SCLK & FS
                                ;0 == codec receives  SCLK & FS
CODEC_TX_OFF    equ     $010000 ;0 == enable codec TX to DSP
                                ;1 == disable (Hi-Z) codec output

;----------------------------------------------------------------------------
;  constructed constants for codec set up/initialize
;----------------------------------------------------------------------------
;
;CTRL_WD_34      equ     IMMED_3STATE+XTAL2_SELECT+BITS_64+CODEC_MASTER
CTRL_WD_56      equ     $000000
CTRL_WD_78      equ     $000000

;---DSP56002 on-chip peripheral addresses
IPR             equ     $FFFF   ;Interrupt Priority Register
BCR             equ     $FFFE   ;Bus Control Register
PLL             equ     $FFFD   ;PLL Control Register
SSIDR           equ     $FFEF   ;SSI Data Register
SSISR           equ     $FFEE   ;SSI Status Register
CRB             equ     $FFED   ;SSI Control Register B
CRA             equ     $FFEC   ;SSI Control Register A
PCD             equ     $FFE5   ;Port C Data Register
PCDDR           equ     $FFE3   ;Port C Data Direction Register
PCC             equ     $FFE1   ;Port C Control Register
PBC             equ     $FFE0   ;Port B Control Register
;****************************************************************************
;
STACK   equ     $0050         ; Puffer-Basis (x-Speicher) beliebig legbar

        org     x:$0010       ; der Adressbereich $0000 - $0013 ist vergeben
ADACTRL dc      DefaultADACTRL
ADAOUT  dc      DefaultADAOUT
ADAIN   dc      DefaultADAIN 
CTRL    dc      DefaultCTRL   ; nderung von CTRL bewirkt Initialis. des CODEC
DSPCLK  dc      DefaultDSPCLK ; nderung nur gleichzeitig mit CTRL
LCTRL   dc      $003300       ; der letzte Wert von CTRL, (hier nicht ndern!)
LCLK    dc      DefaultDSPCLK ; der letzte Wert von PLL
ADAWD34 dc      CTRL_WD_34    ; wegen CLOCK_SELECT 1/2 bei EasyDSP/EVM
RND     dc      $000100       ; Hilfsvariable fr das Runden von 24 auf 16 Bit
C1      dc      w1
ZZ1     ds      1
Z1      ds      1
C2      dc      w2
ZZ2     ds      1
Z2      ds      1

START   EQU     $40
        
        org     p:$0
        jmp     START

        org     p:$000c
        jsr     ssi_rx_isr      ;SSI receive data
        jsr     ssi_rx_isr      ;SSI receive data with exception
        jsr     ssi_tx_isr      ;SSI transmit data
        jsr     ssi_tx_isr      ;SSI transmit with exception

        org     p:START

        move    x:DSPCLK,x0     ; DSP-Takt holen und diesen in LCLK
        move    x0,x:LCLK       ; speichern, damit nderung bemerkbar
        movep   x0,x:PLL        ; PLL und BCR sind erklrt im ADA_CTRL.ASM
        movep   #0000,x:BCR     ; ADA_CTRL.ASM
        ori     #3,mr           ; mask interrupts
        movec   #0,sp           ; clear hardware stack pointer
        move    #0,omr          ; operating mode 0
        move    #STACK,r6       ; initialise stack pointer
        move    #-1,m6          ; linear addressing

Initialisierung:

        move    x:DSPCLK,a      ; falls DSPCLK 
        move    x:LCLK,b        ; gegenber LCLK
        cmp     a,b             ; gendert,
        jne     START           ; dann ganz an START zurck.
        move    x:CTRL,a
        move    a,x:LCTRL

        move  #sp11,a
        move  a,x:ZZ1
        move  #sp12,a
        move  a,x:Z1
        move  #sp21,b
        move  b,x:ZZ2
        move  #sp22,b
        move  b,x:Z2

;****************************************************************************
;	ADA_CTRL.ASM
;	         Dieses Programm dient der Einstellung des 
;                Crystal Semi. CS4215 A/D & D/A Converters
;
;  	NOTES:
;          1-  The DSP5002EVM analog inputs are connected to "MIC"
;                input pins only.  The "LINE" input pins are connected
;                to analog GROUND.  Line level inputs are supported
;                by disabling the 20 dB Microphone Pre-Amplifier.
;          2-  As shipped, the DSP56002EVM has a 24.576 MHz crystal
;                connected to the XTAL2 inputs of the CD4215.  Do
;                not select any other clock source unless the board
;                has been modified to support the alternate clock
;                source(s).
;
;
;       Das Programm entstand aus dem ADA_INIT.ASM, fr welches gilt:
;	Copyright (c) MOTOROLA 1995
;		      Semiconductor Products Sector 
;		      Digital Signal Processing Division
;
;****************************************************************************
;
;      portc usage:
;     	bit8: SSI TX (from DSP to Codec)
;	bit7: SSI RX (from Codec to DSP)
;	bit6: SSI Clock
;	bit5: SSI Frame Sync
;	bit4: codec reset (from DSP to Codec)
;	bit3:
;     	bit2: data/control bar
;             0=control
;             1=data
;
;****************************************************************************


;----------------------------------------------------------------------------
; The two buffers which are defined below are the source and
; destination storage for the codec Input/Output ISRs
;----------------------------------------------------------------------------
       org    x:0
RX_BUFF_BASE    equ     *
RX_data_1_2     ds      1       ;data time slot 1/2 for RX ISR
RX_data_3_4     ds      1       ;data time slot 3/4 for RX ISR
RX_data_5_6     ds      1       ;data time slot 5/6 for RX ISR
RX_data_7_8     ds      1       ;data time slot 7/8 for RX ISR

TX_BUFF_BASE    equ     *
TX_data_1_2     ds      1       ;data time slot 1/2 for TX ISR
TX_data_3_4     ds      1       ;data time slot 3/4 for TX ISR
TX_data_5_6     ds      1       ;data time slot 5/6 for TX ISR
TX_data_7_8     ds      1       ;data time slot 7/8 for TX ISR

RX_PTR          ds      1       ; Pointer for rx buffer
TX_PTR          ds      1       ; Pointer for tx buffer



;***************************************************************************
;***** 			initialize the CS4215 codec                    *****
;***************************************************************************
;   1.  Configure the SSI port and the GPIO lines used (D/C~ & Reset)
;   2.  Select Control Mode and reset the codec (50ms @ 40MHz)
;   3.  Initialize the Transmit Data Buffer with Control Words (CLB=0)
;   4.  Enable SSI
;   5.  Wait until CLB in receive buffer = 0
;   6.  Set CLB = 1 in TX buffer
;   7.  Send 4 frames of data
;   8.  Disable SSI port
;   9.  Program SSI to receive Frame Sync and Clock
;  10.  Select Data Mode (D/C~ = 1)
;  11.  Enable SSI port
;***************************************************************************
;
;
        org     p:
codec_init
	move    #RX_BUFF_BASE,x0
	move         x0,x:RX_PTR             ; Initialize the rx pointer
	move    #TX_BUFF_BASE,x0
	move         x0,x:TX_PTR             ; Initialize the tx pointer


;----- initialize SSI -----
; Assuming the DSP56002 is running at 40 MHz,  this section selects a
;   2.5 MHz SSI clock to be sent from the 56002's SSI clock circuit 
;   to the codec.  It also sets up 64-bit frame length (4 words per
;   frame x 16-bits per word), enables SSI TX & RX, enables TX & RX
;   interrupts and synchronous operation with bit-length frame sync.
;----------------------------------------------------------------------------
	movep   #$0000,x:PCC    ;  turn off ssi port 
	movep   #$4303,x:CRA    ;  40MHz/16 = 2.5MHz SCLK, WL=16 bits, 4W/F
	movep   #$FB30,x:CRB    ; RIE,TIE,RE,TE, NTWK, SYN, FSR/RSR->bit
	movep   #$14,x:PCDDR    ; setup pc2 and pc4 as outputs
	movep   #$0,x:PCD       ; D/C~ and RESET~ = 0 ==> control mode
				;----reset delay for codec ----
	do      #500,_delay_loop
	rep     #2000           ; 100 us delay
	nop
_delay_loop
	bset    #4,x:PCD        ; RESET~ = 1
	movep   #$3000,x:IPR    ; set interrupt priority level
	movep   #$01E8,x:PCC    ; Turn on ssi port


;--- set up the TX buffer with control mode data
	move    x:$0010,x0      ; hier wird die feste Adresse x:$0010 verwendet
	move                     x0,x:TX_BUFF_BASE
;	move    #CTRL_WD_34,x0  ; dies besser auf Variable:
        move    x:ADAWD34,x0    ; wegen XTAL1/2 bei EVM bzw. EasyDSP
	move                     x0,x:TX_BUFF_BASE+1
	move    #CTRL_WD_56,x0
	move                     x0,x:TX_BUFF_BASE+2
	move    #CTRL_WD_78,x0
	move                     x0,x:TX_BUFF_BASE+3

	andi    #$FC,mr         ; enable interrupts

;
; CLB == 0 in TX Buffer,  wait for CLB == 1 in RX Buffer
;
	jclr    #3,x:SSISR,*            ; wait until rx frame bit==1
	jset    #3,x:SSISR,*            ; wait until rx frame bit==0
	jclr    #3,x:SSISR,*            ; wait until rx frame bit==1
	jset    #18,x:RX_BUFF_BASE,*    ; loop until CLB set

;
; CLB == 1 in RX Buffer, send 4 frames and then disable SSI
;
	bset    #18,x:TX_BUFF_BASE      ;set CLB
	do      #4,_init_loopB          ; Delay as 4 full frames to pass
	jclr    #2,x:SSISR,*            ; wait until tx frame bit==1
	jset    #2,x:SSISR,*            ; wait until tx frame bit==0
_init_loopB
	movep   #0,x:PCC                ;reset SSI port (disable SSI...)

;
;    now CLB should be 1 -- re-program fsync and sclk direction to input
;
;	movep   #$4303,x:CRA    ; 16bits,4 word/frame, /2/4/2=2.5 MHz
	movep   #$FB00,x:CRB    ; rcv,xmt & int ena,netwk,syn,sclk==inp,msb 1st
	movep   #$14,x:PCD      ; D/C~ pin = 1  ==> data mode
	movep   #$01E8,x:PCC    ;  turn on ssi port (enable SSI now...)
;--------------------------------------------------------------------------
;   this is the end of the ada_init.asm routine...the main program continues
;--------------------------------------------------------------------------

sample
        move    x:LCTRL,x0
        move    x:CTRL,a
        cmp     x0,a
        jne     Initialisierung ; wenn x:CTRL gendert
        
        jset    #2,x:SSISR,*    ; wait for frame sync to pass
        jclr    #2,x:SSISR,*    ; wait for frame sync

        move    x:RX_BUFF_BASE,a        ; receive left
        move    x:RX_BUFF_BASE+1,b      ; receive right

        jsr     audio_process

        move    x:RND,x1           ; Runden von 24 Bit auf 16 Bit:
        jclr    #7,a1,RUNDA        ; Rundung a
        add     x1,a               ; auf 16 Bit
RUNDA:  jclr    #7,b1,RUNDB        ; Rundung b
        add     x1,b               ; auf 16 Bit
RUNDB:
        move    a,x:TX_BUFF_BASE        ; transmit left
        move    b,x:TX_BUFF_BASE+1      ; transmit right

        move    x:ADAOUT,y0             ; set up control words
        move    y0,x:TX_BUFF_BASE+2
        move    x:ADAIN,y0
        move    y0,x:TX_BUFF_BASE+3

        jmp     sample

audio_process
        move  x:C1,x0
        move  x:Z1,y0
        mpy   x0,y0,a   x:ZZ1,y1
        mac   x0,y0,a   y0,x:ZZ1
        sub   y1,a
        move  a,x:Z1
        move  x:C2,x0
        move  x:Z2,y0
        mpy   x0,y0,b   x:ZZ2,y1
        mac   x0,y0,b   y0,x:ZZ2
        sub   y1,b
        move  b,x:Z2
        rts


;*****************************************************************************
;   TXRX_ISR.ASM 
;     This file contains the basic Interrupt Service Routines (ISR) 
;       used to service the SSI Transmit and SSI Receive Interrupts:
;               ssi_rx_isr
;               ssi_tx_isr
;
;       Before using these routines, the appropriate interrupt
;       vectors must be initialized to jump to the associated 
;       handler. (e.g., P:$000C, the SSI RX interrupt vector should
;       have an instruction which forces the DSP to jump to the
;       address of ssi_rx_isr).  In addition, the DSP's Interrupt 
;       Priority Register (IPR) must choose an interrupt level for
;       the SSI interrupts and the DSP56002's Mode Register must 
;       enable that interrupt level.
;
;    The ISRs which follow require that r6 has been established as 
;      a pointer to a stack which grows towards increasing addresses.
;*****************************************************************************
;
;	Copyright (c) MOTOROLA 1995
;		      Semiconductor Products Sector 
;		      Digital Signal Processing Division
;
;*****************************************************************************

;--------------------------------------------------------------------
;   SSI Receive ISR
;   This Interrupt Service Routine is the destination of the SSI RX 
;      vector located at p:$000C.   In many cases the SSI RX w/Exception
;      vector will also jump here.
;   R6 should point to the first free location on the stack (in X:memory).
;   The data is placed in a 1 frame (4 word) buffer and sync. 
;      is verified/restored every frame.
;--------------------------------------------------------------------
ssi_rx_isr
	move    r0,x:(r6)+              ; Save r0 to the stack.
	move    m0,x:(r6)+              ; Save m0 to the stack.
	move    #3,m0                   ; Modulo 4 buffer.
	move    x:RX_PTR,r0             ; Load the pointer to the rx buffer.
	jclr    #3,x:SSISR,next_rx      ; If not fr. syc, jump to receive data.
	move    #RX_BUFF_BASE,r0        ; If frame sync, reset base pointer.
	nop
next_rx
	movep   x:SSIDR,x:(r0)+         ; Read out received data to buffer.
	move    r0,x:RX_PTR             ; Update rx buffer pointer.
	move    x:-(r6),m0              ; Restore m0.
	move    x:-(r6),r0              ; Restore r0.
	rti

;--------------------------------------------------------------------
;   SSI Transmit ISR
;   This Interrupt Service Routine is the destination of the SSI TX 
;      vector located at p:$0010.   In many cases the SSI TX w/Exception
;      vector will also jump here.
;   R6 should point to the first free location on the stack (in X:memory).
;   The data is taken from a 1 frame (4 word) buffer and sync. 
;      is verified/restored every frame.
;--------------------------------------------------------------------
ssi_tx_isr
	move    r0,x:(r6)+              ; Save r0 to the stack.
	move    m0,x:(r6)+              ; Save m0 to the stack.
	move    #3,m0                   ; Modulus 4 buffer.
	move    x:TX_PTR,r0             ; Load the pointer to the tx buffer.
	jclr    #2,x:SSISR,next_tx      ; If not frame sync, jump to transmit data.
	move    #TX_BUFF_BASE+1,r0      ; If frame sync, reset pointer.
	nop
next_tx
	movep   x:(r0)+,x:SSIDR         ; SSI transfer data register.
	move    r0,x:TX_PTR             ; Update tx buffer pointer.
	move    x:-(r6),m0              ; Restore m0.
	move    x:-(r6),r0              ; Restore r0.
	rti

        end
