function x = diskretfourier(s)
% x = diskretfourier(s)
% Bestimmung der periodischen Fouriertransformierten aus einer 
% gegebenen Sequenz  s  von Abtastwerten. Alle ausserhalb des 
% Vektors s liegenden Abtastungen werden als Null angenommen.
% Wird diskretfourier ohne Parameter aufgerufen, so wird ein
% Gauss-Puls mit zwei Frequenzen erzeugt.
 
% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<1 
   t = (-100:99)/200;
   s = (sin(2*pi*20*t)+0.4*sin(2*pi*33*t)).*exp(-30*t.^2);
end;
fsiz = 12;                       % FontSize

% Hilfsgrssen
% ============
m  = 200;                        % Frequenzbereich in 2*m+1 Punkten
du = 2*pi/(2*m+1);               % Auflsung im Frequenzbereich
k  = 1:length(s);                % Sample-Nummern
zb = k;                          % Zeitbereich
fb = (-m:m)/(2*m+1)*2;           % Frequenzbereich

% Fouriertransformation
% =====================
for u = -m:m  S(u+m+1) = s*exp(-i*u*du*k)'; end

% Darstellung Zeitbereich
% =======================
h(1) = fullscreen('zeitdiskretes Signal','w',0,[2 1; 1 1]);
plot(k,s)
line([zb;zb],[zeros(size(s));real(s)],'Color','r')
line(get(gca,'xlim'),[0 0],'LineStyle',':','Color','k')
fmark=line('Color','r','LineStyle','.','MarkerSize',10);
set(fmark,'xdata',zb,'ydata',s);
title('diskretes Signal s','FontSize',fsiz) 
xlabel('Zeitbereich','FontSize',fsiz)
x = S;
%
% Darstellung Frequenzbereich
% ===========================
h(2) = fullscreen('Fouriertransformierte','w',0,[2 1; 2 1]);
plot(fb,real(S),'b',fb,imag(S),'r')
line([0 0],get(gca,'ylim'),'LineStyle',':','Color',0.7*[1 1 1])
legend('Realteil','Imaginrteil')
title('eine Periode der Fouriertransformierten des diskreten Signals s',...
      'FontSize',fsiz) 
xlabel('Omega  ( 1 = Nyquistfrequenz )','FontSize',fsiz)
