%
%
%10.3  Hilbert-Transformation%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-2,'Color',MSVTITLCOLOR>
%
%
%
%  Die zur Erzeugung eines analytischen Signals erforderliche Hilbert-Transformation 
%  soll die Phase um   {\fontname{Courier}-sign(\omega) \pi/2}   drehen und die Amplitude nicht verndern.  
%  Die bertragungsfunktion ist damit
%
%  H(\omega) = e^{-i sign(\omega) \pi/2} = -i sign(\omega)                   %<'FontName',MSVFORMFONT>
%
%  Durch inverse Fouriertransformation erhlt man daraus die nichtkausale Impulsantwort:
%        0               \pi                                                 %<'FontName',MSVFORMFONT>
%  h_k =  {\fontsize{28}_\int} i e^{ik\omega} d\omega  -  {\fontsize{28}_\int} i e^{ik\omega} d\omega  %<'FontName',MSVFORMFONT>
%       -\pi              0                                                  %<'FontName',MSVFORMFONT>
%
%     = (2/k\pi) (sin(k\pi/2))^2 ;   h_0 = 0                                 %<'FontName',MSVFORMFONT>
%
%  Diese Impulsantwort ist wie die des idealen Tiefpasses im Zeitbereich beidseitig 
%  unendlich.  Einen Ausschnitt von  {\fontname{Courier}31}  Punkten dieser Impulsantwort zeigt 
%  das folgende Bild.
%
g = 30; n = g/2; k = -n:n;            % 31 Punkte 
h = (2./(pi*k)).*(sin(pi*k/2)).^2;    % Impulsantwort nach obiger Formel
                                      % bei k = 0 Division durch Null, deshalb:
h(n+1) = 0;                           % richtiger Wert fr k = 0
fh1 = fullscreen('Hilbertfilter');    % Grafikfenster erzeugen 
stem(h); axis([0,g+2,-0.7,0.7])       % Impulsantwort zeichnen
title('Ausschnitt aus der idealen Impulsantwort des Hilbertfilters','FontSize',12)
%
%  Beim Entwurf des Hilbertfilters mit  {\fontname{Courier}remez}  ergeben sich nur geringfgig 
%  andere Koeffizienten:
%
g = 30;                               % Filtergrad
b = remez(g,[.1 .9],[1 1],'Hilbert'); % Hilbert-Filter mit REMEZ 
fh2 = fullscreen('Hilbertfilter');    % Grafikfenster erzeugen 
stem(b); axis([0,g+2,-0.7,0.7])       % Impulsantwort zeichnen
title('Entwurf eines Hilbertfilters vom Grad 30 mit REMEZ','FontSize',12)
%
%  Mit einem FIR-Filter ist die ideale Hilberttransformation nicht erreichbar.  
%  Die Einbuen betreffen allerdings nicht die Phasendrehung sondern die Amplitude.  
%  Das eben berechnete Hilbertfilter vom Grad {\fontname{Courier}30}  ist z.B. anstelle eines Allpasses 
%  ein sehr breiter Bandpass, der bei   {\fontname{Courier}f = 0}   und bei   {\fontname{Courier}\Omega = 1}   sperrt:
%
fh3 = fullscreen('Frequenzgang'); 
filterplot(b)                         % Amplitudenfrequenzgang des Hilbert-Filters
%
%  Der Entwurf von FIR-Hilbertfiltern wurde schon im Abschnitt 6.4f  behandelt 
%  ( {\fontname{Courier}halbhilb(g)}  und  {\fontname{Courier}remez( ... , 'Hilbert')} ).
%
%  Eine Demonstration der frequenzunabhngigen Drehung von  {\fontname{Courier}90\circ}  bringt  
%  {\fontname{Courier}hilbdemo(g)}  mit  {\fontname{Courier}g} als Filtergrad.  Es wird ein Chirp-Signal erzeugt, 
%  d.h. ein mit einem linear ansteigenden Signal frequenzmodulierter Sinus.  
%  Die Hilberttransformation muss das entsprechende Cosinus-signal liefern.  
%  In der komplexen Ebene, dem sogenannten Signalraum, muss sich also ein 
%  Kreis ergeben.  Es zeigt sich, dass dies nur dann der Fall ist, wenn der
%  Durchlassbereich des Hilbertfilters alle Frequenzen des Chirps auch wirklich 
%  durchlsst.
%  
hilbdemo(30);
%
hilbdemo(14);
%
%  {\fontname{Courier}hilb2demo}  schaltet vier Hilbertfilter hintereinander und zeigt fr ein 
%  rechteckiges Inputsignal die Zwischensignale und das Ausgangssignal, das 
%  natrlich gleich dem Inputsignal sein soll.  Die Verzgerung ist hier fr den 
%  Vergleich eliminiert.  Das Rechteck bentigt einen erheblichen Frequenzbereich.  
%  Die Anforderungen an den Durchlassbereich des Hilberfilters sind deshalb hoch.  
%  Schon beim Filtergrad   {\fontname{Courier}g = 82}  sind die Einbussen deutlich erkennbar 
%  (die Grundfrequenz wird abgeschwcht).
%
hilb2demo(102);
%
hilb2demo(82);
%
%  Die Hilbert-Transformierte des hier benutzten Rechtecks lsst sich berechnen zu:
%
%  (1/\pi) ln(abs((t + T/2)/(t - T/2)))                            %<'FontName',MSVFORMFONT>
%
%  Das menschliche System zur Spracherkennung ist unabhngig von der Phasen-
%  information.  Deshalb kann man per Gehr Realteil und Imaginrteil eines 
%  Audiosignals nicht unterscheiden, obwohl diese im Signalverlauf vllig 
%  verschieden sind.  Fr das folgende Beispiel ist die Audioausgabe des PC 
%  richtig einzustellen.  Zum Test dient hier ein "Kammerton a".
%
%%  Die Einstellung verndern, bis dieser Ton laut, aber unverzerrt zu hren ist.
%
fs= 8000;                       % Abtastrate
t = (1:16000)/fs;               % Zeitbereich 2 Sekunden
sound(0.2*sin(2*pi*440*t),fs);  % Kammerton
%
%%  Fr alle danach folgenden Ausgaben ist das einmalige Laden einer Audiosequenz 
%%  und ihrer Hilbert-Filterung erforderlich:
%
load 'oberseminar.mat';
y = real2analyt(x');
%
%  Ausgabe des Realteils:
%
sound(real(y),fs); pause(3)
%
%  Ausgabe des Imaginrteils:
%
sound(imag(y),fs); pause(3)
%
%  Ausgabe von Real- und Imaginrteil in Stereo:
%
sound([real(y);imag(y)]',fs); pause(3)
%
%  Die Teile sind durchaus verschieden.  Eine Teilsequenz ist in folgendem 
%  Bild dargestellt.
%
ta= 3000; te = 3200;
k = ta:te;
fh4 = fullscreen('KomplexAudio'); 
plot(t(k),[real(y(k));imag(y(k))])
axis([t(ta),t(te),max(abs(y(k)))*[-1 1]])
legend('Realteil','Imaginrteil')
%
komplexanimat(y(k),[1 1],0.2,[90 0])
%
%
%%  Drehen Sie das Bild und toggeln Sie die Sichtbarkeit des zeitkontinuierlichen 
%%  Signals mit der Taste  1  sowie der Abtastpunkte mit der Taste  2  und der 
%%  Abtastradien mit der Taste  3  oder klicken Sie die folgenden Einstellungen:
%
%  Realteil ber der Zeit:
kfig = findobj('Name','Komplexsignal'); 
for k=1:length(kfig) figure(kfig(k)); set(gca,'View',[0 90]); end
%
%  Imaginrteil ber der Zeit:
kfig = findobj('Name','Komplexsignal'); 
for k=1:length(kfig) figure(kfig(k)); set(gca,'View',[0 0]); end
%
%  Komplexe Ebene:
kfig = findobj('Name','Komplexsignal'); 
for k=1:length(kfig) figure(kfig(k)); set(gca,'View',[90 0]); end
%
