%
%
%12.1  Algorithmen  %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Die Generierung von Kosinus/Sinus/Exp-Signalen hat in der Technik ausserordentliche 
% Bedeutung.  Im Fall zeitdiskreter Abtastung an den Zeitpunkten   {\fontname{Courier}t_k}   ist die 
% Kreisfunktion zu berechnen fr die diskreten Winkel   
%
% \alpha_k = \omega t_k                                           %<'FontName',MSVFORMFONT>
%
% Hierin ist   {\fontname{Courier}\omega}  die Winkelgeschwindigkeit der Kreisbewegung.
% 
% Es gilt
%
% \omega = (Winkel/Zeit) = (Winkel/Umdrehung) \times (Umdrehung/Zeit) = 2\pi \cdot f %<'FontName',MSVFORMFONT>
%
% {\fontname{Courier}f}  ist die Frequenz der Kreisbewegung.   
% Die Winkelgeschwindigkeit  {\fontname{Courier}\omega}  wird auch Kreisfrequenz genannt.
%
% Die Abtastzeitpunkte sind meistens quidistant:
%
% t_k = k \cdot \deltat + t_0                                     %<'FontName',MSVFORMFONT>
%
% Gesucht sind dann die Werte der Kreisfunktion fr die Winkel
%
% \alpha_k = \omega(k\cdot\deltat+t_0) = \alpha_0 + k\cdot\beta ;   k \in \bfN   %<'FontName',MSVFORMFONT>
%
% wo   {\fontname{Courier}\alpha_0 = \omegat_0}   und   {\fontname{Courier}\beta = \omega \deltat}
%
% Fr alle  {\fontname{Courier}\alpha_k}  ist also der Reihe nach   {\fontname{Courier}e^{i\alpha_k}}  zu berechnen.
%
% Das ist natrlich trivial, besonders in MATLAB:
%
k     = 1:200;                              % natrliche Zahlen
alpha0= 2*pi*rand;                          % ein beliebiger Anfangswert
beta  = pi*(0.05*rand+rand^4);              % ein zuflliger Winkelschritt
alpha = alpha0 + beta*k;                    % die quidistanten Winkel
z     = exp(i*alpha)'                       % die gesuchten komplexen Werte
komplexanimat(z',[1 1 0 0 0 0],0.5)         % Darstellung
%
%% Wegen der zuflligen Wahl des Winkelschritts sollte man dies mehrfach aufrufen.
%
% Es geht in diesem Kapitel 12 jedoch um die effiziente Realisierung der Kreisfunktion 
% auf Signalprozessoren oder ASICs.  Dabei sind meist hohe Anforderungen an die 
% Genauigkeit und an die Geschwindigkeit zu erfllen.  Wir behandeln in diesem 
% Kapitel zunchst die grundstzlichen Algorithmen.  Man unterscheidet dabei zwei 
% verschiedene Prinzipien:  Die digitalen Oszillatoren, die wie analoge Oszillatoren 
% durch Rckkopplung der Signalwerte schwingen, und andererseits die Berechnung der 
% Kreisfunktion fr durch Rekursion ermittelte quidistante Winkel.  
% Dieser Abschnitt 12.1 enthlt neben der Diskussion dieser beiden Verfahren zwei 
% Unterabschnitte zur Frequenzsynthese aus mehreren Schwingungen und zur 
% Synchronisation von Oszillatoren:
%
%
%
%
%
dsp_12_1_1 %MSV 12.1.1   Digitale Oszillatoren
%
%
dsp_12_1_2 %MSV 12.1.2   Berechnung der Kreisfunktion fr quidistante Winkel
%
%
dsp_12_1_3 %MSV 12.1.3   Frequenzsynthese
%
%
dsp_12_1_4 %MSV 12.1.4   Phasenregelung
%
%