%
%
%
%
%12.1.1  Digitale Oszillatoren  %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-10,'Color',MSVTITLCOLOR>
%
%
%
% Zu berechnen ist der Reihe nach fr  {\fontname{Courier}k = 0, 1, 2, ...}
%
% {\fontname{Courier}z_k  =  e^{i\omega(k\deltat + t_0)}}
%
% Hieraus folgt die Rekursion
%
% {\fontname{Courier}z_{k+1}  =  e^{i\omega((k+1)\deltat + t_0)}  =  e^{i\omega(k\deltat + t_0)} \cdot e^{i\omega\deltat}  =  z_k \cdot p}
%
% wo       {\fontname{Courier}p = e^{i\omega\deltat}}      und      {\fontname{Courier}z_0 = e^{i\omegat_0}}
%
% Die Berechnung erfordert also nur eine einzige Komplex-Multiplikation fr jeden 
% Abtastpunkt.
%
% In jeder Programmiersprache ist das ein Einzeiler.
%
% Z.B. in MATLAB:
%
fa     = 8000;                         % Abtastfrequenz [Hz]
f      = 440;                          % Kammerton a    [Hz]
omega  = 2*pi*f;                       % die zugehrige Winkelgeschwindigkeit
deltat = 1/fa;                         % Abstand der Abtastpunkte
p      = exp(i*omega*deltat);          % Faktor
z      = [1 cumprod(p*ones(1,16383))]; % akkumulierte Faktoren
         % dies ist viel schneller als  for k=2:16384  p*z(k) = z(k-1); end
   
soundsc(real(z),fa)                    % Audioausgabe
   
komplexanimat(z(1:200))                % animierte graphische Darstellung
%
%
% Eine weitere Mglichkeit direkter Rekursion ergibt sich aus der bekannten 
% Beziehung
%
% 2cos(\alpha)cos(\beta) = cos(\alpha+\beta) + cos(\alpha-\beta)   %<'FontName',MSVFORMFONT>
%
% durch Umformung:
%
% cos(\alpha+\beta) = 2cos(\alpha)cos(\beta) - cos(\alpha-\beta)   %<'FontName',MSVFORMFONT>
%
% Setzt man nun
%
% \alpha_k = \alpha_{k-1} + \beta                                  %<'FontName',MSVFORMFONT>
%
% so folgt die Rekursive Beziehung
%
% z_k = cz_{k-1} - z_{k-2}                                         %<'FontName',MSVFORMFONT>
%
% wo   {\fontname{Courier}c = 2cos(\beta)}   und   {\fontname{Courier}z_0 = 1;   z_1 = cos(\beta)}
%
% Z.B. in MATLAB:
%
fa     = 8000;                         % Abtastfrequenz [Hz]
f      = 440;                          % Kammerton a    [Hz]
omega  = 2*pi*f;                       % die zugehrige Winkelgeschwindigkeit
deltat = 1/fa;                         % Abstand der Abtastpunkte
c      = 2*cos(omega*deltat);          % Faktor
z(1)   = 1;                            % Anfangswert
z(2)   = c/2;                          % Anfangswert

for k = 3:16384  z(k) = c*z(k-1) - z(k-2); end  % der Algorithmus

fh = fullscreen('Oszillator','w',2,[2 1; 1 1]);  axes('Position',[0.0 0.1 1.1 0.8])
plot(z);  axis off                     % graphische Darstellung

soundsc(real(z),fa)                    % Audioausgabe
%
%% Nutzen Sie die Zoom-Funktion der Menleiste zur Darstellung des Signals.
%
% Es wird sich im Abschnitt 12.2.3 zeigen, dass die Digitalen Oszillatoren 
% Schwchen in der Genauigkeit haben.
%