%
%
%
%
%12.3.2  Digitaler Oszillator   %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
% Das Problem der digitalen Oszillatoren liegt in ihrer Instabilitt.  
% Ein einfaches Beispiel zeigt dies deutlich:
%
z = recdds(0.275,6);                              % Reprsentation mit 6 Bit 
komplexanimat(z(1:500),[1 1 0 0 0 0],1,[90 0]);
%
%
% Vier Fehler sind hier sichtbar:
%
% (1)  Die Amplitude nimmt ab bis zu einem Fixpunkt
%
% (2)  Die erzeugte Frequenz weicht erheblich von der Wunschfrequenz ab
%
% (3)  Das Spektrum ist verbreitert
%
% (4)  Es gibt Nebenwellen
%
%
% Die Verbreiterung liegt an der Abnahme der Amplitude und am Verfahren der 
% Spektralberechnung. Mit einem Kaiser-Fenster ist dieser Effekt behoben, 
% weil dann praktisch nur der Bereich im Fixpunkt noch relevant ist:
%
z = recdds(0.275,6,6,3);                          %  6 Bit,   Kaiser-Fenster 
komplexanimat(z(1:150),[1 1 0 0 0 0],1,[90 0]);
%
% Das erzeugte Signal hngt wesentlich von der Anfangsphase ab.  Insbesondere 
% ist die Kohrenz zweier so erzeugter Signale mit der selben Frequenz nicht 
% fr beliebig lange Sequenzen gewhrleistet. Wir zeigen dies drastisch mit 
% folgendem Beispiel fr die Quantisierung mit nur 6 Bit.  Berechnet werden 
% zwei Signale der selben Frequenz, aber unterschiedlicher Anfangsphase. 
% Die Signale werden wie auf einem Oszilloskop im X-Y-Modus dargestellt. 
% Es muss sich eine Ellipse ergeben, die wegen der Zeitdiskretisierung 
% verbreitert und wegen der Quantisierung auch als Strichmuster erscheint.
% Als erstes Bild wird der korrekte Fall der klassischen DDS gezeigt, als 
% zweites das nicht einmal ber die relativ kurze berechnete Sequenz 
% kohrente Signal des digitalen Oszillators.
%
f  = 0.428;                         % Frequenz
pt = 6;                             % Wortbreite fr die Arithmetik
po = 6;                             % Wortbreite fr die Ausgabe
y1 = ddssim(f,16,6,pt,po,0,0,3,0.107);
y2 = ddssim(f,16,6,pt,po,0,0,3,2.217);
fh1 = fullscreen('Phasendiagramm');
plot(y1(2,:),y2(2,:))               % Phasendiagramm
title('Phasendiagramm fr klassische DDS mit linearer Interpolation','FontSize',13)
axis square;  axis off
z1 = rec2dds(f,pt,po,3,0.107);
z2 = rec2dds(f,pt,po,3,2.217);
for k=1:4 delete(gcf); end          % berflssige Bilder fortwerfen
fh2 = fullscreen('Phasendiagramm');
plot(z1,z2)                         % Phasendiagramm
title('Phasendiagramm fr Digitalen Oszillator','FontSize',13)
axis square;  axis off
%
% Unsinnige Bilder geben folgende Kommandos:
%
h = fullscreen('');  plot(y1,y2);    axis off
%
h = fullscreen('');  plot(y1',y2');  axis off
%
h = fullscreen('');  plot([y1;y2]);  axis off
%
% Die direkte Rekursion ist bei blichen Wortbreiten bis zu  {\fontname{Courier}n = 32}  Bit unbrauchbar. 
% Es stellt sich aber die Frage, ob es eine akzeptable Wortbreite gibt, bei der 
% diese Methode brauchbar wird.
%
% Annahmen:  
% Die Amplitude von   {\fontname{Courier}p}   sei   {\fontname{Courier}a = 1 - \epsilon} .
% Die Abtastrate sei   {\fontname{Courier}r}
%
% Dann ist die Amplitude   {\fontname{Courier}A(t)}   des Ausgangssignals zur Zeit  {\fontname{Courier}t}  gegeben durch 
%
% A(t) = a^{rt} = (1 - \epsilon)^{rt} \approx 1 - rt\epsilon    %<'FontName',MSVFORMFONT>
%
% Der Amplitudenfehler ist damit
%
% \deltaA(t) \approx rt\epsilon           %<'FontName',MSVFORMFONT>
%        
% Wir setzen  {\fontname{Courier}\epsilon = 2^{1-n}} .  Das entspricht dem Wert des LSB von a. 
%
%
% Damit hat man
%
% \deltaA(t) \approx rt2^{1-n}            %<'FontName',MSVFORMFONT>
%
% Nach n aufgelst ergibt sich
%
% n = 1 - log_2(\deltaA(t) / rt)          %<'FontName',MSVFORMFONT>
%
%
% In MATLAB z.B.  
%
dA = 10^-6;                    % zulssiger Maximalfehler nach Ablauf von t
r  = 10^8;                     % Abtastrate in Hz                  
t  = 3600*24;                  % Betriebszeit in s  (hier ein Tag)
n  = ceil(1-log2(dA/(r*t)))    % Anzahl der erforderlichen Bits
%
%% Das Resultat erscheint im Kommandofenster
%
% Audioanwendung:
%
dA = 2^-16;                    % zulssiger Maximalfehler nach Ablauf von t
r  = 44100;                    % Abtastrate in Hz                  
t  = 3600*8;                   % Betriebszeit in s  (hier 8 Stunden)
n  = ceil(1-log2(dA/(r*t)))    % Anzahl der erforderlichen Bits
%