%
%
%15.1  Berechnung der Filterkoeffizienten aus dem Signalspektrum%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-23,'Color',MSVTITLCOLOR>
%
%
%
% Adaptive Filter sind Filter, bei denen die Koeffizienten fortlaufend aus dem 
% zu filternden Signal neu berechnet werden.  Basis fr diese Berechnung kann 
% unmittelbar das Signal im Zeitbereich sein oder seine Fouriertransformierte 
% bzw. das Spektrum. 
%
% In diesem Abschnitt werden einige Beispiele behandelt fr die Ermittlung der 
% Filterkoeffizienten aus dem Signalspektrum.
%
%
% \bfBeispiel 1
% 
% In einem Signal sollen die strksten Frequenzkomponenten hervorgehoben werden. 
% Anstatt dies hnlich wie im Abschnitt 14.3 im Frequenzbereich zu tun, soll das 
% Amplitudenspektrum des Eingangssignals als Amplitudenfrequenzgang eines FIR-
% Filters genommen werden.  Dieses Filter lsst offensichtlich die strkste 
% Komponente gut durch.  Alles andere wird dem Spektrum entsprechend abgeschwcht:
%
n = 16384;  fs = 8000;                     % Abtastrate
x = cos(2*pi*660/fs*(0:n-1)) + 0.7*cos(2*pi*880/fs*(0:n-1)) + 0.2*randn(1,n);
x = x/max(abs(x));                         % Normierung
s = abs(fft(x));                           % Spektrum
y = real(ifft(s));                         % Filterentwurf
b = [y(100:-1:2), y(1:100)].*hamming(199)';% Filterkoeffizienten
b = b/sum(abs(b));                         % Normierung
z = filter(b,1,x);                         % Resultat
z = z/max(abs(z));                         % Normierung
fh1 = fullscreen('Frequenzgang','w',0,[3 1; 1 1]);   
filterplot(b,0,1,0,-50,0)
fh2 = fullscreen('Spektrum','w',0,[3 1; 2 1]);       
plot(s(1:n/2)); set(gca,'XLim',[0,n/2-1]);
fh3 = fullscreen('Koeffizienten','w',0,[3 1; 3 1]);  
stem(b)
sound(x,fs); pause(2)                      % Originalsignal
sound(z,fs); pause(2)                      % gefiltertes Signal
%
% Dieses Beispiel zeigt, dass das Verfahren prinzipiell funktioniert. 
%
%
% \bfBeispiel 2
% 
% Bei der Berechnung der Filterkoeffizienten muss natrlich nicht direkt das 
% Spektrum verwendet werden.  Ebenso ist eine Schwellwertoperation mglich. 
% Hier eine feste Schwelle:
%
n = 16384;  fs = 8000;                     % Abtastrate
x = cos(2*pi*660/fs*(0:n-1)) + 0.7*cos(2*pi*880/fs*(0:n-1)) + 0.2*randn(1,n);
x = x/max(abs(x));                         % Normierung
s = abs(fft(x));                           % Spektrum
y = real(ifft(s>2000));                    % Filterentwurf mit Schwelle
b = [y(100:-1:2), y(1:100)].*hamming(199)';% Filterkoeffizienten
b = b/sum(abs(b));                         % Normierung
z = filter(b,1,x);                         % Resultat
z = z/max(abs(z));                         % Normierung
fh1 = fullscreen('Frequenzgang','w',0,[3 1; 1 1]);   
filterplot(b,0,1,0,-50,0)
fh2 = fullscreen('Spektrum','w',0,[3 1; 2 1]);       
plot(s(1:n/2)); set(gca,'XLim',[0,n/2-1]);
fh3 = fullscreen('Koeffizienten','w',0,[3 1; 3 1]);  
stem(b)
sound(x,fs); pause(2)                      % Originalsignal
sound(z,fs); pause(2)                      % gefiltertes Signal
%
%
% \bfBeispiel 3
% 
% Auch bei Sprachsignalen ist die Methode verwendbar.  Im folgenden Beispiel wird 
% eine frequenzabhngige, aber statische Schwelle benutzt.  berdies wird die 
% Bassanhebung des Verfahrens durch ein Klangfarbenfilter wieder rckgngig gemacht:
%
load audiotest                             % Testsignal laden
n = length(x); if mod(n,2)  x = [0,x]; n = n + 1; end
x = x + 0.01*randn(size(x));               % Rauschen hinzufgen
s = abs(fft(x));                           % Spektrum
y = real(ifft(s>0.6*n./[n/2:-1:1,1:n/2])); % Filterentwurf
g = 200;                                   % Filtergrad
b = [y(g/2+1:-1:2), y(1:g/2+1)].*hamming(g+1)';% Filterkoeffizienten
b = b/sum(abs(b));                         % Normierung
z = filter(b,1,x);                         % Resultat
z = z/max(abs(z));                         % Normierung
r  = 0.7;                                  % Klangfarbe
bk = 0.5*(1+r)*[0 0 1 0 0] - r*fir1(4,0.2);% Klang-Filterentwurf
bk = bk/sum(bk);                           % Normierung
u = filter(bk,1,z);                        % Filtern
fh1 = fullscreen('Frequenzgang','w',0,[3 1; 1 1]); 
filterplot({b;bk},0,1,0,-50,0,1,24,1)
fh2 = fullscreen('Spektrum','w',0,[3 1; 2 1]);       
plot(s); set(gca,'XLim',[0 n/2])
fh3 = fullscreen('Koeffizienten','w',0,[3 1; 3 1]);  
stem(b); set(gca,'XLim',[0 g+2])
sound(x/max(abs(x)),fs); pause(2)          % Originalsignal
sound(u/max(abs(u)),fs); pause(2)          % gefiltertes Signal
%
% Die hrbare Rauschunterdrckung wird im wesentlichen durch die automatische 
% Beschrnkung auf den Bandpassbereich  {\fontname{Courier}100 ... 2500 Hz}  erreicht.
%
% Die hier aufgefhrten Beispiele sind zwar adaptiv insofern als sie die 
% Filterkoeffizienten aus dem Signalspektrum errechnen.  Dies geschieht bei 
% diesen kurzen Demonstrationen jedoch jeweils nur einmal und nicht fortlaufend 
% neu.  Um letzteres zu realisieren, mssen die Filterkoeffizienten in jedem 
% Abtastschritt neu bestimmt werden. Das ist via FFT zu aufwendig. 
%