%
%
%  4.3  Fouriertransformation Zeit-diskreter Funktionen%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-19,'Color',MSVTITLCOLOR>
%
%
%
%  Im zu untersuchenden Fall liegen Zeit-diskrete Signale vor. Diese haben ein 
%  periodisches Spektrum.
%
%  Die MATLAB-Funktion  {\fontname{Courier}diskretfourier}   berechnet eine Periode des Spektrums 
%  fr ein als Vektor gegebenes endliches diskretes Signal.  Das Spektrum wird hier 
%  numerisch berechnet, es liegt deshalb als Vektor von Sttzstellen vor (401 Punkte).
%
%  Zwei Beispiele:
%
t = (-100:99)/200;
x = (sin(2*pi*20*t)+0.4*sin(2*pi*33*t)).*exp(-30*t.^2);
S = diskretfourier(x);
%
t = (-100:99)/200;
x = (sin(2*pi*10*t)+0.4*sin(2*pi*33*t)+0.6*sin(2*pi*41*t)).*exp(-30*t.^2);
diskretfourier(x);
%
%  Die Umkehrung erfolgt durch  {\fontname{Courier}diskretifourier} .  Wir transformieren das 
%  oben in  {\fontname{Courier}S}  gespeicherte Spektrum zurck in ein diskretes Zeitsignal:
%
diskretifourier(S);
%
%
%  Wird ein zeitkontinuierliches Signal abgetastet, so wird offenbar aus seiner 
%  Fouriertransformierten eine periodische Funktion.  Die Periode ist gleich der 
%  Abtastfrequenz  {\fontname{Courier}f_s} .  Hufig wird die Frequenz innerhalb der Periode 
%  relativ zu  {\fontname{Courier}f_s}  angegeben  {\fontname{Courier}(0..1)}  oder auch zur Nyquistfrequenz  {\fontname{Courier}(0..2)}  
%  oder auch  {\fontname{Courier}(0..2\pi)} .  Im letzteren Fall heisst das Argument  {\fontname{Courier}\Omega = \omega/f_s} .
%
%  Den Zusammenhang zwischen den Fouriertransformierten des kontinuierlichen 
%  und des abgetasteten Signals demonstriert die MATLAB-Funktion  {\fontname{Courier}abtastung} :
%
%
%  Gausspuls mit Sinus  {\fontname{Courier}f = 2.3 ;  f_s = 7.71}
%
abtastdemo('exp(-t.^2).*(sin(2*pi*2.3*t))',7.71,[-2,2],[-20,20]);
%
%  Wie vor jedoch zwei Sinus:  {\fontname{Courier}f_1 = 2.3 ; f_2 = 1.1 ;  f_s = 7.71}
%
abtastdemo('exp(-t.^2).*(sin(2*pi*2.3*t)+0.8*sin(2*pi*1.1*t))',7.71,[-2,2],[-20,20]);
%
%  Wie vor jedoch zustzlich Sinus  {\fontname{Courier}f_3 = 5.1 > Nyquistfrequenz}
%
abtastdemo('exp(-t.^2).*(sin(2*pi*2.3*t)+0.8*sin(2*pi*1.1*t)-0.6*sin(2*pi*5.1*t))',7.71,[-2,2],[-20,20]);
%
%  Wie vor jedoch  {\fontname{Courier}f_s = 12} ,  so dass  {\fontname{Courier}f_1,f_2,f_3 < Nyquistfrequenz}
%
abtastdemo('exp(-t.^2).*(sin(2*pi*2.3*t)+0.8*sin(2*pi*1.1*t)-0.6*sin(2*pi*5.1*t))',12,[-2,2],[-20,20]);
%
%  Wie vor jedoch  {\fontname{Courier}f_s = 15} ,  so dass  {\fontname{Courier}f_1, f_2, f_3 << Nyquistfrequenz}
%
abtastdemo('exp(-t.^2).*(sin(2*pi*2.3*t)+0.8*sin(2*pi*1.1*t)-0.6*sin(2*pi*5.1*t))',15,[-2,2],[-20,20]);
%
%  {\fontname{Courier}f_s} viel zu klein !
%
abtastdemo('exp(-t.^2).*(sin(2*pi*2.3*t)+0.8*sin(2*pi*1.1*t)-0.6*sin(2*pi*12.1*t))',1.4,[-2,2],[-20,20]);
%
%  Niedrigabtastung bei bandbegrenztem Signal: im Prinzip rekonstruierbar.
%
abtastdemo('exp(-t.^2).*(sin(2*pi*13*t)+0.8*sin(2*pi*11.5*t)-0.6*sin(2*pi*13.5*t))',10,[-2,2],[-20,20]);
%
%
%%  bung 4.3a:  Rufen Sie  {\fontname{Courier}abtastdemo}  auf mit der Abtastrate  {\fontname{Courier}f_s = 20} 
%%  und den beiden Signalen
%%
%%  sin(2\pi5t) \cdot sin(2\pi4t)
%%
%%  sin(2\pi5t) \cdot sin(2\pi6t)
%%
%%  Warum sind die Spektren der beiden abgetasteten Signale identisch?
%%
%%  bung 4.3b:  Analysieren Sie die Berechnung der Fouriertransformierten innerhalb der 
%%  Funktion  {\fontname{Courier}diskretfourier}.
%