%
%
%  5.2  Die schnelle Fouriertransformation (FFT)%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-16,'Color',MSVTITLCOLOR>
%
%
%
%  Die schnelle Fouriertransformation ist ein optimiertes Verfahren zur Berechnung 
%  der diskreten Fouriertransformation.  Es ist besonders effizient, wenn die 
%  Primfaktorenzerlegung der Anzahl der Abtastungen in der Zeitperiode mglichst 
%  viele Zweien enthlt.  Zweierpotenzen wie  {\fontname{Courier}64, 128}  etc. sind also optimal. 
%  Das Verfahren ist in vielen Bchern ausfhrlich behandelt.  In MATLAB ist es 
%  realisiert in der Funktion  {\fontname{Courier}fft}  und die inverse FFT in  {\fontname{Courier}ifft} :
%
help fft
%
%  Das folgende Beispiel zeigt die FFT eines Signals mit drei Sinuskomponenten:
%
%  s(t) = a_1cos(2\pif_1t) + a_2sin(2\pif_2t) + a_3sin(2\pif_3t + 0.5) %<'FontName',MSVFORMFONT>
%
%  Der erste Term ist eine gerade Funktion.  Er liefert eine relle Komponente im 
%  Ausgabevektor der FFT.  Der zweite Term ist eine ungerade Funktion.  Er liefert 
%  eine rein imaginre Komponente im Ausgabevektor der FFT.  Der dritte Term ist 
%  weder ungerade noch gerade.  Er liefert eine komplexe Komponente im Ausgabevektor 
%  der FFT:  
%
n  = 256;                    % Anzahl der Abtastpunkte 
t  = (0:n-1)/n;              % Zeitbereich 0...1 in n Punkten 
f1 = 20; f2 = 30;  f3 = 70;  % drei Frequenzen
a1 = 1;  a2 = 0.5; a3 = 0.4; % drei Amplituden
s  = a1*cos(2*pi*f1*t) + a2*sin(2*pi*f2*t) + a3*sin(2*pi*f3*t+0.5);
S  = fft(s);                 % FFT von s 
fh = fullscreen('FFT');      % Fenster
tx = 0.87*n/2; ty = n/32;    % Textposition
l = 0.02; b = 0.96; h = 0.3; u1 = 0.67; u2 = 0.35; u3 = 0.03;
axes('Position',[l u1 b h]);
p1 = stem(real(S),'filled'); set(p1,'Color','g','Marker','.')
axis([0 n 0 n/2]); axis off
text(tx,ty,'Realteil der FFT','FontSize',12,'Color','g')
axes('Position',[l u2 b h]); 
p2 = stem(imag(S),'filled'); set(p2,'Color','r','Marker','.') 
axis([0 n -n/4 n/4]); axis off
text(tx,ty,'Imaginrteil der FFT','FontSize',12,'Color','r')
axes('Position',[l u3 b h]); axis([0 n 0 n/2]); axis off
p3 = stem( abs(S),'filled'); set(p3,'Color','b','Marker','.') 
axis([0 n 0 n/2]); axis off
text(tx,ty,'Absolutwert der FFT','FontSize',12,'Color','b')
%
%  In diesem Beispiel sind die Sinus-Frequenzen so gewhlt, dass die Perioden 
%  von  {\fontname{Courier}N}  Abtastpunkten nahtlos aneinander passen.
%
%  Ein Beispiel fr die iFFT gibt das folgende MATLAB-Script.  Zunchst wird 
%  ein Signal im Zeitbereich generiert und dieses mit der FFT transformiert. 
%  Anschliessend erfolgt die Rcktransformation mit ifft:
%
n = 128;                   % Anzahl der Abtastpunkte
t = 0:n-1;                 % n Abtastzeitpunte der Periode
s = sin(2*pi*0.15*t).*exp(-0.005*(t-50).^2); % ein Signal
S = fft(s);                % FFT berechnen
r = ifft(S);               % inverse FFT
fonts= 12;                 % FontSize      
figh = fullscreen('FFT/iFFT'); % Bildfenster kreieren
subplot(3,1,1);            % dreiteiligen Plot festlegen
p1 = stem(s); set(p1,'Color','b','Marker','.')
title('abgetastetes Signal','FontSize',fonts)
axis([0 n -1 +1])          % Achsenbereich
subplot(3,1,2);            % mittleres Teilbild
p2 = stem(real(S)); set(p2,'Color','g','Marker','.'); hold on
p3 = stem(imag(S)); set(p3,'Color','r','Marker','.')
title('Fouriertransformierte','FontSize',fonts)
axis([0 n -30 +30])        % Achsenbereich
hold off
subplot(3,1,3);            % unteres Teilbild
p4 = stem(real(r)); set(p4,'Color','b','Marker','.')
title('rcktransformiertes Signal','FontSize',fonts)
axis([0 n -1 +1])          % Achsenbereich
%
%%  bung 5.2a:  Selektieren Sie das obenstehende MATLAB-Script durch Anklicken 
%%  (roter Balken muss links erscheinen).  Tippen Sie nun die Taste "c", um 
%%  dieses Script ins Editorfenster zu kopieren. ndern Sie dort das Signal in
%  s = randn(size(t));   %<'FontName',MSVFORMFONT>
%%
%%  Nun ist dieses Script mit "cut and paste" ins Kommandofenster 
%%  zu bertragen und dort zu starten.
%%  Wie sieht die Fouriertransformierte einer Sequenz von 
%%  normalverteilten Zufallszahlen aus?
%%  Nutzen Sie die Skalierungsmglichkeit (tippen Sie "h").
%
%%  bung 5.2b:  Generieren Sie gefrbte Zufallszahlen durch Vorgabe der 
%%  Fouriertransformierten als
%  S = [zeros(1,n1-1),randn(1,n2-n1+1)+i*randn(1,n2-n1+1),zeros(1,n-n2-1)]; %<'FontName',MSVFORMFONT>
%%
%%  Hierin sind  n1  und  n2  mit  0 < n1 < n2 < N  die Grenzen des Spektralbereiches 
%%  fr das Rauschen relativ zu  N  als Abtastfrequenz.  Die tatschlichen 
%%  Eckfrequenzen sind also  n1*fs/N  bzw.  n2*fs/N, wo  fs  die tatschliche 
%%  Abtastfrequenz bedeutet.
%%
%%  Nehmen Sie folgende Kombinationen:
%   N    n1    n2         %<'FontName',MSVFORMFONT>
%  128    1    20         %<'FontName',MSVFORMFONT>
%  128    1     5         %<'FontName',MSVFORMFONT>
%  128   10    13         %<'FontName',MSVFORMFONT>
%  128   40    46         %<'FontName',MSVFORMFONT>
%  128   42    44         %<'FontName',MSVFORMFONT>
%%
%%  Wie macht sich die Eingrenzung des Spektrums im Zeitbereich bemerkbar?
%%  Was passiert im Zeitbereich, wenn die Bandbreite verringert wird?
%%  Warum scheint das Signal in den beiden letzten Fllen aus drei Komponenten 
%%  zu bestehen?
%