%
%
%  5.3  Fensterung%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Das Verbreitern von Komponenten des diskreten Spektrums liegt daran, dass ein 
%  Signal durch Abtastung erfasst wird und dieses zur Berechnung der diskreten 
%  Fouriertransformation knstlich als periodisch erklrt wird mit einer durch die 
%  abgetastete Sequenz gegebenen Periode.  Anfang und Ende der Sequenz passen im 
%  allgemeinen nicht zusammen.  Genau das kann man aber knstlich erzwingen durch 
%  die sogenannte Fensterung:  Man multipliziert die Sequenz Punkt fr Punkt mit 
%  einer diskreten Fensterfunktion  {\fontname{Courier}W_k} , die an den Enden der Sequenz gegen 
%  Null geht.  Drei hufig benutzte Fenster werden nach demselben Schema erzeugt:
%
%  W_k = A - B cos(2\pik/N) + C cos(4\pik/N) ;    1 \leq k \leq N     %<'FontName',MSVFORMFONT>
%
%  Die Konstanten haben folgende Werte:
%                                 A     B     C        %<'FontName',MSVFORMFONT>
%         Hanning-Fenster :      0.5   0.5    0        %<'FontName',MSVFORMFONT>
%         Hamming-Fenster :      0.54  0.46   0        %<'FontName',MSVFORMFONT>
%         Blackman-Fenster:      0.42  0.5    0.08     %<'FontName',MSVFORMFONT>
%
%  Die folgende Funktion zeigt im ersten Bild diese Fenster und zustzlich das 
%  Kaiser-Fenster, welches mit zwei Parametern variiert werden kann.  Letzteres 
%  zeigt das zweite Fenster:
%
windemo
%
%  Die Fenster sind wegen ihrer Wichtigkeit als Standard-Funktionen in MATLAB 
%  verfgbar.
%
%  Wegen der periodischen Fortsetzung im Zeitbereich kommt die Fensterung einer 
%  Amplitudenmodulation gleich.  Zeitkontinuierlich lsst sich die Wirkung auf 
%  ein Cosinus-Signal elementar berechnen:
%  (A - B cos(Wt)) cos(\omegat) = A cos(\omegat) - B cos(Wt) cos(\omegat) %<'FontName',MSVFORMFONT>
%     = A cos(\omegat) - 0.5 B cos((\omega + W)t) - 0.5 B cos((\omega - W)t) %<'FontName',MSVFORMFONT>
%
%  Neben dem Dirac-Puls fr die eigentliche Cosinus-Schwingung an der Stelle  {\fontname{Courier}\omega}  
%  werden zwei Dirac-Pulse bei  {\fontname{Courier}\omega + W}  und  {\fontname{Courier}\omega - W}  erscheinen.  Ihr Abstand  {\fontname{Courier}W}  
%  zu  {\fontname{Courier}\omega}  ist genau ein Schritt der Diskretisierung des Frequenzbereiches, denn  {\fontname{Courier}2\pi/W}  
%  ist die Zeitperiode, und damit  {\fontname{Courier}W/2\pi}  die Schrittweite im Frequenzbereich bzw.  {\fontname{Courier}W}  
%  fr Kreisfrequenzen.
%  
%  Wird ein Signal gefenstert, welches sich ohnehin periodisch richtig fortsetzt, 
%  so bringt die Fensterung also nur eine Verschlechterung.  Das richtige Fortsetzen 
%  betrifft aber immer nur ganz wenige Stellen im Spektrum.  An allen anderen Stellen 
%  tritt eine Verbesserung ein, so dass praktisch alle Stellen des Spektrums 
%  gleichmssig aufgelst werden.
%
%  Zunchtst ein Beispiel fr perfekte Fortsetzung ohne Fensterung:
%
winzeitfreq('sin(2*pi*6.0*t)+0.1*sin(2*pi*10.0.*t)',40,2)
%
%  Dasselbe mit Kaiserfenster:
%
winzeitfreq('sin(2*pi*6.0*t)+0.1*sin(2*pi*10.0.*t)',40,2,60)
%
%  Nun ein Signal mit passendem und nicht-passendem Sinus:
%
winzeitfreq('0.01*sin(2*pi*6.00*t)+sin(2*pi*10.05.*t)',40,2)
%
%  Dasselbe mit Kaiserfenster:
%
winzeitfreq('0.01*sin(2*pi*6.00*t)+sin(2*pi*10.05.*t)',40,2,80)
%
%  Offensichtlich muss man bei der Wahl des Fensters einen Kompromiss eingehen 
%  zwischen Verbreiterung der Spektrallinien und Tiefe der Unterdrckung des durch 
%  die Periodizidierung erzeugten Untergrundes.  Das Kaiserfenster erlaubt die 
%  Einstellung mit einem Parameter, der in winzeitfreq als letzter optionaler 
%  Parameter die Unterdrckung des Untergrundes in  {\fontname{Courier}dB}  angibt.  Die anderen 
%  Fenster sind Alternativen ohne Parameter.
%
%  Ein Beispiel fr starke Verbreiterung des Spektrums wegen zu harter Forderung 
%  nach Unterdrckung der Artefakte {\fontname{Courier}(120 bB)} :
%
winzeitfreq('0.01*sin(2*pi*6.00*t)+sin(2*pi*10.05.*t)',40,2,120)
%
%
%%  bung 5.3a:  In der Funktion winzeitfreq kann das gewnschte Fenster explizit 
%%  angegeben werden:
%%
help winzeitfreq
%%
%%  Betrachten Sie das Signal  
%  cos(2\pi7.5t) + sin(2\pi30t)       %<'FontName',MSVFORMFONT>
%%
%%  mit allen Fenstern:
%  win = 'bartlett', 'blackman', boxcar', 'hamming', 'hanning', 'kaiser', 'triang'  %<'FontName',MSVFORMFONT>
%%
%%  Vergleichen Sie Hanning / Hamming und Blackman / Chebwin / Kaiser:
%%
winzeitfreq('cos(2*pi*7.5*t)+sin(2*pi*30*t)',100,1,'boxcar',[-150,50])
%
%
%%  bung 5.3b:  Untersuchen Sie die mit dem selben Funktionsaufruf die 
%%  Artefaktunterdrckung in dB beim Kaiserfenster.  Setzen Sie dazu den 
%%  Parameter  win  von  winzeitfreq  wie folgt: 
%  win = 20,  25,  30,  40,  60,  80,  100,  200,  500. %<'FontName',MSVFORMFONT>
%%
%%  In welchen Bereich ist der Einsatz des Fensters gnstig?
%%
%%  bung 5.3c:  Ist das Fenstern von weissen Rauschen sinnvoll?
%%  Stellen Sie weisses Rauschen mit  winzeitfreq  dar.
%