%
%
%  6.1  Filter%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Unter einem Filter verstehen wir ein System, welches eingehende Signale  {\fontname{Courier}x}  
%  in ausgehende Signale  {\fontname{Courier}y}  wandelt unter folgenden Einschrnkungen:
%
%  (a)  Die Verarbeitung ist linear.  Dies bedeutet:
%        Ist  {\fontname{Courier}y_1}  die Antwort auf das Signal  {\fontname{Courier}x_1}  und
%        {\fontname{Courier}y_2}  die Antwort auf das Signal  {\fontname{Courier}x_2} ,  so ist die 
%        Antwort auf das Signal  {\fontname{Courier}ax_1 + bx_2}  gegeben 
%        durch  {\fontname{Courier}ay_1 + by_2}.
%
%  (b)  Die Verarbeitung ist zeitinvariant.  Dies bedeutet:
%        Ist  {\fontname{Courier}y(t)}  die Antwort auf das Signal  {\fontname{Courier}x(t)} , so ist 
%        die Antwort auf das um  {\fontname{Courier}t_0}  in der Zeit verschobene 
%        Signal  {\fontname{Courier}x(t-t_0)}  gegeben durch  {\fontname{Courier}y(t-t_0)}  fr alle {\fontname{Courier}t_0}.
%
%  Aus (a) folgt, dass sich das Systemverhalten fr zeitdiskrete Signale und endliche 
%  Zeitfenster durch eine Matrix  {\fontname{Courier}H}  beschreiben lsst:
%  y = Hx                    %<'FontName',MSVFORMFONT>
%
%  Aus (b) folgt, dass die Zeilen dieser Matrix  {\fontname{Courier}H}  alle gleich sind bis auf eine 
%  Verschiebung nach rechts um die Zeilennummer.  Es ist also eine Toeplitz-Matrix. 
%  {\fontname{Courier}Hx}  ist damit die diskrete Faltung der Vektoren  {\fontname{Courier}h}  und  {\fontname{Courier}x} , wo  {\fontname{Courier}h}  eine Spalte von  {\fontname{Courier}H}  ist. 
%  Diese ist gleich einer von rechts nach links gelesenen Zeile:
%       n-1                                          %<'FontName',MSVFORMFONT>
%  y_i = _{\fontsize{26}\Sigma} h_k x_{i-k}          %<'FontName',MSVFORMFONT>
%       k=0                                          %<'FontName',MSVFORMFONT>
%
%  Die einfache Betrachtung ist dann sinnvoll, wenn nur ein  {\fontname{Courier}n}  Stellen breites 
%  Band der Matrix  {\fontname{Courier}H}  von Null verschieden ist.  Das hergeleitete Filter heisst 
%  Finite Impulse Response Filter, kurz FIR-Filter.  Die Bezeichnung beruht auf der 
%  Tatsache, dass fr einen Eingangspuls  {\fontname{Courier}x = [0 ... 0 0 0 1 0 0 0 ... 0]} 
%  die Impulsantwort  {\fontname{Courier}y}  gleich  {\fontname{Courier}h}  ist:
%  y_{i+j} = h_i                                     %<'FontName',MSVFORMFONT>
%
%  {\fontname{Courier}j}  gibt die zeitliche Verschiebung an.
%
%  Im folgenden Matlab-Script wird zunchst ein Signal  {\fontname{Courier}x}  aus  {\fontname{Courier}100}  Zufallszahlen 
%  erzeugt sowie ein einfaches Filter mit der Impulantwort  {\fontname{Courier}h} , die nur  {\fontname{Courier}9} Abtastungen 
%  lang ist.  Anschliessend wird das Filter auf vier Wegen auf das Signal  {\fontname{Courier}x}  angewendet:
%  (1)  als Matrix-Vektor-Produkt mit der Toeplitz-Matrix  {\fontname{Courier}H}
%  (2)  durch in Matlab programmierte Faltung
%  (3)  und (4) durch MATLAB-Standard-Funktionen  {\fontname{Courier}conv}  und  {\fontname{Courier}filter} .
%  Im Bild werden oben das Signal und darunter jeweils um  {\fontname{Courier}0.2}  in der Hhe 
%  versetzt die Resultate gezeigt.  Sie sind identisch bis auf unterschiedliche Behandlung 
%  an den Enden.
%
m = 100;                    % Anzahl der Abtastungen
t = 1:m;                    % Zeitbereich
x = randn(1,m);             % ein Rauschsignal
g = 8;                      % Filtergrad
g2= g/2 + 1;                % Anzahl der Koeffizienten einer Seite
h = fir1(g,0.4);            % Koeffizienten des Filters
h2= h(g2:g+1);              % eine Seite davon 
H = toeplitz([h2,zeros(1,m-g2)],[h2,zeros(1,m-g2)]); % Toeplitz-Matrix
y1= (H*x')';                % Filter als Matrix-Vektorprodukt
for k=(g+1):100  y2(k) = sum(h.*x(k:-1:k-g)); end % Filter als Faltung
y3= conv(x,h);              % Faltung mit MATLAB-Standard-Funktion
y4= filter(h,1,x);          % Filtern mit MATLAB-Standard-Funktion
figh = fullscreen('Filter'); 
plot(t,[x+2.5;y1+0.6;[y2(g2:m),0,0,0,0]+0.4;y3(g2:m+g2-1)+0.2;[y4(g2:m),0,0,0,0]])
legend('Inputsignal','Matrix-Vektor-Produkt','programmierte Faltung','Standard-Funktion conv','Standard-Funktion filter')
title('Vergleich verschiedener Algorithmen zum Filtern','FontSize',15)
pause
%  Der Faltung im Zeitbereich entspricht eine Multiplikation im Frequenzbereich:
%  Y(\omega) = A(\omega) * X(\omega) ,     %<'FontName',MSVFORMFONT>
%
%  wo  {\fontname{Courier}A}  die Fouriertransformierte von  {\fontname{Courier}h}  ist.   {\fontname{Courier}A}  ist komplexwertig. 
%  Anstelle von Real- und Imaginrteil betrachtet man meist den Betrag und die 
%  Phase in Abhngigkeit von der Frequenz  {\fontname{Courier}\omega}  und spricht dann von
%  Betragsfrequenzgang und Phasenfrequenzgang.
%
%  Die Matlab-Standard-Funktion  {\fontname{Courier}freqz}  zeichnet beide Frequenzgnge fr 
%  gegebenen Impulsantwort-Vektor  {\fontname{Courier}h} . 
%  Beispiel:
%
figh = fullscreen('Frequenzgang'); 
freqz([0.08 0.24 0.33 0.24 0.08]);
%
%  Die Phasensprnge von {\fontname{Courier}\pi} werden durch die Darstellung hervorgerufen. 
%  Es sind eigentlich Nulldurchgnge, die in der Betragsdarstellung als Nullstellen 
%  mit Phasensprung erscheinen.  Das folgende Bild stellt den Frequenzgang linear dar:
%
[h,w] = freqz([0.08 0.24 0.33 0.24 0.08]);
fh = fullscreen('Frequenzgang linear','w',3); 
plot(w/pi,(1-2*mod(cumsum(abs(diff([0;unwrap(angle(h))])>3)),2)).*abs(h)); 
line([0 1],[0 0],'LineStyle',':','Color',0.7*[1 1 1]); axis([0 1 -0.1 1])
%
%  Diese Darstellung ist aber unblich, da der Frequenzgang eigentlich komplexwertig ist. 
%  Schaut man lngs der Frequenzachse auf den komplexen Frequenzgang, so ergibt sich 
%  folgende Ortskurve mit der Frequenz als Parameter:
%
filterort([0.08 0.24 0.33 0.24 0.08])
%
%%  Bitte dieses Bild unter Benutzung der Zoom-Funktion in der Men-Leiste um den Nullpunkt
%%  vergrssern, bis die beiden Nulldurchgnge deutlich zu sehen sind.
%
%  Nullstellen und Pole des Frequenzganges werden im Abschnitt 7.6 nher behandelt.
%
%  Ein Beispiel fr die Filterung im Zeitbereich soll im folgenden Script gegeben 
%  werden.  Zunchst wird ein stark verrauschtes Signal  {\fontname{Courier}x}  aus zwei 
%  Sinus-Komponenten gleicher Amplitude erzeugt.  Dieses Signal wird durch einen 
%  Tiefpass geschickt, der nur die erste Sinuskomponente durchlsst und den 
%  tieffrequenten Rauschanteil.  Input und Output werden abgebildet.
%
n = 1000;
g = 8;
t = (0:n-1)/n;             % Zeitbereich
f1= 9;  
f2 = 111;
x = sin(2*pi*f1*t) + cos(2*pi*f2*t) + 10*rand(1,n);
[b,a] = butter(8,0.02);
y = filter(b,a,x);
gdf1 = 100;
figh = fullscreen('Filterdemo'); 
plot(t(1:n-gdf1+1),x(1:n-gdf1+1),t(1:n-gdf1+1),y(gdf1:n))
lineobj = findobj('Parent',gca,'Type','line');
set(lineobj(2),'Color','g')
set(lineobj(1),'Color','r','LineWidth',2)
legend('Input','Output')
title('Demonstration einer Filterung','FontSize',15)
xlabel('Zeitbereich','FontSize',15)
pause
%  Meistens spezifiziert man das Filterverhalten im Frequenzbereich und berechnet 
%  durch inverse diskrete Fouriertransformation die Impulsantwort  {\fontname{Courier}h} , mit der
%  dann das Eingangssignal zu falten ist.
%
%  Als Beispiel nehmen wir den Betragsfrequenzgang eines idealen Tiefpasses. 
%  Dieser ist gegeben durch
%
%  {\fontname{Courier}A = 1}    fr    {\fontname{Courier}-g < \omega < g}    und    {\fontname{Courier}A = 0}   sonst    ({\fontname{Courier}0 < g < \pi})
%
%  Die Transformation in den Zeitbereich ergibt als Impulsantwort die Funktion  
%  {\fontname{Courier}sin(\omegat)/\omegat} , die fr  {\fontname{Courier}t}  gegen unendlich nur sehr langsam gegen  {\fontname{Courier}0}  strebt.  
%  Um solch einen idealen Tiefpass zu realisieren, msste man mit einer unendlich 
%  langen Impulsantwort falten.  Dies hat insbesondere auch zur Folge, dass das 
%  Resultat erst nach unendlicher Zeit ausgegeben wird.  Wir schneiden die 
%  Impulsantwort deshalb versuchsweise auf beiden Seiten einfach ab, so dass
%  ein endlicher Vektor  {\fontname{Courier}h}  mit  {\fontname{Courier}n}  Komponenten brig bleibt.  Die MATLAB-Funktion  
%  {\fontname{Courier}idealtpdemo}  hat die Parameter  {\fontname{Courier}fs, gr}  und  {\fontname{Courier}grad = n - 1} .  Sie stellt 
%  oben die abgetastete Impulsantwort dar und unten den aus diesem endlichen
%  Vektor  {\fontname{Courier}h}  durch Fouriertransformation ermittelten
%  Betragsfrequenzgang dieses realen Filters.
%
%  Beispiel:
%
idealtpdemo(8000,0.4,60);
%
%  Mit zunehmendem  {\fontname{Courier}n}  wird der bergangsbereich zwar schmaler, aber die strende 
%  Welligkeit bleibt
%
idealtpdemo(8000,0.4,200);
%
%
%  Dass die Impulsantwort tatschlich eine beiderseits abgeschnittene  {\fontname{Courier}sinc}-Funktion 
%  ist, sieht man bei kleiner Grenzfrequenz besser:
%
idealtpdemo(8000,0.08,260)
%
%  Dieses berschwingen beim Abbruch der Fourierentwicklung einer periodischen 
%  Rechteckschwingung ist bekannt als Gibbs-Effekt.  Die MATLAB-Funktion  
%  {\fontname{Courier}fourectdemo}  zeigt, dass die Amplitude des berschwingens praktisch konstant
%  ist.  Mit grsserer Zahl von Koeffizienten wird nur der gestrte Bereich kleiner. 
%  Als Parameter von  {\fontname{Courier}fourectdemo}  wird die maximale Zahl von Fourierkoeffizienten 
%  angegeben.   Es liegen zwei quivalente Darstellungen bereinander:
%
fourectdemo(4);
%
fourectdemo;
%
fourectdemo(20);
%
%%  Tippen Sie die Taste  "1"  und anschliessend mehrfach  "g" bzw. auch  "k"  
%%  zur Skalierung der Zeitachse, insbesondere beim 2D-Bild.
%
%%  bung 6.1:  Die beiderseits abgeschnittene Impulsantwort des idealen Tiefpasses 
%%  kann in MATLAB einfach erzeugt werden durch
%  b = fg*sinc((-gh:+gh)*fg);          %<'FontName',MSVFORMFONT>
%%
%%  Hierin ist  fg  die Grenzfrequenz des Filters relativ zur Nyquistfrequenz 
%%  und  gh  ist die halbe Lnge der Impulsantwort.
%%
%%  Die Darstellung der Filtercharakteristik ist mglich mit
%  filterplot(b,0,1,'lin',0,1.2)       %<'FontName',MSVFORMFONT> 
%%
%%  Erzeugen Sie Tiefpassfilter nach diesem Schema mit den Grenzfrequenzen 
%  0.1, 0.3, 0.5, 0.7, 0.9.            %<'FontName',MSVFORMFONT>
%%  Generieren Sie ein weisses Rauschen durch
%  x = 0.3*randn(1,16000);             %<'FontName',MSVFORMFONT>
%%
%%  und spielen Sie dieses Rauschen ungefiltert und gefiltert ab mit der Funktion 
%%  sound.  Die Abtastrate sollte 8 kHz sein. 
%%  Zum Filtern eignet sich die Funktion  conv.
%