%
%
%  6.2  Filtertypen%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Man unterscheidet Filter nach verschiedenen Gesichtspunkten:
%
%  (a)  Filter mit endlicher Impulsantwort (FIR-Filter) vs.
%        Filter mit unendlicher Impulsantwort (IIR-Filter)
%
%  (b)  Prinzipieller Verlauf des Betragsfrequenzganges:
%        Tiefpass,  Hochpass,  Bandpass,  Bandsperre,  Allpass,  Resonanzfilter, 
%        Kerbfilter,  Kammfilter,  spezielle Entzerrerfilter
%
%  (c)  Verlauf des Phasenganges:
%        Allpass mit fester Phasendrehung  {\fontname{Courier}+\pi/2}  oder  {\fontname{Courier}-\pi/2}  (Hilbert-Filter)
%        nullphasig,  linear,  nichtlinear
%
%  (d)  Filter fr spezielle Aufgaben wie Differentiation oder 
%        Integration des Signals 
%
%  Beispiel zu (a):
%  Es werden zunchst zwei Tiefpassfilter mit Durchlass  {\fontname{Courier}0...0.3} 
%  (relativ zur Nyquistfrequenz) und Sperrdmpfung von  {\fontname{Courier}80 dB}  entworfen 
%  (Diskussion spter).  Das FIR-Filter hat  {\fontname{Courier}61}  Koeffizienten und entsprechende 
%  Impulsantwort.  Das IIR-Filter hat zweimal {\fontname{Courier}9}  Koeffizienten, aber unendliche 
%  Impulsantwort.  Dies zeigt das erste Bild.  Der gesamte Betragsfrequenzgang 
%  sowie ein vergrsserter Ausschnitt des Durchlassbereiches ist auf weiteren 
%  Bildern dargestellt.
%
b1 = remez(60,[0, 0.28, 0.37,1],[1 1 0 0],[0.002,1]); % FIR-Filter
[b2,a2] = ellip(8,1,80,0.3);            % Entwurf eines IIR-Filters
[b,t] = impz(b2,a2,200,1);              % dessen Impulsantwort
n = min(160,length(t));                 % eine sinnvolle Plotbreite
t = t(1:n);                             % Zeitbereich einschrnken
b = b(1:n);                             % Impulsantwort eingrenzen
h(1) = fullscreen('Impulsantworten');
plot(t,[b1,zeros(1,n-length(b1))],'r',t,b)
legend('FIR','IIR')
title('Impulsantwort','FontSize',13)
xlabel('Zeitbereich','FontSize',12)
h(2) = fullscreen('Frequenzgnge');
filterplot({b1;{b2;a2}})
lineobj = get(gca,'Children');
set(lineobj(1),'Color','b')
set(lineobj(2),'Color','r')
hl = legend('FIR','IIR');
set(hl,'Position',[0.171514 0.156982 0.145393 0.0557107])
posmat = [ 355 210 411 339; 455 273 519 456]; pos = posmat(screen,:);
h(3) = figure; 
set(h(3),'position',pos,'Color','w','MenuBar','none','Numbertitle','off')
set(h(3),'Name','Durchlassbereich','KeyPressFcn','zoom3d')
filterplot({b1;{b2;a2}},0,0.32,0,-1.2,0.8)
lineobj = get(gca,'Children');
set(lineobj(1),'Color','b')
set(lineobj(2),'Color','r')
title('Durchlassbereich','FontSize',13)
%
%  Beispiele zu (b)  (Verlauf des Betragsfrequenzganges):
%  Tiefpass,  Hochpass,  Bandpass,  Bandsperre.
%  (Resonanzfilter,  Kerbfilter,  Kammfilter  werden spter behandelt)
%
tp = remez(50,[0, 0.2, 0.3,1],[1 1 0 0],[0.01,1]);
posmat = [ 3 314 394 242; 2 402 505 347]; pos = posmat(screen,:);
h(1) = figure;
set(h(1),'position',pos,'Color','w','MenuBar','none','Numbertitle','off')
set(h(1),'Name','TP','KeyPressFcn','zoom3d')
filterplot(tp); 
title('Tiefpass','FontSize',12)

hp = remez(50,[0, 0.5, 0.6,1],[0 0 1 1],[1,0.01]);
posmat = [ 405 314 394 242; 515 402 507 347]; pos = posmat(screen,:);
h(2) = figure;
set(h(2),'position',pos,'Color','w','MenuBar','none','Numbertitle','off')
set(h(2),'Name','HP','KeyPressFcn','zoom3d')
filterplot(hp); 
title('Hochpass','FontSize',12)

bp = remez(50,[0, 0.2, 0.3,0.6,0.7,1],[0 0 1 1 0 0],[1,0.01,1]);
posmat = [ 3 30 394 242; 3 31 504 345]; pos = posmat(screen,:);
h(3) = figure;
set(h(3),'position',pos,'Color','w','MenuBar','none','Numbertitle','off')
set(h(3),'Name','BP','KeyPressFcn','zoom3d')
filterplot(bp); 
title('Bandpass','FontSize',12)

bs = remez(50,[0, 0.3, 0.4,0.6,0.7,1],[1 1 0 0 1 1],[0.01,1,0.01]);
posmat = [ 405 30 394 242; 515 31 507 345]; pos = posmat(screen,:);
h(4) = figure;
set(h(4),'position',pos,'Color','w','MenuBar','none','Numbertitle','off')
set(h(4),'Name','BS','KeyPressFcn','zoom3d')
filterplot(bs); 
title('Bandsperre','FontSize',12)
%
%
%  Beispiele zu (c)  (Verlauf des Phasenganges):
%
%  Der Phasengang bestimmt die Verzgerung des Filters und gewhrleistet 
%  Verzerrungsfreiheit oder auch nicht.  Wir betrachten zunchst das Verhalten 
%  eines nicht verzerrenden Allpasses.  Gegeben sei ein zeitkontinuierliches Signal  {\fontname{Courier}x(t)}  
%  und dessen Fouriertransformierte  {\fontname{Courier}X(\omega)} .  Der Allpass soll am Ausgang das 
%  unverzerrte, aber mglicherweise um  {\fontname{Courier}\tau} verzgerte Signal liefern:
%
%  y(t) = x(t - \tau)                %<'FontName',MSVFORMFONT> 
%
%  bzw. im Frequenzbereich nach dem Verschiebungssatz (Abschnitt 3.4):
%
%  Y(\omega) = e^{-i\tau\omega} X(\omega) %<'FontName',MSVFORMFONT>
%
%  Andererseits gilt nach Abschnitt 6.1 mit dem Frequenzverhalten  {\fontname{Courier}A(\omega)}  des Allpasses:
%
%  Y(\omega) = A(\omega) X(\omega)   %<'FontName',MSVFORMFONT>
%
%  Daraus folgt fr das Filterverhalten:
%
%  A(\omega) = e^{-i\tau\omega}      %<'FontName',MSVFORMFONT>
%
%  Der Betragsfrequenzgang des Allpasses ist also wie zu erwarten
%
%  abs(A(\omega)) = 1                %<'FontName',MSVFORMFONT>
%
%  und der Phasenfrequenzgang ist linear:
%
%  angle(A(\omega)) = -\tau\omega    %<'FontName',MSVFORMFONT>
%
%  Fr mit der Abtastrate  {\fontname{Courier}f_s}  abgetastete zeitdiskrete Signale  {\fontname{Courier}x_n}  der Periode  {\fontname{Courier}N}  
%  ergibt sich mit
%
%  \omega_k = 2\pikf_s/N  ;    \tau = r/f_s  %<'FontName',MSVFORMFONT>
%
%  angle(A_k) = -\tau\omega_k = -r \cdot 2\pik/N   %<'FontName',MSVFORMFONT>
%
%  Linearphasigkeit in den Durchlassbereichen garantiert auch bei den brigen Filtertypen 
%  die Verzerrungsfreiheit. Der Phasengang darf in Sperrbereichen natrlich beliebig sein.
%
%  Den Vergleich eines linearphasigen (FIR-) und eines nicht linearphasigen 
%  (IIR-) Tiefpasses zeigt  {\fontname{Courier}demolinphas} :  es liegen drei Abbildungen bereinander. 
%  Die Phasensprnge um  {\fontname{Courier}\pi}  beim FIR-Filter sind Folge der Nulldurchgnge der
%  Amplitude. Diese liegen als Null-Werte natrlich im Sperrbereich.
%
demolinphas
%
%  Offensichtlich gibt es beim IIR-Filter Verzerrungen. Die leichten berschwinger 
%  beim FIR-Filter beruhen auf dem Gibbs-Effekt, sind also keine Verzerrungen.
%
%%  bung 6.2a: Geben Sie die FIR-Filterkoeffizienten der gleitenden Mittelwertbildung 
%%  ber je n Abtastungen an.
%%
%%  bung 6.2b: Stellen Sie den Amplituden- und den Phasenfrequenzgang der gleitenden 
%%  Mittelwertbildung mit der Funktion  freqz  graphisch dar fr n = 3, 5, 7.
%%
%%  bung 6.2c: Klassifizieren Sie das Filterverhalten der gleitenden Mittelwertbildung 
%%  ( TP / HP / BP / BS ).  Filtern Sie wie in bung 6.1 weisses Rauschen mit der 
%%  gleitenden Mittelwertbildung und geben Sie dies mit der Funktion  sound  aus.
%
