%
%
%6.3  FIR-Filter%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  In diesem Abschnitt sind folgende Punkte zu besprechen:
%
%  \bf(a)  Kausale und nicht kausale Schreibweise
%
%  \bf(b)  Symmetrien und deren Konsequenzen
%
%  \bf(c)  Charakteristika von Pass- und Sperrfiltern
%
%
%  Im Falle symmetrischer Impulsantworten lsst sich die diskrete Faltung vorteilhaft 
%  beschreiben durch
%        n                                           %<'FontName',MSVFORMFONT>
%  y_i = _{\fontsize{26}\Sigma} h_k x_{i-k}          %<'FontName',MSVFORMFONT>
%      k=-n                                          %<'FontName',MSVFORMFONT>
%
%  Die Indices  {\fontname{Courier}k}  und  {\fontname{Courier}i}  sind fortlaufende Nummern der Abtastungen. Sollen sich beide 
%  auf dieselben Abtastzeitpunkte beziehen, so folgt, dass zur Berechnung von  {\fontname{Courier}y_i}  auf 
%  {\fontname{Courier}x_j}  mit  {\fontname{Courier}j>i}  vorausgegriffen werden muss.  Man nennt das Filter mit diesem  {\fontname{Courier}h_k}  ein 
%  nicht-kausales Filter.  Bezieht man dagegen die Abtastungen auf um  {\fontname{Courier}n}  Schritte 
%  versetzte Zeitpunkte, so ist das Problem der Kausalitt behoben.
%
%
%  \bf(b)  Symmetrien und deren Konsequenzen
%
%  Angenommen, ein FIR-Filter sei linearphasig mit der Verzgerung  {\fontname{Courier}\tau} .  
%  Dann lsst sich die Fouriertransformierte der Impulsantwort schreiben als
%
%  H(\omega) = A(\omega) e^{-i\omega\tau}            %<'FontName',MSVFORMFONT> 
%
%  wo  {\fontname{Courier}A(\omega)}  eine {\bf\itreelle} Funktion ist.  Wir transformieren dies in den Zeitbereich, 
%  um Eigenschaften der Impulsantwort linearphasiger Filter zu finden.  Die 
%  Transformierte des Produktes von  {\fontname{Courier}A(\omega)}  und  {\fontname{Courier}e^{-i\omega\tau}}  ist im Zeitbereich 
%  die Faltung der inversen Fouriertransformierten  {\fontname{Courier}a(t)}  von  {\fontname{Courier}A(\omega)}  mit der 
%  inversen Fouriertransformierten  {\fontname{Courier}\delta(t+\tau)}  von  {\fontname{Courier}e^{-i\omega\tau}} .  Diese Faltung ergibt  
%  {\fontname{Courier}a(t+\tau)}  als Impulsantwort.   {\fontname{Courier}a(t)}  ist die inverse Fouriertransformierte einer reellen 
%  Funktion, also eine gerade Funktion.  Die nicht kausale Impulsantwort  {\fontname{Courier}a(t)}  ist 
%  also symmetrisch um  {\fontname{Courier}t = 0} , die kausale um  {\fontname{Courier}t = \tau} .
%
%  Da Linearphasigkeit eine wesentliche Eigenschaft ist, die sich nur mit digitalen 
%  FIR-Filtern erzielen lsst (mit analogen Filtern nie), wird diese nachfolgend immer 
%  angenommen.  Diese Annahme machen auch alle gngigen Entwurfsprogramme, 
%  ohne das explizit zu nennen.
%
%  IIR-Filter knnen nicht linearphasig sein, da sonst die Verzgerung  {\fontname{Courier}\tau}  unendlich 
%  sein msste, um bei unendlicher Impulsantwort symmetrisch sein zu knnen.
%
%  Ist in obiger Betrachtung  {\fontname{Courier}A(\omega)}  eine rein imaginre Funktion, so ergibt 
%  sich bei inverser Fouriertransformation in den Zeitbereich ebenfalls eine 
%  reelle Funktion  {\fontname{Courier}a(t)} , die jedoch eine ungerade Symmetrie aufweist. 
%
%  Die Verzgerung bzw. Laufzeit durch ein FIR-Filter mit  {\fontname{Courier}n}  Koeffizienten 
%  ist bei der Abtastfrequenz  {\fontname{Courier}f_s}
%
%  \tau = n/2f_s  %<'FontName',MSVFORMFONT>
%
%  Im Falle gerader Zahl  {\fontname{Courier}n}  von Koeffizienten ist die Laufzeit nicht gleich einer ganzen 
%  Zahl von Abtastschritten.  FIR-Filter mit ungerader Anzahl von Koeffizienten werden 
%  deshalb hufig bevorzugt.
%
%  FIR-Filter werden in 4 Klassen eingeteilt:
%
%  Typen von FIR-Filtern                                             %<'FontName',MSVFORMFONT>
%  =====================                                             %<'FontName',MSVFORMFONT>
%
%  Anzahl Koeffizienten    Symmetrie der Impulsantwort   Bezeichnung %<'FontName',MSVFORMFONT>
%  ----------------------------------------------------------------- %<'FontName',MSVFORMFONT>
%       ungerade                   gerade                Typ 1       %<'FontName',MSVFORMFONT>
%       gerade                     gerade                Typ 2       %<'FontName',MSVFORMFONT>
%       ungerade                   ungerade              Typ 3       %<'FontName',MSVFORMFONT>
%       gerade                     ungerade              Typ 4       %<'FontName',MSVFORMFONT>
%
%  Das folgende MATLAB-Script veranschaulicht diese Klassen:
%
if screen==1 pos = [3 314 394 264; 405 314 394 264; 3 30 394 258; 405 30 394 258]; end
if screen==2 pos = [2 402 505 345; 515 402 507 345; 3 31 504 345; 515 31 507 345]; end
for k=1:4 h(k)=figure; set(h(k),'position',pos(k,:),'Color','w','MenuBar','none'); end
for k=1:4 set(h(k),'NumberTitle','off','KeyPressFcn','zoom3d','Name',sprintf('Typ %d',k)); end
yl = 0.43;
ug = fir1(8,0.4);
figure(h(1)); stem(ug)
line([1,9],[0,0],'LineStyle',':','Color','k')
line([5,5],[-yl,yl],'LineStyle',':','Color','k')
set(gca,'ylim',[-yl,yl]);
title('Typ 1')
gg = fir1(7,0.4);
figure(h(2)); stem(gg)
line([1,9],[0,0],'LineStyle',':','Color','k')
line([4.5,4.5],[-yl,yl],'LineStyle',':','Color','k')
set(gca,'ylim',[-yl,yl]);
set(gca,'xlim',[1,8]);
title('Typ 2')
uu = [ug(1:4),0,-ug(4:-1:1)];
figure(h(3)); stem(uu)
line([1,9],[0,0],'LineStyle',':','Color','k')
line([5,5],[-yl,yl],'LineStyle',':','Color','k')
set(gca,'ylim',[-yl,yl]);
title('Typ 3')
gu = [gg(1:4),-gg(4:-1:1)];
figure(h(4)); stem(gu)
line([1,9],[0,0],'LineStyle',':','Color','k')
line([4.5,4.5],[-yl,yl],'LineStyle',':','Color','k')
set(gca,'ylim',[-yl,yl]);
set(gca,'xlim',[1,8]);
title('Typ 4')
%
%  Die Frequenzgnge getrennt nach Betrag und Phase fr diese Filter zeigen die 
%  folgenden Bilder.  Die Typen 3 und 4  beginnen wegen des konstanten 
%  Phasenversatzes von  {\fontname{Courier}\pi/2}  bei  {\fontname{Courier}90} Grad.
%
if screen==1 pos = [3 314 394 264; 405 314 394 264; 3 30 394 258; 405 30 394 258]; end
if screen==2 pos = [2 402 505 345; 515 402 507 345; 3 31 504 345; 515 31 507 345]; end
for k=1:4 h(k)=figure; set(h(k),'position',pos(k,:),'Color','w'); end
for k=1:4 set(h(k),'MenuBar','none','NumberTitle','off','KeyPressFcn','zoom3d'); end
set(h(1),'Name','Typ 1');
set(h(2),'Name','Typ 2');
set(h(3),'Name','Typ 3');
set(h(4),'Name','Typ 4');
figure(h(1)); freqz(ug)
figure(h(2)); freqz(gg)
figure(h(3)); freqz(uu)
figure(h(4)); freqz(gu)
pause
%
%  \bf(c)  Charakteristika von Pass- und Sperrfiltern
%
%  Wegen der Unmglichkeit des idealen Tief- und Hochpasses gibt es zwischen dem 
%  Durchlassbereich  D  und dem Sperrbereich  S  einen bergangsbereich  . 
%  Je schmaler dieser bergangsbereich gewnscht wird, desto mehr Koeffizienten 
%  sind erforderlich.  Neben der Breite  des bergangsbereiches wird die Zahl der 
%  Koeffizienten bestimmt durch die maximale Welligkeit im Durchlassbereich sowie 
%  durch die gewnschte Sperrdmpfung, die der Welligkeit im Sperrbereich entspricht.
%
%  Beispiel:
%
if screen==1 pos = [-2 30 804 549; 417 257 341 301];  end
if screen==2 pos = [4 30 1017 719; 534 326 431 397]; end
for k=1:2 h(k)=figure; set(h(k),'Color','w','MenuBar','none','NumberTitle','off'); end
for k=1:2 set(h(k),'position',pos(k,:),'KeyPressFcn','zoom3d'); end
set(h(1),'Name','logarithmisch');
set(h(2),'Name','linear');
figure(h(1)); filterplot(remez(40,[0,0.3,0.4,1],[1 1 0 0],[0.005,1]))
h(3) = copyobj(h(1),0); set(h(3),'Visible','off')
figure(h(1))
line([0,0.3],[0.85,0.85],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0,0.3],[-0.9,-0.9],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0.4,1],[-66,-66],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0.3,0.3],[-100,10],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0.4,0.4],[-100,10],'LineStyle','-','LineWidth',2.0,'Color','r')
figure(h(2)); filterplot(remez(40,[0,0.3,0.4,1],[1 1 0 0],[0.005,1]),0,1,'lin',0,1.3)
line([0,0.3],[1.1,1.1],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0,0.3],[0.9,0.9],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0.4,1],[0,0],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0.3,0.3],[0,1.3],'LineStyle','-','LineWidth',2.0,'Color','r')
line([0.4,0.4],[0,1.3],'LineStyle','-','LineWidth',2.0,'Color','r')
pause
%  Die Spezifikation von derartigen Filtern erfolgt meist graphisch durch Angabe der 
%  verbotenen Gebiete, durch die also der Betragsfrequenzgang nicht verlaufen darf.
%
%  Beispiel:  {\fontname{Courier}D = 0 ... 0.4}  mit Welligkeit  {\fontname{Courier}< 3} dB
%                {\fontname{Courier}S = 0.6 ... 1}  mit Dmpfung {\fontname{Courier}> 60} dB
%
%%  Der vorige MATLAB-Block muss vor dem folgenden ausgefhrt sein.
%%  Es drfen danach nicht alle Graphiken mit "ESC" gelscht werden.
%
set(h(3),'Visible','on'); figure(h(3))
patch([0,0.3,0.3,0],[-100,-100,-1,-1],'r')
patch([0,0.4,0.4,1,1,0],[1,1,-66,-66,10,10],'r')
%
%
%%  bung 6.3:  Zeigen Sie mit der Funktion  filspezgraph, dass die gleitende 
%%  Mittelwertbildung ber je 5 Abtastwerte die Spezifikation eines Tiefpasses 
%%  erfllt mit folgenden Angaben:
%%
%%  bergangsbereich:        (0.2 bis 0.33)*Nyquistfrequenz
%%  Welligkeit im Durchlass:  -4 ... 0 dB
%%  Dmpfung im Sperrbereich: -12 dB
%