%
%
%7.1  Filterstrukturen%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Jede Struktur mit Rckkopplung stellt ein IIR-Filter dar.  Bestimmte Eigenschaften 
%  lassen sich mit ganz bestimmten Strukturen aufwandsarm realisieren.  Das erschwert 
%  die generelle Behandlung.  Wir beschrnken uns deshalb zunchst auf eine Standard-
%  Struktur, die sog. Direktstruktur, der folgender Algorithmus entspricht:
%
%  y_n = (b_0x_n + b_1x_{n-1} +...+ b_gx_{n-g} - a_1y_{n-1} -...- a_gy_{n-g}) / a_0 %<'FontName',MSVFORMFONT>
% 
%  Hierin ist der erste Teil mit den Koeffizienten  {\fontname{Courier}b_k}  ein FIR-Filter.  Der zweite Teil 
%  realisiert die Rckkopplung.  {\fontname{Courier}g}  ist der Filtergrad.  
%  Die Indizierung der Koeffizienten geschieht hier von  {\fontname{Courier}0}  bis  {\fontname{Courier}g} , in MATLAB-Programmen 
%  und im folgenden Bild dagegen von  {\fontname{Courier}1}  bis  {\fontname{Courier}g+1} .
%
%  Filterstrukturen werden meist graphisch dargestellt.  Das folgende Bild zeigt die 
%  Direktstruktur in der blichen Form mit Verzgerungen, Multiplizierern und Addierern.
%
direktstruktur
%
%  In MATLAB wird diese Direktstruktur in der Funktion  {\fontname{Courier}filter}  realisiert:  
%  y = filter(b,a,x)                 %<'FontName',MSVFORMFONT>
%
%  wo  {\fontname{Courier}b}  und  {\fontname{Courier}a}  die Koeffizienten des nichtrekursiven und des rekursiven Teils der 
%  Struktur sind und  {\fontname{Courier}x}  der Inputvektor.
%
%  Ein sehr einfaches Beispiel (siehe nchsten Abschnitt) gibt das folgende Bild fr 
%  je einen Koeffizienten   {\fontname{Courier}b_1=0.06}   im nichtrekursiven Teil und  
%  {\fontname{Courier}a_2=-0.94}   im rekursiven Teil  (Normierung:  {\fontname{Courier}a_1=1} ) :
%
t = 1:800;                                % Zeitbereich
x = sin(2*pi*0.01*t) + randn(size(t));    % Signal
b = [0.06];  a = [1 -0.94];               % Koeffizienten
y = filter(b,a,x);                        % Filterung
figh = fullscreen('Filter');              % Bilderzeugung
plot(t,[x+4;y])                           % Darstellung
%
