%
%
%7.4  Entwurf von IIR-Filtern%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Der Entwurf von IIR-Filtern ist unvergleichlich komplizierter als der von FIR-Filtern. 
%  In diesem Kurs beschrnken wir uns auf die Direkt-Struktur (ausser in Abschnitt 7.5). 
%  Eine ausfhrliche Darstellung findet sich in  W. Hess: "Digitale Filter".
%
%  Die Entwurfsverfahren fr IIR-Filter basieren zumeist auf solchen fr elektrische 
%  Analogfilter.  Wir diskutieren hier nur zwei wichtige Verfahren, die zu Filtern mit 
%  ziemlich unterschiedlichem Frequenzgang im Detail fhren:
%
%  Butterworth-Filter sind Tiefpassfilter ohne Welligkeit im Durchlassbereich und relativ 
%  grossem bergangsbereich.  Sie werden in MATLAB mit der Funktion  {\fontname{Courier}butter}  
%  entworfen.  Aus "{\fontname{Courier}help butter}":
%  [B,A] = BUTTER(N,Wn) designs an N'th order lowpass digital        %<'FontName',MSVFORMFONT>
%  Butterworth filter and returns the filter coefficients in length  %<'FontName',MSVFORMFONT>
%  N+1 vectors B and A.  The cut-off frequency Wn must be            %<'FontName',MSVFORMFONT>
%  0.0 < Wn < 1.0, with 1.0 corresponding to half the sample rate.   %<'FontName',MSVFORMFONT>
%
%  Ein Beispiel mit  Filtergrad = {\fontname{Courier}6}  und  Grenzfrequenz = {\fontname{Courier}0.2} :
%
[bb,ab] = butter(6,0.2)
fig1 = fullscreen('Butterworth');
filterplot({{bb;ab}},0,1,0,-100,10,1,64)
title('IIR-Filterentwurf: Butterworth','FontSize',13)
%
%  Entsprechend dem REMEZ-Verfahren fr FIR-Filter mit jeweils gleichmssiger 
%  Welligkeit im Durchlass- sowie im Sperrbereich kann man dasselbe iterativ 
%  fr IIR-Filter durchfhren.  In MATLAB geschieht das mit der Funktion  {\fontname{Courier}ellip} .  
%  Aus "{\fontname{Courier}help ellip}":
%  [B,A] = ELLIP(N,Rp,Rs,Wn) designs an N'th order lowpass digital   %<'FontName',MSVFORMFONT>
%  elliptic filter with Rp decibels of ripple in the passband and    %<'FontName',MSVFORMFONT>
%  a stopband Rs decibels down.  ELLIP returns the filter            %<'FontName',MSVFORMFONT>
%  coefficients in length N+1 vectors B and A.  The cut-off          %<'FontName',MSVFORMFONT>
%  frequency Wn must be 0.0 < Wn < 1.0, with 1.0 corresponding to    %<'FontName',MSVFORMFONT>
%  half the sample rate.  Use Rp = 0.5 and Rs = 20 as starting       %<'FontName',MSVFORMFONT>
%  points, if you are unsure about choosing them.                    %<'FontName',MSVFORMFONT>
%
%  \bfBeispiel:  
%  dasselbe Filter wie oben  ( Grad = {\fontname{Courier}6} ;  Grenzfrequenz = {\fontname{Courier}0.2} )
%  Es wird neben dem elliptischen Filter auch das Butterworthfilter gezeigt:
%
[be,ae] = ellip(6,1,60,0.2),  [bb,ab] = butter(6,0.2);
fig2 = fullscreen('Elliptisches Filter');
filterplot({{bb;ab};{be;ae}},0,1,0,-100,10,[1 1],64)
legend('Butterworth-Filter','elliptisches Filter')
set(fig2,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}},'KeyPressFcn','hervorhebung');
%
%  Mit geringfgig hheren Filtergraden sind ausserordentlich kleine bergangsbereiche 
%  realisierbar:
%
for g = 6:2:10 [b,a] = ellip(g,1,60,0.2); kof{g} = {b;a}; end
fig3 = fullscreen('Elliptische Filter');
filterplot({kof{6};kof{8};kof{10}},0,1,0,-100,10,[1 1 1],64)
legend('Grad = 6','Grad = 8','Grad = 10')
set(fig3,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}},'KeyPressFcn','hervorhebung');
%
%  Etwa ab Filtergrad  {\fontname{Courier}12}  gibt es beim Entwurf der Filter numerische Probleme. 
%  In jedem Fall sollte man sich den durch das berechnete Filter realisierten 
%  Frequenzgang anschauen.  Er widerspricht bei Graden > {\fontname{Courier}12}  hufig der 
%  Spezifikation durch die Input-Parameter von  {\fontname{Courier}ellip} .
%
%  \bfBeispiel:  
%  Tiefpass vom Grad {\fontname{Courier}18}
%
[be,ae] = ellip(18,1,80,0.1); 
fig3 = fullscreen('Instabilitt');
filterplot({{be;ae}},0,1,0,-100,10,1,64)
title('Numerische Instabilitt beim Entwurf von IIR-Filtern','FontSize',13)
%
%  Viel kritischer als die numerische Instabilitt beim Filterentwurf ist die begrenzte 
%  Reprsentation der Koeffizienten in einem Signalprozessor.  Die Funktion  {\fontname{Courier}filterplot}  
%  hat deshalb die Option, die Reprsentation der Koeffizienten  {\fontname{Courier}b}  und  {\fontname{Courier}a}  auf  {\fontname{Courier}p}  Bits 
%  zu beschrnken.  Dabei wird davon ausgegangen, dass diese Koeffizienten optimal 
%  skaliert werden (der grsste Koeffizient von b ist dann {\fontname{Courier}1}, was nach der 
%  Filterrechnung korrigiert wird).  Das von  {\fontname{Courier}filterplot}  fr  {\fontname{Courier}p}  Bits gezeigte 
%  Ergebnis ist der beste Fall.  Rundungsfehler sind nmlich noch nicht bercksichtigt.
%
%  \bfBeispiel:  
%  Tiefpass vom Grad {\fontname{Courier}10}
%
[b,a] = ellip(10,1,80,0.2);
fig4 = fullscreen('Wortbreite');
filterplot({{b;a};{b;a};{b;a};{b;a};{b;a}},0,1,0,-100,10,[1 1 1 1 1],[16 20 24 28 32])
title('Abhngigkeit des Frequenzganges von der Reprsentation der Koeffizienten','FontSize',13)
legend('16 Bit','20 Bit','24 Bit','28 Bit','32 Bit')
set(fig4,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}},'KeyPressFcn','hervorhebung');
%
%  \bfBeispiel:  
%  Tiefpass vom Grad {\fontname{Courier}6}
%  Fr dieses Filter sind  {\fontname{Courier}16}  Bit kaum ausreichend.
%
[b,a] = ellip(6,1,80,0.2);
fig5 = fullscreen('Gesamtbereich');
filterplot({{b;a};{b;a};{b;a};{b;a};{b;a}},0,1,0,-100,10,[1 1 1 1 1],[14 16 18 20 32])
legend('14 Bit','16 Bit','18 Bit','20 Bit','32 Bit',0)
title('Abhngigkeit des Frequenzganges von der Reprsentation der Koeffizienten')
set(fig5,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}},'KeyPressFcn','hervorhebung');
fig6 = fullscreen('Durchlass');
filterplot({{b;a};{b;a};{b;a};{b;a};{b;a}},0,0.22,0,-5,5,[1 1 1 1 1],[14 16 18 20 32])
legend('14 Bit','16 Bit','18 Bit','20 Bit','32 Bit',0)
title('Verhalten im Durchlassbereich','FontSize',13)
set(fig6,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}},'KeyPressFcn','hervorhebung');
%
%  Untersuchung von IIR-Bandpassfiltern mit  {\fontname{Courier}iirbanddemo(f1,f2,dbtrans,dbstop,p)} :
%  Gesucht wird ein IIR-Bandpass mit Durchlassbereich  {\fontname{Courier}0.2...0.4}  bei  {\fontname{Courier}1 dB}  Welligkeit 
%  im Durchlassbereich und  {\fontname{Courier}60 dB}  Sperrdmpfung zur Realisierung mit einem 
%  {\fontname{Courier}16}-Bit-Prozessor.  Der bergangsbereich soll nicht grsser sein als  {\fontname{Courier}0.12}
%
iirbanddemo(0.2,0.4,1,60,16);
%
%  Offenbar sind alle Filter unbrauchbar, weil entweder der bergangsbereich oder die 
%  Welligkeit zu gross ist.
%
%%  bung 7.4.a:  Nach der Methode "Versuch und Irrtum" ist der Entwurf des letzen Bandpasses 
%%  zu verbessern.  Als Welligkeit ist zu zu versuchen:  {\fontname{Courier}  0.9  0.8  0.7 ... 0.1}
%
%
%%  bung 7.4.b  Entwerfen Sie mit filtdemo ein FIR-Filter mit folgenden 
%%  Eigenschaften (vgl. bung 6.4.g):
%
%  obere Grenze des Durchlassbereiches :  0.20      %<'FontName',MSVFORMFONT>
%  untere Grenze des Sperrbreiches :      0.30      %<'FontName',MSVFORMFONT>
%  Welligkeit im Durchlassbereich :       +- 1.0 dB %<'FontName',MSVFORMFONT> 
%  Dmpfung im Sperrbereich :             -100 dB   %<'FontName',MSVFORMFONT>
%
%%  Vergleichen Sie das Resultat der Methoden  BUTTER, CHEBY1, CHEBY2, ELLIP !
%%  Wie viele Filterkoeffizienten b und a sind jeweils minimal erforderlich ?
%
[b,a] = filtdemo('getfilt');
%
%%  Prfen Sie das Resultat jeweils mit dem folgenden MATLAB-Skript:
%
[b,a] = filtdemo('getfilt');
filspezgraph([0 0.2],[0.3 1],[-2 +0.01],100,{b;a},'Filterspezifikation')
%
%  Die Koeffizientenzahl sollte folgende Werte erreichen:
%  BUTTER: 27 ;   CHEBY1: 14 ;   CHEBY2: 14 ;   ELLIP:  9 ; %<'FontName',MSVFORMFONT>
%
%%  (Beim Butterworth-Filter ist der Toleranzbereich des Durchlassgebietes anzupassen,
%%  da die Welligkeit um 0 erfolgt).
%
