%
%
%  7.7  Spezielle Strukturen%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Mit speziellen Strukturen knnen besondere Eigenschaften des Frequenzganges 
%  aufwandsarm realisiert werden.  Die Zahl der untersuchten Strukturen ist sehr 
%  gross.  An dieser Stelle soll nur ein Beispiel gegeben werden:  Das Kerbfilter 
%  aus  W.Hess: "Digitale Filter".  In diesem Buch findet sich eine ausfhrliche 
%  Diskussion des Themas.
%
%  Die Struktur basiert auf zwei Kreuzgliedern:
%
kerbfilter
%
%  Der gesamte Rechenaufwand pro Abtastwert beschrnkt sich auf den Rumpf der 
%  folgenden Programmschleife:
%
%  t1 = 0; t2 = 0;                 %<'FontName',MSVFORMFONT>
%  for k = 1:length(x)             %<'FontName',MSVFORMFONT>
%     h1 = p2*(x(k) - t1);         %<'FontName',MSVFORMFONT>
%     u  = x(k) + h1;              %<'FontName',MSVFORMFONT>
%     h2 = p2*(u - t2);            %<'FontName',MSVFORMFONT>
%     v  = u + h2;                 %<'FontName',MSVFORMFONT>
%     y(k) = (x(k) + h1 + t1)*0.5; %<'FontName',MSVFORMFONT>
%     t1 = t2 + h2;                %<'FontName',MSVFORMFONT>
%     t2 = v;                      %<'FontName',MSVFORMFONT>
%  end                             %<'FontName',MSVFORMFONT>
%
%  Das sind also  {\fontname{Courier}7}  Additionen und  {\fontname{Courier}3}  Multiplikationen.  Allerdings ist der Gewinn 
%  gegenber den  {\fontname{Courier}5}  Additionen und  {\fontname{Courier}6}  Multiplikationen der Direktstruktur zweiten 
%  Grades in diesem einfachen Beispiel nicht nennenswert.  Wesentlich besser kann 
%  bei speziellen Strukturen die numerische Stabilitt sein.  Dieser Algorithmus 
%  ist in MATLAB realisiert in der Funktion notchfilter:
%
help notchfilter
%
%  Der Frequenzgang des Filters ergibt sich aus der Struktur zu
%
%  H_{Kerb}(z) = (1 + H_{Kreuz}(z)) / 2 %<'FontName',MSVFORMFONT>
%
%  Dies entspricht dem linken senkrechten Pfad der Struktur.   {\fontname{Courier}H_{Kreuz}(z)}  ist die 
%  bertragungsfunktion der Kreuzgliedstruktur zweiten Grades, die vom senkrechten 
%  Pfad abzweigt und unten hinzuaddiert wird.  Diese entspricht einem IIR-Filter in
%  Direktstruktur mit den Koeffizienten
%
%  b = [p2,  p1*(1+p2),  1] ;   a = [1,  p1*(1+p2),  p2] %<'FontName',MSVFORMFONT>
%
%  Die Kreuzgliedstruktur ist ein Allpassfilter.  Dies zeigt der Frequenzgang fr 
%  ein Beispiel:   {\fontname{Courier}p1 = -0.6 ;  p2 = 0.8} :
%
p1 = -0.6;  p2 = 0.8;
b  = [p2,  p1*(1+p2),  1],   a = [1,  p1*(1+p2),  p2]
fh1= fullscreen('Allpass');
freqz(b,a)
ax = get(gcf,'children'); ah = ax(2); axes(ah); set(ah,'ylim',[-1,+1])
title('Allpassfilter in Kreuzgliedstruktur','FontSize',13)
%
%  Zwar sieht man so den przisen Frequenzgang, aber wie er zustande kommt, 
%  geht erst aus dem Verhalten der bertragungsfunktion in der Z-Ebene hervor. 
%  Hier sieht man, dass die Wirkung eines engen Paares von einer Nullstelle und 
%  einer Polstelle mit der Entfernung rasch abnimmt.  Legt man den Einheitskreis 
%  genau zwischen das Paar, so ergibt sich ein Allpass.  Man beachte aber, dass 
%  diese Darstellung nur den Betrag der bertragungsfunktion zeigt.  An jeder 
%  Stelle der Z-Ebene hat  {\fontname{Courier}H(z)}  einen komplexen Wert.
%
p1 = -0.6;  p2 = 0.8;
b  = [p2,  p1*(1+p2),  1],   a = [1,  p1*(1+p2),  p2]
hzplot(b,a);
%
%  Setzt man   {\fontname{Courier}H_{Kreuz}(z) = Num/Den} ,  wo  {\fontname{Courier}Num}  das Zhler- und  {\fontname{Courier}Den} das
%  Nennerpolynom des Allpasses  {\fontname{Courier}H_{Kreuz}(z)}  mit den Koeffizienten 
%  {\fontname{Courier}b_k}  bzw.  {\fontname{Courier}a_k}  ist, in die Beziehung
%
%  H_{Kerb}(z) = (1 + H_{Kreuz}(z)) / 2            %<'FontName',MSVFORMFONT>
%
%  ein und bringt dies wieder auf die gebrochen-rationale Form, so ergeben sich 
%  fr das Zhler- und Nennerpolynom von  {\fontname{Courier}H_{Kerb}(z)}  die Koeffizienten
%
%  bn = a + b = [(1+p2)/2,  p1*(1+p2),  (1+p2)/2] %<'FontName',MSVFORMFONT>
%  an =   a   = [    1   ,  p1*(1+p2),     p2   ] %<'FontName',MSVFORMFONT>
%
%  Egal in welcher Struktur ein Filter realisiert wird, die bertragungsfunktion 
%  lsst sich immer in diese gebrochen rationale Form bringen.  Man kann es also 
%  auch immer in der Direktstruktur realisieren.  Der Rechenaufwand ist dann
%  hufig hher.
%
%  Wir betrachten nun den Betrag der bertragungsfunktion  {\fontname{Courier}H_{Kerb}(z)} .
%  Offenbar werden die Nullstellen auf den Einheitskreis verlagert, so dass diese 
%  die gewnschten Kerben des Frequenzganges werden:
%
p1 = -0.6;  p2 = 0.8;
b  = [p2,  p1*(1+p2),  1],   a = [1,  p1*(1+p2),  p2]
hzplot((a+b)/2,a,'crt',[10,20],[-4,2]);
%
%  Die Frequenzgnge fr verschiedene Werte von  {\fontname{Courier}p2}  sind in den folgenden Bildern 
%  gezeigt.
%
p1 = -0.6;
p2 = 0.5; b1 = [(1+p2)/2, p1*(1+p2), (1+p2)/2]; a1 = [1, p1*(1+p2), p2];
p2 = 0.7; b2 = [(1+p2)/2, p1*(1+p2), (1+p2)/2]; a2 = [1, p1*(1+p2), p2];
p2 = 0.9; b3 = [(1+p2)/2, p1*(1+p2), (1+p2)/2]; a3 = [1, p1*(1+p2), p2];
p2 = 0.96;b4 = [(1+p2)/2, p1*(1+p2), (1+p2)/2]; a4 = [1, p1*(1+p2), p2];
p2 = 0.99;b5 = [(1+p2)/2, p1*(1+p2), (1+p2)/2]; a5 = [1, p1*(1+p2), p2];
fh2= fullscreen('Frequenzgang des Notchfilters');
filterplot({{b1;a1};{b2;a2};{b3;a3};{b4;a4};{b5;a5}},0,1,'lin')
legend('p2 = 0.5','p2 = 0.7','p2 = 0.9','p2 = 0.96','p2 = 0.99')
set(fh2,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
set(fh2,'KeyPressFcn','hervorhebung')
%
%  Das komplementre Filter erhlt man nach
%
%  H_{Res}(z) = (1 - H_{Kreuz}(z)) / 2 %<'FontName',MSVFORMFONT>
%
%  also mit  {\fontname{Courier}k = -1} :
%
p1 = -0.6;  p2 = 0.8;
b  = [p2,  p1*(1+p2),  1],   a = [1,  p1*(1+p2),  p2]
hzplot((a-b)/2,a,'crt',[10,20],[-7,3]);
%
%  Dieses Resonanzfilter hat an der Resonanzstelle genau die Verstrkung  {\fontname{Courier}1}  und 
%  hat bei  {\fontname{Courier}w = 0}  und  {\fontname{Courier}w = \pi}  Nullstellen: 
%
c1 = a1-b1; c2 = a2-b2; c3 = a3-b3; c4 = a4-b4; c5 = a5-b5;  
fh3= fullscreen('Frequenzgang des Resonanzfilters');
filterplot({{c1;a1};{c2;a2};{c3;a3};{c4;a4};{c5;a5}},0,1,'lin')
legend('p2 = 0.5','p2 = 0.7','p2 = 0.9','p2 = 0.96','p2 = 0.99')
set(fh3,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
set(fh3,'KeyPressFcn','hervorhebung')
%
%
%%  bung 7.7  Generieren Sie ein Mehrtonsignal der Abtastrate  8 kHz  und entfernen Sie 
%%  einzelne Tne mit der Funktion notchfilter.  Geben Sie das Ergebnis aus mit der Funktion 
%%  sound.
%