%
%
%8. Filtern im Frequenzbereich%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-2,'Color',MSVTITLCOLOR>
%
%
%
%  Die Betrachtung linearer zeitinvarianter Systeme fhrte im Abschnitt 6.1  zu einer 
%  Beschreibung des Systemverhaltens durch eine Toeplitz-Matrix  {\fontname{Courier}H}, deren Spalten 
%  die Impulsantwort zu jedem Abtastzeitpunkt des Ausgabesignals enthlt.  Der
%  Zusammenhang zwischen Inputvektor  {\fontname{Courier}x}  und Outputvektor  {\fontname{Courier}y}  ist:
%
%  y = H\cdotx          %<'FontName',MSVFORMFONT>
%
%  Die Matrix hat die Grsse  {\fontname{Courier}n^2} , wo  {\fontname{Courier}n}  die Zahl der Abtastungen im Vektor  {\fontname{Courier}x}  ist.  
%  Das macht diese Beschreibung fr die Anwendung unbrauchbar. 
%  Vor allem aber kann das Ausgangssignal erst berechnet werden, wenn das 
%  Inputsignal vollstndig aufgenommen ist.  Signalverarbeitung in Realzeit geht 
%  deshalb in dieser Form nicht.  Nimmt man jedoch eine endliche Impulsantwort an, 
%  so ist nur ein entsprechend schmales Band der Toeplitz-Matrix von Null verschieden. 
%  Dann kann man die Multiplikation  {\fontname{Courier}H\cdotx}  ersetzen durch  mehrere Multiplikationen  
%  {\fontname{Courier}v = A\cdotu} , wo  {\fontname{Courier}A}  eine Diagonalsubmatrix von  {\fontname{Courier}H}  und  {\fontname{Courier}u}  und  {\fontname{Courier}v}   entsprechende 
%  Teilvektoren von  {\fontname{Courier}x}  bzw.  {\fontname{Courier}y}  sind. 
%  Die Matrizen  {\fontname{Courier}A}  sowie die Vektoren  {\fontname{Courier}u}  mssen sich um die Breite des 
%  nichtverschwindenden Bandes von  {\fontname{Courier}H}  berlappen.
%  Das folgende Bild stellt die Verhltnisse dar.
%
fftfilgraph1
%
%  Filtern im Frequenzbereich bedeutet, dass das Signal  {\fontname{Courier}x}  transformiert wird in den 
%  Frequenzbereich, dort mit dem Frequenzgang multipliziert und anschliessend in den
%  Zeitbereich zurcktransformiert wird.
%
%  Die Transformation erfolgt mit der diskreten Fouriertransformation, die auch als 
%  Matrix-Vektor-Produkt geschrieben werden kann:
%
%  X = F\cdotx                     %<'FontName',MSVFORMFONT>
%
%  Die quadratische Matrix  {\fontname{Courier}F}  der diskreten Fouriertransformation enthlt die Elemente  
%
%  e^{-i2\pikn/N}                  %<'FontName',MSVFORMFONT>
%
%  Hierin sind  {\fontname{Courier}k}  und  {\fontname{Courier}n}  der Zeilen- bzw. Spaltenindex und  {\fontname{Courier}N}  die
%  Anzahl der Zeilen.
%
%  Die Filterung erfolgt dann nach
%
%  y = F^{-1}\cdotA\cdotF\cdotx    %<'FontName',MSVFORMFONT>
%
%  mit  {\fontname{Courier}F^{-1}\cdotA\cdotF = H} .  Der Aufwand ist nur scheinbar hoch, denn durch die 
%  Transformation in den Frequenzbereich wird aus der Toeplitz-Matrix  {\fontname{Courier}H}  die 
%  Diagonalmatrix  {\fontname{Courier}A} .  Die Matrix  {\fontname{Courier}A} enthlt auf ihrer Diagonalen den (komplexen)
%  Frequenzgang und enthlt sonst nur Nullen.  Die Fouriertransformation transformiert 
%  also vom Zeitbereich in jenen Raum, in dem die lineare Transformation  {\fontname{Courier}y = H\cdotx}  
%  durch die Diagonalmatrix  {\fontname{Courier}A}  erfolgt:   {\fontname{Courier}Y = A\cdotX} .
%
%  Zur Demonstration zeigen wir zunchst die Matrix  {\fontname{Courier}F} , die die Fouriertransformation 
%  durchfhrt:
%
N = 4;
k = (0:N-1)';
n = 0:N-1;
exp(-i*2*pi*k*n/N)
%
%%  Das Resultat steht im Kommandofenster
%
%  In MATLAB gibt es hierfr die Standardfunktion  DFTMTX:
%
help dftmtx
%
%  {\bfBeispiel:}  {\fontname{Courier}n = 4}
%
dftmtx(4)
%
%  Die Transformation der zyklischen Toeplitz-Matrix  {\fontname{Courier}H}  in den Frequenzbereich 
%  erfolgt nach
%
%  A = F\cdotH\cdotF^{-1}          %<'FontName',MSVFORMFONT>
%
%%  Fr ein einfaches Beispiel von  n < 9  geben wir die Spalte 1 von H ein, 
%%  z.B.   4  33  2  1    oder   4,  33,  2,  1   oder  ...
%%
%%  Das Resultat steht dann im Kommandofenster.
%
str = inputdlg('(mit blank oder Komma getrennt)','die Elemente einer Spalte von H eingeben:  ');
s = eval(['[', str{1}, ']'])
z = reverse([s(2:length(s)),s(1)]);  % Zeile 1 von H (zyklisch!)
H = toeplitz(s,z)
%
%  Die Matrix  {\fontname{Courier}H}  muss zyklisch Toeplitz sein, um die Periodizitt des Signals 
%  im Zeitbereich zu bercksichtigen.
%
%  Nun wird  {\fontname{Courier}H}  in den Frequenzbereich transformiert:
%
%%  Dieses erst ausfhren, nachdem oben die Matrix  H  berechnet wurde.
%%  Sowohl Real- wie auch Imaginrteil von  A  sollten nur auf der 
%%  Hauptdiagonalen von Null verschieden sein.
%
[n,h] = size(H);
A = (dftmtx(n)*H*conj(dftmtx(n))/n);
Realteil_von_A = real(A), Imaginaerteil_von_A = imag(A)
%
%  Wird das Filtern im Frequenzbereich durch die FFT von Signal-Segmenten 
%  vorgenommen, so ist wegen der zyklischen Form der Submatrizen das weiter 
%  oben gezeigte Bild etwas abzundern:
%
fftfilgraph2
%
%  Das Zusammenflicken von hin- und zurcktransformierten  Signalsegmenten wird 
%  demonstriert durch  {\fontname{Courier}fftfildemo} :
%
fftfildemo(fir1(20,0.3),64);
%
fftfildemo(fir1(40,0.3),64);
%
fftfildemo(fir1(40,0.3),128);
%
%  Zu beachten ist bei dieser Realisierung des Filterns im Frequenzbereich durch 
%  Transformation berlappender Segmente, dass die berlappung die maximale Lnge 
%  der Impulsantwort festlegt.  Die Diagonale der Matrix  {\fontname{Courier}A}  darf also nicht 
%  beliebig gewhlt werden.  Versucht man z.B. einen quasi-idealen Tiefpass
%  zu realisieren durch eine Rechteckfunktion auf der Haupdiagonalen
%
%  A_{jj} = 0  fr  N/4 + 1 \leq j \leq 3N/4    %<'FontName',MSVFORMFONT>
%  A_{jj} = 1  sonst                            %<'FontName',MSVFORMFONT>
%  A_{ij} = 0  fr  i \neq j                    %<'FontName',MSVFORMFONT>
%
%  so, entspricht dem im Zeitbereich eine unendliche Impulsantwort.  Deshalb passen 
%  die in den Zeitbereich zurcktransformierten Segmente nicht ohne Sprnge 
%  aneinander.  Hier wird dies indirekt gezeigt fr eine berlappung der 
%  Signalsegmente, die kleiner als die Zahl der Filterkoeffizienten ist:
%
fftfildemo(fir1(40,0.3),64,20)
%