%
%
%  9.3  Asynchrone Interpolation%<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-4,'Color',MSVTITLCOLOR>
%
%
%
%  Fr die asynchrone Interpolation sind alle Varianten der Interpolation mit Polynomen 
%  einschliesslich der Splines geeignet.  Die im Abschnitt 9.1 besprochenen Fehler treten
%  im asynchronen Fall allerdings genauso auf.  Die Alternative ber das Hochtasten und 
%  Filtern steht hier aber nicht zur Verfgung.  Man muss deshalb einen anderen Weg 
%  gehen.
%
%  Die inverse Fouriertransformierte des Rechteckfensters im Frequenzbereich, welches 
%  eine Periode  {\fontname{Courier}-f_s/2...+f_s/2}  herausschneidet ({\fontname{Courier}f_s} = Abtastfrequenz), ist im 
%  Zeitbereich die  sinc-Funktion:
%
%      sinc(t) = 1               fr t = 0         %<'FontName',MSVFORMFONT>
%      sinc(t) = sin(\pit) / \pit    fr t \neq 0  %<'FontName',MSVFORMFONT>
%
%%  Die Frequenz  {\fontname{Courier}\omega}  ist in folgendem Bild relativ zu  {\fontname{Courier}2\pif_s} ,
%%  Beachten Sie, dass das zugehrige Signal im Zeitbereich an allen Abtastzeitpunkten
%%  ausser bei Null eine Nullstelle hat.  Nutzen Sie die Zoomfunktion des Fensters!
%
syms w t; 
ifourierplot('Heaviside(w+pi)-Heaviside(w-pi)',w,t,[-10,10],[-20,20])
%
%  Der sinc-frmige Puls ist das zeitkontinuierliche quivalent zum diskreten 
%  Einheitspuls  {\fontname{Courier}[... 0 0 1 0 0 ...]} .  Jedes auf den Bereich  {\fontname{Courier}-f_s...+f_s}  
%  bandbegrenzte Signal  {\fontname{Courier}s(t)}  kann nach sinc-Funktionen entwickelt werden 
%  (Shannon-Entwicklung):
%         \infty                              %<'FontName',MSVFORMFONT>
%  s(t) = _{\fontsize{26}\Sigma} x_k sinc(kt) %<'FontName',MSVFORMFONT>
%        k=-\infty                            %<'FontName',MSVFORMFONT>
%
%  Umgekehrt kann man die Abtastwerte  {\fontname{Courier}x_k}  eines Signals als Koeffizienten 
%  dieser Entwicklung auffassen und entsprechend obiger Formel das zeitkontinuierliche 
%  Signal rekonstruieren.  Das geht in der Praxis jedoch nicht ganz fehlerfrei, weil 
%  ein Signal nur entweder zeitbegrenzt oder bandbegrenzt sein kann.  Je krzer ein 
%  Signalsegment ist, desto grsser wird entsprechend der Fehler der Rekonstruktion. 
%  Andererseits geht die Sinc-Funktion fr  {\fontname{Courier}t \rightarrow \infty}  nur langsam gegen Null. 
%  Deshalb muss man auch bei langen Signalsegmenten die Summe ber alle  {\fontname{Courier}k}
%  ausfhren und das fr alle gewnschten  {\fontname{Courier}t}.  Der Aufwand ist erheblich.
%
%  Die MATLAB-Funktion  {\fontname{Courier}nyquistinterpol}  veranschaulicht die  Rekonstruktion, 
%  indem die sinc-Funktion fr alle Abtastungen gezeichnet wird (eine zur Verdeutlichung 
%  rot hervorgehoben) und zustzlich die Summe ber alle Funktionen.
%
nyquistinterpol(randn(1,15),300);
%
%  Der Rechenaufwand lsst sich deutlich verringern durch Fenstern der sinc-Funktion, 
%  z.B. mit dem einfachen Hanning-Fenster.  Dadurch wird der Summationsbereich fr  {\fontname{Courier}k}
%  eingeschrnkt.  Andererseits fehlen dann die weggelassenen Komponenten, was zu 
%  fehlerhafter Rekonstruktion fhrt.  Die mit  {\fontname{Courier}N}  Summanden berechnete 
%  Rekonstruktion hat ungefhr die Qualitt der Interpolation durch Einfgung von 
%  Nullen und Filterung mit einem FIR-Filter vom Grad  {\fontname{Courier}N}.
%
%  Die Funktion  {\fontname{Courier}nyquistinterpol}  erlaubt im dritten Parameter die Angabe 
%  der halben Breite des Hanning-Fensters.  Schon fr relativ kleine Fensterbreiten {\fontname{Courier}> 2}  
%  machen die Rekonstruktionen qualitativ einen guten Eindruck:
%
nyquistinterpol(randn(1,15),300,0,4);  % Fenster:  -4...+4
%
nyquistinterpol(randn(1,15),300,0,3);  % Fenster:  -3...+3
%
nyquistinterpol(randn(1,15),300,0,2);  % Fenster:  -2...+2
%
nyquistinterpol(randn(1,15),300,0,1);  % Fenster:  -1...+1
%
%  Die Funktion  {\fontname{Courier}resample}  benutzt anstelle der sinc-Funktion Realisierungs-nahe 
%  eine Tabelle dieser Funktion mit linearer Interpolation.  Wir benutzen  {\fontname{Courier}resample}  
%  innerhalb von  {\fontname{Courier}umtastdemo} .  Diese Funktion tastet ein gegebenes Signal 
%  auf anzugebende Abtastzeitpunkte um und tastet auf die selbe Weise wieder auf 
%  die ursprnglichen Abtastzeitpunkte zurck.  Ausgegeben wird neben einer 
%  Graphik mit den Signalen die Standardabweichung der Differenz von Eingabesignal 
%  und zweimal umgetasteten Signal.
%
%  Hochtastung um  {\fontname{Courier}1/0.72} :
%
umtastdemo(randn(1,260),60,14,1,0.271,0.1)  % Fehler ca. -60 dB
%
umtastdemo(randn(1,120),24,200,1,0.271,0.1) % Fehler ca. -100 dB
%
%  Tieftastung um  {\fontname{Courier}1/1.731} , deshalb Tiefpassfilter ntig:
%
[b,a] = ellip(10,2,110,0.3);
umtastdemo(filter(b,a,randn(1,300)),40,100,1,1.731,0.1)
%
%
%%  bung 9.3  Bei der Praxis-nahen Umsetzung der Abtastrate unter Benutzung einer 
%%  sinc-Tabelle sind einige Parameter zu optimieren:
%%  (1) die Fensterbreite (Parameter k in umtastdemo)
%%  (2) die Anzahl der Sttzstellen fr die sinc-Funktion
%%      (bei umtastdemo sind dies  2*k*n + 1)
%%  (3) der RollOff-Faktor (Parameter r in umtastdemo)
%%
%%  Finden Sie Parameterkombinationen [k, n, r] fr minimalen Rechenaufwand bei den 
%%  Genauigkeiten  s < 0.001  sowie   s < 0.0001  fr folgenden Fall: 
%%
[b,a] = ellip(8,2,80,0.3);
s = umtastdemo(filter(b,a,randn(1,1000)),k,n,r,0.5971,0)
%%