function b = fedemo(g,fkt,sc)
% b = fedemo(g,fkt,sc)
% FIR-Koeffizientenberechnung fr einen durch den im String fkt vorgegebenen
% Frequenzgang.  fkt muss eine Funktion mit der freien Variablen f sein. 
% f steht dabei fr Omega/2pi, also fr f/fs. Ausgewertet wird fkt fr 0 <= f < 0.5
% und dieses wird symmetrisch zur f = 0.5 ergnzt. g ist der Filtergrad.
% Mit  sc = 'lin'  kann lineare Darstellung statt dB erreicht werden.
% Default :  fedemo(126,'round(f*10)/5')
% Das zweite Fenster zeigt das Verhalten ohne und mit Fensterung der Koeffizienten. 
% Mit Fensterung ist die Sperrdmpfung grsser, der bergangsbereich aber breiter.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Konstanten und Defaults
% =======================
if nargin<1  g = 126; end;
if nargin<2  fkt = 'round(f*10)/5'; end;
if nargin<3  sc = 0; end
if g<2 error('g > 1  nicht erfllt.'); end;
n = g + 2;
if rem(n,2)~=0 error('g muss gerade sein.'); end;
%
% Rechnung
% ========
ff = (0:n-1)/n;                            % Frequenzbereich 0 bis Abtastfrequenz
f  = ff(1:n/2);                            % Frequenzbereich 0 bis Nyquistfrequenz
w  = eval(fkt);                            % Frequenzgang 0 bis Nyquistfrequenz
wf = [w,w(n/2:-1:1)];                      % Frequenzgang 0 bis Abtastfrequenz
dftwf = ifft(wf);                          % IDFT davon
b  = real([dftwf(n/2:-1:1),dftwf(2:n/2)]); % Impulsantwort
bf = b.*hamming(n-1)';                     % Fensterung mit Hamming-Fenster
f  = (0:99)/200;                           % Frequenzbereich 0 bis Nyquistfrequenz
wf = eval(fkt);                            % Wunschfrequenzgang
%
% Darstellung
% ===========
figh = fullscreen('realisierter Frequenzgang');
set(figh,'KeyPressFcn','hervorhebung')
if sc=='lin'
   filterplot({b;bf},0,1,sc,0,1.1);        % realisierte Frequenzgnge linear
   y = abs(wf);                            % Wunschfrequenzgang linear 
else
   filterplot({b;bf},0,1);                 % realisierte Frequenzgnge in dB
   y = max(-100,20*log10(max(10^-5,abs(wf)))); 
end
lineobj = get(gca,'Children');
set(lineobj(1),'Color','r')
set(lineobj(2),'Color','b')
line(2*f,y,'Color','k')                    % Wunschfrequenzgang
legend('Entwurf mit Rechteckfenster','Entwurf mit Hammingfenster','Wunschfrequenzgang');
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
