function filterort(b,a,sc)
% filterort(b,a,sc)
% Ortskurve des Frequenzganges fr Filter:
% b, a       :  Filterkoeffizienten (a = 1 bei FIR-Filtern)
% sc = 'lin' :  lineare Skala fr den Radius (0...1.2)
% sc = 'lod' :  dB-Skala fr den Radius (-80...+10 dB)

% Autor:  Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<3     sc = 'lin';             end
if nargin<2      a = 1;                 end
if nargin<1  [b,a] = ellip(8,1,60,0.3); end
%
% Frequenzgangberechnung
% ======================
fz = freqz(b,a,0:0.0002:1,2);              % Frequenzgang
if strncmpi(sc,'log',3)
   v  = 1;                                 % x-Versatz fr Textanfang
   q  = 100;                               % halbe Achsenlnge
   rs = [80 60 40 20 0];                   % Gitterkreisradien
   ds = rs - 80;                           % Skalenversatz
   rdb= 20*log10(abs(fz)) + 80;            % Radius
   fz = (rdb>0).*rdb./(abs(fz)+eps).*fz;   % Radius in dB, Winkel bleibt
else
   v  = 0.01;                              % x-Versatz fr Textanfang
   q  = 1.2;                               % halbe Achsenlnge
   rs = [0.2 0.4 0.6 0.8 1.0];             % Gitterkreisradien
   ds = rs;                                % kein Skalenversatz
end
fp = fz(1:100:length(fz));                 % Markierungspunkte fr Text
%
% Darstellung
% ===========
fh = fullscreen('Ortskurve','w',2); 
plot(fz)
line(real(fp),imag(fp),'LineStyle','none','Marker','.','MarkerSize',5,'Color','k')
line(q*[0 -1; 0 +1],q*[-1 0; +1 0],'lineStyle',':','Color',0.7*[1 1 1])
for k = 1:length(fp)
%   text(real(fp(k))+v,imag(fp(k)),sprintf('%1.2f',(k-1)/(length(fp)-1)),'FontSize',8)
   text(real(fp(k)),imag(fp(k)),sprintf('  %1.2f',(k-1)/(length(fp)-1)),'FontSize',8)
end
f = (0:200)/200;                           % Punkte fr Gitterkreise
for k = 1:length(rs)
   kreis = rs(k)*exp(i*2*pi*f);
   line(real(kreis),imag(kreis),'LineStyle',':','Color',0.7*[1 1 1])
   text(v,rs(k)+2*v,sprintf('%2.1f',ds(k)),'Color',0.7*[1 1 1])
end
axis(q*[-1 1 -1 1]); axis square; axis off

