function fintpol(methode,f1,f2,r)
%  fintpol(methode,f1,f2,r)
%  fintpol demonstriert den Fehler bei Hochtastung um den Faktor 2
%  bei Interpolation mit der Methode 'methode'
%
%  Parameter:
%  methode =
%      'nearest' - nearest neighbor interpolation
%      'linear'  - linear interpolation
%      'spline'  - cubic spline interpolation
%      'cubic'   - cubic interpolation
%  f1 und f2 :  zwei Sinusfrequenzen  0 <= f1,f2 <= 1 (Nyquistfrequenz)
%  r :  Amplitude eines weissen Rauschens

%  Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
%  Defaults
%  ========
if nargin<5  m = 2; end
if nargin<3  f2 = 0.8; end
if nargin<2  f1 = 0.3; end
if nargin<4  r = 0; end
if nargin<1  methode = 'linear'; end
fsiz = 12;                             % FontSize
%
%  Signalerzeugung Interpolation und FFT
%  =====================================
n = 256;
x = r*randn(1,n) + sin(pi*f1*(0:n-1)) + sin(pi*f2*(0:n-1));
y = interp1(x,(1:n-1)+0.5,methode);    % Interpolation
z = nullein(x,1) + [0,nullein(y,1),0]; % Einfgen interpolierter Werte
X = abs(fft(x,n));                     % Inputspektrum (eine Periode)
Z = 0.5*abs(fft(z,2*n));               % Outputspektrum (eine Periode)
%
%  Darstellung
%  ===========
v = 1:n/2;
w = 1:n;
h = fullscreen('Interpolationsfehler');
plot(w-1,[X(w);Z(w)],'LineWidth',2)
patch([n,0,w-1],abs([0,0,X(v)-Z(v),Z(n/2+1:n)]),'r')
legend('Spektrum des Inputsignals',...
       'Spektrum des hochgetasteten Signals','Fehler',0)
yl = get(gca,'YLim');
set(gca,'XTick',[0,n/2,n],'XTickLabel',[' 0 ';'0.5';' 1 '],'YTick',[])
line([n/2,n/2],yl,'Color',0.5*[1 1 1],'LineStyle',':')
axis([0,n,0,yl(2)])
tx = sprintf('Fehler der Interpolation (%s) im Frequenzbereich',methode);
title(tx,'FontSize',18)
xlabel('Frequenz relativ zur Abtastfrequenz des Inputs bzw. der Nyquistfrequenz des hochgetasteten Signals',...
       'FontSize',fsiz)
ylabel('Betrag der Fouriertransformierten','FontSize',fsiz)
