function bb = halbbf(b)
% bb = halbbf(b)
% Erzeugung eines Halbbandbandfilters aus einem Tiefpass mit dem
% Koeffizientenvektor b.
% Der Durchlassbereich muss grsser als  0.5  sein.
% Aus dem Tiefpass wird durch spektrale Rotation um pi ein zum
% Tiefpass symmetrischer Hochpass generiert und diese beiden 
% werden in Serie verwendet, d.h. ihre Impulsantworten gefaltet.
% Wird halbbf ohne Ausgabe aufgerufen, so werden zwei Bilder erzeugt.

% K. von der Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<1  b = fir1(30,0.7); end  % ein einfacher Tiefpass
%
c = -real(specrot(b,pi));    % zum Tiefpass symmetrischer Hochpass
bb= conv(b,c);               % Halbbandbandfilter
%
if nargout<1
   %
   % Darstellung
   % ===========
   bmax = max([b,c,bb])+0.05; bmin = min([b,c,bb])-0.05;
   h(1) = fullscreen('Frequenzgnge');
   set(h(1),'KeyPressFcn','hervorhebung')
   set(h(1),'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
   filterplot({b;c;bb},0,1,0,-110,10);
   hl = legend('Originalfilter','symmetrischer Hochpass','Halbbandbandfilter');
   set(hl,'Position',[0.383623 0.178108 0.269859 0.080244])
   h(2) = fullscreen('Impulsantworten');
   subplot(3,2,1); stem(b); title('Originalfilter'); 
   set(gca,'xlim',[0,length(b)+1],'ylim',[bmin,bmax])
   subplot(3,2,3); stem(c); title('symm. Hochpass'); 
   set(gca,'xlim',[0,length(c)+1],'ylim',[bmin,bmax])
   subplot(3,2,5); stem(bb); title('Halbbandfilter'); 
   set(gca,'xlim',[0,length(bb)+1],'ylim',[bmin,bmax])
   subplot(3,2,2); filterplot(b);
   subplot(3,2,4); filterplot(c);
   subplot(3,2,6); filterplot(bb);
end
