function c = halbhilb(g);
%  c = halbhilb(g)
%  Erzeugung eines Hilbertfilters aus einem Halbbandbandtiefpass durch
%  spektrale Rotation um pi/2  (Demo).
%  Wird  halbhilb  ohne Ausgabe aufgerufen, so wird der Frequenzgang
%  geplottet.
%  g ist der gewschte Filtergrad.  g muss gerade sein.
%  Ist g durch 4 teilbar, dann verschwindet der erste und der letzte 
%  Koeffizient. In diesem Fall wird g um 2 vermindert.
%  Wird halbhilb ohne Ausgabe aufgerufen, so werden drei Bilder geplottet.
%  Fr praktische Flle ist remez(....,'Hilbert') besser.

% K. von der Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<1  g = 30; end
if g<2 error('der Filtergrad muss positiv sein.'); end;
if rem(g,2)==1 error('Der Filtergrad muss gerade sein.'); end;
if rem(g/2,2)==0  g = g - 2; end
fsiz = 13;              % FontSize
%
b = fir1(g,1/2);        % einfacher Entwurf eines Halbbandtiefpasses
d = specrot(b,pi/2);    % Halbbandtiefpass um pi/2 rotiert ist komplex
c = 2*real(d);
%
if nargout<1
   %
   % Darstellung
   % ===========
   h(1) = fullscreen('spektrale Rotation um pi/2','w',0,[2 1; 1 1]);
   set(h(1),'KeyPressFcn','hervorhebung')
   set(h(1),'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
   filterplot({b;c},-2,2,'lin',-0.1,1.1);
   title('Entwurf eines Hilbertfilters durch spektrale Rotation',...
         'FontSize',fsiz);
   legend('Halbbandtiefpass','Hilbertfilter')
   %
   h(3) = fullscreen('Phasengang','w',0,[2 1; 2 1]);
   fr = freqz(real(d));
   fi = freqz(imag(d));
   f  = (0:length(fr)-1)/length(fr);
   plot(f,unwrap((angle(fr)-angle(fi)))*180/pi)
   axis([0,1,0,100])
   title('Phasendifferenz zwischen Real- und Imaginrteil','FontSize',fsiz)
   xlabel('Omega','FontSize',fsiz)
   ylabel('Grad','FontSize',fsiz)
   %
   h(2) = fullscreen('Impulsantworten und Frequenzgnge');
   mx = max([b,c])+0.05; mn = min([b,c])-0.05; 
   subplot(2,2,1); stem(b); 
   title('Halbbandprototyp','FontSize',fsiz);
   axis([0,g+2,mn,mx])
   subplot(2,2,3); stem(c); title('Hilbertfilter','FontSize',fsiz);
   axis([0,g+2,mn,mx])
   subplot(2,2,2); filterplot(b);
   subplot(2,2,4); filterplot(c);
end