function b = hblowpass(g,r)
% b = hblowpass(g,r)
% Entwurf eines Halbbandtiefpasses fr  g=4*k+2 (k=0,1,2,...) nach 
% folgendem Verfahren:
% Mit REMEZ wird ein Tiefpass-Prototyp entworfen.  Der hierzu 
% komplementre Hochpass wird um pi rotiert zu einem zweiten 
% Tiefpass.  Das arithmetische Mittel beider Tiefpsse ist das Resultat.
% Das Verfahren liefert nicht exakt Equiripple-Filter.
% Fr kleine r liefert es u.U. sehr grosse Welligkeit.
% 
% g :  Filtergrad
% r :  Grenze des Durchlassbereiches
% Ausgegeben werden die Filterkoeffizienten b.
% Werden die Koeffizienten nicht zugewiesen, so gibt es eine Graphik.

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<2   r = 0.1; end;
if nargin<1   g = 10;  end;
if rem(g+2,4) error('hblowpass:  Filterorder must be  4*k+1 (k=0,1,2,...)'); end

% Filterentwurf
% =============
gh = g/2 + 2;                          % Filtermitte
b1 = remez(g+2,[0 r 1-r 1],[1 1 0 0]); % Tiefpassprototyp
b2 = -b1.*((-1).^(0:g+2));             % Komplementrfilter und           
b2(gh) = b2(gh) + 1;                   % dessen Rotation
b  = (b1 + b2)/2;                      % Mittelwert beider Filter
b([gh-2:-2:1,gh+2:2:end]) = 0;         % Halbbandfilter:
b  = b(2:end-1);                       % Nullen erzwingen

% Graphik
% =======
if nargout<1
   fh = fullscreen('Halfband Filter','w',3); 
%   filterplot({b1;b2;b},0,1,'lin',-0.1,1.1)
   filterplot({b1;b2;b},0,1,'log',-120,10)
   title(['Halfband Lowpass Filter of Order ',num2str(g)],'FontSize',15)
end