function bb = hilb2demo(g);
% bb = hilb2demo(g)
% Erzeugung eines Hilbertfilters aus einem Halbbandbandtiefpass.
% und Demonstration der Phasenverschiebung.
% Es wird ein periodisches Rechtecksignal erzeugt und durch eine Kaskade 
% von 4 Hilbertfiltern geschickt. Nach dem ersten Filter ergibt sich ein 
% verzerrtes Signal, nach dem zweiten Filter das invertierte Rechtecksignal, 
% nach dem dritten Filter das Inverse des zweiten Filters und nach dem 
% vierten Filter muss das Inputrechteck wieder erscheinen.
% Gezeigt wird auf zwei Bildern das Ergebnis nach dem ertsen und nach dem vierten Filter.
% Der Parameter g legt den Filtergrad fest (gerade, aber nicht teilbar durch 4).

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<1  g = 186; end;
if g>186|g<2 error('Der Filtergrad ist in dieser Demo beschrnkt auf  1 < g < 187.'); end;
if rem(g,2)==1 error('Der Filtergrad muss gerade sein.'); end;
if rem(g/2,2)==0 error('Der Filtergrad darf nicht durch 4 teilbar sein.'); end;
d = g/2;
%
% Filterberechnung, Signalerzeugung und -verarbeitung
% ===================================================
bb= 2*real(specrot(fir1(g,1/2),pi/2));       % Berechnung eines Hibertfilters
n = 1024;                                    % Anzahl der Abtastungen
t = (1:n)/n;                                 % Zeitbereich 0...1 in n Punkten
zpft = 2*pi*n*1.111*t/64;                    % Phasenvektor = 2*pi*f*t
s = 0;
for k=1:2:25  s = s + sin(k*zpft)/k; end;    % Rechtecksignal
y1 = filter(bb,1,s);                         % Ausgang des Hilbertfilters 1
y2 = filter(bb,1,y1);                        % Ausgang des Hilbertfilters 2
y3 = filter(bb,1,y2);                        % Ausgang des Hilbertfilters 3
y4 = filter(bb,1,y3);                        % Ausgang des Hilbertfilters 4
x1 = delay(s,d);                             % Verzgerung wie 1 Hilbertfilter
x4 = delay(delay(delay(x1,d),d),d);          % Verzgerung wie 4 Hilbertfilter
%
% Darstellung
% ===========
h1 = fullscreen('nach dem ersten Hilbertfilter');
plot(t(450:550),x1(450:550),t(450:550),y1(450:550),'r');
xlabel('blau:  Eingang (verzgert);   rot:  Ausgang des Hilbertfilters','FontSize',12);
grid on;

h2 = fullscreen('nach dem vierten Hilbertfilter');
plot(t(450:550),x4(450:550),t(450:550),y4(450:550),'r');
xlabel('4 Hilbertfilter kaskadiert;  blau: Eingang (verzgert);  rot: Ausgang der Kaskade','FontSize',12);
grid on;
