function bb = hilbdemo(g);
% bb = hilbdemo(g)
% Erzeugung eines Hilbertfilters aus einem Halbbandbandtiefpass.
% und Demonstration der Phasenverschiebung mit einem Chirp-Signal.
% Gezeigt wird im Zeitbereich der Chirp sowie im komplexen
% Signalraum die Ausgabe des Hilbertfilters: ein Kreis.
% Der Parameter g gibt den Filtergrad an (gerade, aber nicht teilbar durch 4).

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin <1  g = 30; end;
if rem(g,2)==1 error('Der Filtergrad muss gerade sein.'); end;
if rem(g/2,2)==0 error('Der Filtergrad darf nicht durch 4 teilbar sein.'); end;
%
% Filterberechnung, Signalerzeugung und -verarbeitung
% ===================================================
bb= 2*real(specrot(fir1(g,1/2),pi/2));         % Berechnung eines Hibertfilters
n = 1000;                                      % Anzahl der Abtastungen
t = (1:n)/n;                                   % Zeitbereich 0...1 in n Punkten
s = sin(2*pi*(250+45*sin(2*pi*1*t)).*t);       % Frequenz-moduliertes Signal
y = filter(bb,1,s);                            % Ausgang des Hilbertfilters;
x = filter([zeros(1,g/2),1,zeros(1,g/2)],1,s); % verzgertes Signal
%
% Darstellung
% ===========
h1 = fullscreen('Zeitbereich');
plot(t(600:700),x(600:700),t(600:700),y(600:700));
xlabel('Zeit','FontSize',12); ylabel('Signal','FontSize',12);
title(['Mit Chirp frequenzmoduliertes Sinus-Signal: Demo der ',...
      'frequenzunabhngigen Phasenverschiebung des Hilbertfilters'],...
      'FontSize',12);
legend('Eingangs-Signal','Ausgang des Hilbertfilters');
axis([0.6,0.7,-1.3,1.3]);

h2 = fullscreen('Signalraum');
plot(x(100:900),y(100:900),'r.');
xlabel('Realteil (um g/2+1 Samples verzgerter Input)','FontSize',12); 
ylabel('Imaginrteil (Output des Hilbertfilters)','FontSize',12);
title('Signalraum','FontSize',12);
line([-1.2,1.2],[0,0])
line([0,0],[-1.2,1.2])
axis([-1.2,1.2,-1.25,1.25]);
axis square;
