function [y,z] = homomorpha(x,b)
% [y,z] = homomorpha(x,b)
% Das Signal x wird logarithmiert und dann mit einem Filter mit 
% den Koeffizienten b und seinem Komplementrfilter gefiltert. 
% y ist der mit der Exponentialfunktion zurcktransformierte 
% Durchlassanteil und z der entsprechende Komplementranteil.
% Anstelle von b kann auch die Grenzfrequenz 0<b<1 fr einen 
% Tiefpass angegeben werden, der dann mit FIR1 entworfen wird.

% Defaults
% ========
if nargin<2  b = 0.03; end
if length(b)==1
   g = 200;
   b = fir1(g,b);
else
   g = length(b)-1;
end
if nargin<1
   t = 0:2000;
   x = (1 + 0.8*sin(2*pi*0.005*t)).*sin(2*pi*0.1*t);
end

% homomorphe Transformation
% =========================
[xx,d] = real2analyt(x,400);
lx = log(xx);

% Filter
% ======
ly = filter(b,1,lx);
lz = delay(lx,g/2) - ly;

% Rcktransformation
% ==================
yy = exp(ly);
zz = exp(lz);
y  = real(y);
z  = real(z);

if nargout>0  break; end

% Graphik
% =======
fh1 = fullscreen('Filter');
filterplot(b)

fh2 = fullscreen('Rcktransformation');
plot([delay(x,g/2+d);y;z]')
axis([1000 1400 -2 +2])

fh3 = fullscreen('Homomorph');
plot(real([delay(lx,g/2);ly;lz]'))
legend('log(x)','log(y)','log(z)')
axis([1000 1400 -2  +2])
