function [fh,ah] = hzplot(b,a,coord,view,zl)
%  [fh,ah] = hzplot(b,a)  zeichnet  H(z) = Num/Den  in der z-Ebene 
%  im Bereich -2...+2 fr den Real- und Imaginrteil von Z. 
%  b und a sind die Polynomkoeffizienten von Num bzw. Den.
%  coord = 'crt' : normales kartesisches Gitter (Default)
%  coord = 'cyl' : Zylinderkoordinaten
%  view  gibt den Betrachtungswinkel an. 
%  view = [0 90] ergibt z.B. einen Pseudocolorplot.
%  MIt zl kann der Darstellungsbereich in z-Richtung beschrnkt werden.
%  Das Bild kann mit der Maus gedreht werden.
%  Ausgegeben werden Figurehandle fh und Axeshandle ah.  

%  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<4 view = [10,20]; end                 % Default: Blickrichtung
if nargin<3 coord = 'crt'; end                  % Default: Zylinderkoordinaten
if nargin<2  a = 1; end                         % Default: FIR-Filter
if nargin<1  b = fir1(6,0.4); end               % Default: Tiefpass
fsz = 14;                                       % FontSize fr Beschriftung
%
% Plotkoordinaten
% ===============
if strcmp(coord,'cyl')
   n  = 90;                                     % Phipunkte
   m  = 40;                                     % Radiuspunkte
   [x,y] = pol2cart((ones(m,1)*(0:n)/n*2*pi)',ones(n+1,1)*(0:(m-1))/m*2);
   z  = x + i*y;                                % komplexe Ebene
else
   n  = 100;                                    % Kantenlnge des Plots
   zz = 4*(-n/2:(n-1)/2)/n;                     % Bereich fr Real / Imaginrteil
   z  = ones(n,1)*zz + i*zz'*ones(1,n);         % komplexe Ebene
end
w = (0:511)/256*pi;                             % 0 ... 2 pi in 512 Punkten
zek = cos(w) + i*sin(w);                        % Einheitskreis
%
% Funktion
% ========
y  = polyval(b,z)./polyval(a,z);                % Funktion  NUM / DEN
ly = log(abs(y));                               % Funktion logarithmisch
my = max(max(ly));                              % davon das Maximum
if nargin>4
   mu = zl(2);
   ml = zl(1);
else
   mu = inf;
   ml = my - 8;
end
ly = min(mu,ly);                                % oben abschneiden wegen Caxis
ly = max(ml,ly);                                % unten abschneiden wegen Caxis
yek= polyval(b,zek)./polyval(a,zek);            % Funktion  NUM/DEN auf Einheitskreis
ylk= log(abs(yek));                             % logarithmisch auf Einheitskreis
%
% Darstellung
% ===========
if screen==1  pos = [1 30 550 550]; else pos = [5 32 655 717]; end;
fh = fullscreen('Z-Trans 3D');
set(fh,'position',pos)
colormap(hot)
if strcmp(coord,'cyl')
   zp = [flach(z(1:n,1:m-1)); flach(z(2:n+1,1:m-1));
         flach(z(2:n+1,2:m)); flach(z(1:n,2:m))];
   yp = [flach(ly(1:n,1:m-1));flach(ly(2:n+1,1:m-1));
         flach(ly(2:n+1,2:m));flach(ly(1:n,2:m))];
   patch(real(zp),imag(zp),yp,mean(yp)/my)
else
   surf(zz,zz,ly); axis square; axis([-2,2,-2,2,ml,mu]) 
end
line(real(zek),imag(zek),ylk,'Color','k','LineWidth',2)
xlabel('real(Z)','FontSize',fsz); 
ylabel('imag(Z)','FontSize',fsz); 
zlabel('log(abs(Z-Transformierte))','FontSize',fsz)
title('Betrag der bertragungsfunktion','FontSize',fsz)
[hh,yh] = hist(flach(ly));
csy = cumsum(hh)/length(flach(ly));
axis square
ah = gca;
if any(isnan(yh)) set(ah,'View',view)
elseif nargin>4
   set(ah,'View',view,'Zlim',[ml,mu])
else
   set(ah,'View',view,'Zlim',[min(yh.*(csy>0.01))-8,max(yh.*(csy<0.99))+8])
end
rotate3d on

