function  b = idealtpdemo(fs,gr,grad)
% b = idealtpdemo(fs,gr,grad)
% Approximation des idealen Tiefpasses fr die
% Grenzfrequenz  gr  relativ zur Nyquistfrequenz.
% fs  ist die Abtastfrequenz in Hz.
% grad  ist der Filtergrad, d.h. es werden zur
% Faltung im Zeitbereich nur  grad+1  Abtastungen
% bercksichtigt und die brigen als Null angenommen.
% Methode: Die Impulsantwort des idealen Tiefpasses ist die
% Funktion  sin(x)/x. Diese wird passend abgetastet und dem
% Grad  grad  entsprechend hart abgeschnitten (Rechteckfenster).

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<3  grad = 60; end
if nargin<2  gr = 0.4;  end
if nargin<1  fs = 8000; end
fsiz = 12;                                % FontSize
%
% Berechnung
% ==========
if rem(grad,2)==0  t=(-grad/2:grad/2)/fs; % Zeitbereich
else  t=(-(grad+1)/2:(grad-1)/2)/fs; 
end
fg = fs*gr/2;                             % Grenze des Tiefpasses 
b  = sin(2*pi*fg*(t+eps))./(t+eps)/pi/fs; % Impulaantwort
%
% Darstellung
% ===========
h(1) = fullscreen('Impulsantwort',   'w',1,[2 1; 1 1]);
for k = 1:grad+1
   if isnan(b(k))  b(k) = 2*fg/fs ; end   % b bei Null definieren
   line([t(k),t(k)],[0,b(k)],'Color','r') % zeichnen
end
line([t(1),t(grad+1)],[0,0],'Color','k')
line(t,b,'Marker','.','Color','r','LineStyle','none','MarkerSize',10);
set(gca,'ylim',1.1*get(gca,'ylim'))

h(2) = fullscreen('Frequenzgang',    'w',1,[2 1; 2 1]);
filterplot(b,0,1,'lin',0,1.1)

h(3) = fullscreen('Durchlassbereich','w',1,[2 3; 2 3]);
filterplot(b,0,gr,0,-1,1)

figure(h(1))
