function x0 = ipoldemo(g,n)
% x0 = ipoldemo(g,n)
% Einfache Demo fr ein Interpolationsfilter mit Aufwrtstastung *2.
% Interpolationsfilter ist hier das Halbbandfilter  fir1(g,0.5).
% Parameter:
% g    Grad des Interpolationsfilters (gerade!  Default: 14)
% n    Lnge der dargestellten Abtastsequenz   (Default: 20)
% Dargestellt wird: 
% (1) eine Sequenz von n zuflligen Abtastwerten,
% (2) eingefgte Nullen
% (3) interpolierte Werte

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<2 n = 20; end
if nargin<1 g = 14; end
if rem(g,2)==1 error('Der Filtergrad muss gerade sein !'); end
%
% Rechnung
% ========
m = n + g;           % Lnge der gesamten Abtastsequenz
x = randn(1,m);      % Erzeugung einer Sequenz
b = fir1(g,0.5);     % Interpolationsfilter
v = [zeros(1,g/2),1,zeros(1,g/2)]; % Verzgerung
hx= nullein(x,1);    % Hochabtastung um Faktor 2 (Einfgung von 0)
vx= filter(v,1,hx);  % verzgerte Sequenz
bx= filter(b,1,hx);  % Sequenz nach Interpolationsfilter 
mm= 2*m-1;           % Darstellungsende
gg= mm - n;          % Darstellungsanfang
t = gg:mm;           % Zeitbereich der Darstellung
%
% Darstellung
% ===========
h = fullscreen('Interpolation');
plot(t,2*bx(gg:mm),'r*-',t,vx(gg:mm),'bo');
set(gca,'xlim',[gg,mm])
xlabel('Zeit'); ylabel('Signal');
title('Hochtastung mit Interpolation','FontSize',16);
legend('interpoliertes Signal','Input mit eingefgten Nullen',0);
if g<8 text(gg+5,-1,'ACHTUNG: kein Halbbandfilter!'); end
