function b = komplexfir(g,fkt,sc)
%
% !!!! in Arbeit !!!! geht zur Zeit nur fr reelle Funktionen fkt
%
% b = fedemo(g,fkt,sc)
% FIR-Koeffizientenberechnung fr einen durch den im String fkt vorgegebenen
% komplexen Frequenzgang eines nicht-kausalen FIR-Filters. 
% g   :  Filtergrad (muss gerade sein)
% fkt :  Funktion der freien Variablen f sein. 
%        f steht dabei fr Omega/2pi, also fr f/fs. 
%        Ausgewertet wird fkt fr 0 <= f < 0.5
%        und dieses wird symmetrisch zur f = 0.5 ergnzt. 
%        f muss im String vorkommen. Fr ein Hilbertfilter kann 
%        man z.B schreiben  'i*(f<1)'
% sc = 'lin' :  lineare Darstellung statt dB erreicht werden.
%
% Die Grafik zeigt die Phasengnge der nicht-kausalen Filter.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Konstanten und Defaults
% =======================
if nargin<1  g = 126; end;
if nargin<2  fkt = 'round(f*10)/5'; end;
if nargin<3  sc = 0; end
if g<2 error('g > 1  nicht erfllt.'); end;
n = g + 2;
if rem(n,2)~=0 error('g muss gerade sein.'); end;
fsiz = 13;                                 % FonSize
%
% Rechnung
% ========
ff = (0:n-1)/n;                            % Frequenzbereich 0 bis Abtastfrequenz
f  = ff(1:n/2);                            % Frequenzbereich 0 bis Nyquistfrequenz
w  = eval(fkt);                            % Frequenzgang 0 bis Nyquistfrequenz
wf = [w,conj(w(n/2-1:-1:2))];              % Frequenzgang 0 bis Abtastfrequenz
dftwf = ifft(wf);                          % IDFT davon
b  = [dftwf(n/2:-1:1),conj(dftwf(2:n/2-1))]; % Impulsantwort
bf = b.*hamming(n-2)';                     % Fensterung mit Hamming-Fenster
%
% Darstellung
% ===========
fh1 = fullscreen('KomplexFIR');
set(fh1,'KeyPressFcn','hervorhebung')
f   = (0:99)/200;                          % Frequenzbereich 0 bis Nyquistfrequenz
wf  = eval(fkt);                           % Wunschfrequenzgang
h   = freqz(b,1,2*pi*f);                   % erzielter Frequenzgang
hf  = freqz(bf,1,2*pi*f);                  % erzielter Frequenzgang mit Fensterung
subplot(2,1,1)
if sc=='lin'
   line(f,abs(h),'Color','b')              % realisierter Frequenzgang linear
   line(f,abs(hf),'Color','r')             % realisierter Frequenzgang linear
   line(f,abs(wf),'Color','k')             % Wunschfrequenzgang linear
   ylabel('Dmpfung (linear)','FontSize',fsiz)
else
   line(f,20*log10(max(10^-5,abs(h))),'Color','b')  % realisierter Frequenzgang log
   line(f,20*log10(max(10^-5,abs(hf))),'Color','r') % realisierter Frequenzgang lod
   line(f,20*log10(max(10^-5,abs(wf))),'Color','k') % Wunschfrequenzgang log
   ylabel('Dmpfung (dB)','FontSize',fsiz)
end
title('Amplituden-Frequenzgang','FontSize',fsiz)
legend('Entwurf mit Rechteckfenster','Entwurf mit Hammingfenster','Wunschfrequenzgang');
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
subplot(2,1,2)
line(f,unwrap(angle(h)+pi*f*g),'Color','b')  % Phasengang
line(f,unwrap(angle(hf)+pi*f*g),'Color','r') % Phasengang
line(f,unwrap(angle(wf)),'Color','k')        % Wunschphasengang
title('Phasen-Frequenzgang','FontSize',fsiz)
legend('Entwurf mit Rechteckfenster','Entwurf mit Hammingfenster','Wunschfrequenzgang');
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
