function kompexsig(fsin,f1,f2,snr,m,velocity,blick,nur)
% kompexsig(fsin,f1,f2,snr,m,velocity,blick,nur)
% Demo fr analytische Signale. (Demo auch ohne Parameter) 
% Es wird ein Sinus-Signal der Frequenz fsin erzeugt und 
% ein weisses Rauschen hinzugefgt. Dieses Signal wird mit 
% einem IIR-Bandpass vom Grad 8 und den Passbandgrenzen f1 und f2 
% gefiltert, so dass ein bandbegrenztes Signal mit Signal/Rauschver-
% hltnis snr entsteht. Die Bandbegrenzung erfolgt immer in der 
% Halbperiode, in der sich das Sinus-Signal befindet. 
% Anschliessend geschieht die Wandlung in ein analytisches Signal 
% und die Darstellung als Bewegtbild.
%
% fsin    :  Frequenz des Sinus-Signals    (Nyquistfrequenz = 1)
% f1, f2  :  Bandgrenzen des Signalfilters (Nyquistfrequenz = 1)
%            Das Hilberfilter lsst nur den Bereich 0.02..0.98 zu.
%            Angaben in beliebigen Halbperioden sind erlaubt.
% snr     :  Signal/Rauschverhltnis       (dB)
%            Ist snr > 9999, so wird nur das ungefilterte Signal gezeigt.
%            In diesem Fall kann fr fsin optional ein Vektor von zwei 
%            Komponenten eingegeben werden: [Frequenz, Phase] 
%                                          (Freqenz; 0 <= Phase < pi).
% m       :  Lnge der darzustellenden Sequenz an (Default=25).
% velocity:  Geschwindigkeit der Animation (0.1 ... 10). 
% blick   :  Blickrichtung entsprechend view:
%            blick=[90,0] sieht genau lngs der Zeitachse; default=[12,10].
% nur     :  falls mit beliebigem Wert angegeben, so erfolgt nur die 
%            Darstellung der Animation ohne die Filter.
%
% Im ersten Bild werden der Frequenzgang der benutzten Filter gezeigt 
% und die Spektren des Signals. 
%
% Das zweite Bild zeigt die Animation. Diese kann interaktiv 
% beeinflusst werden. Leider ist dei Reaktion bei verschiedenen 
% MATLAB-Version/Betriebssystem-Kombinationen nicht immer 
% zufriedenstellend:
%
% Anhalten der Animation ist mglich durch Drcken der Taste p.
% Jede Taste startet die Animation wieder.
% Die Animation wird abgebrochen mit der Taste s.
% Die Geschwindigkeit wird verndert mit den Tasten + und -.
% Der Blickwinkel kann mit den Tasten r l h t verndert werden.
% mit den Tasten r l h t sowie mit der Maus gedreht werden.
%
% Wird komplexsig ganz ohne Parameter aufgerufen, so wird 
% komplexsig(0.1,0.05,0.15,10000,100,1,[25 25],0) dargestellt.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
lw = 1.5;                      % LineWidth
if nargin<1  fsin = 0.1; end
if nargin<2  f1 = 0.05;  end
if nargin<3  f2 = 0.15;  end
if nargin<4  snr= 10000; end
if nargin<5  m  = 100;   end   % Lnge der Darstellung im Zeitbereich
if nargin<6  velocity=1; end   % Darstellungsgeschwindigkeit
if nargin<7  blick = [25 25]; end
if nargin<8  nur = 0;    end
if snr<0 error('snr kann nicht kleiner als 0 sein'); end;
if length(fsin)==2  fsn = fsin(1); ph = fsin(2); 
else if length(fsin)==1 fsn = fsin; ph = 0; else fsn = 0; ph = 0; end
end
fsn = mod(1+fsn,2) - 1;
fl = abs(mod(1+f1,2)-1);
fu = abs(mod(1+f2,2)-1);
if fl>fu  h = fl; fl = fu; fu = h; end
if snr<10000
   if floor(f1)~=floor(f2) 
      error('f1 und f2 mssen in der selben Halbperiode liegen'); end
   if fl<0.02 | fu>0.98
      error('f1 oder f2 ist nicht passend'); 
   end;
   if fu-fl < 0.04 error('f2 - f1 muss grsser als 0.04 sein'); end;
   if (abs(fsn)<fl)|(abs(fsn)>fu) hinweis='Das Signal liegt nicht im Bandpass.', end;
end
fsz = 12;                % FontSize fr Beschriftung
%
% Filterentwurf
% =============
ga = 8;                  % Filtergrad fr IIR-Bandpass
gh = 126;                % Filtergrad fr Hilbertfilter
[ba,aa] = ellip(ga/2,0.5,60,[fl,fu]);     % Bandpassfilterkoeffizienten
bh = remez(gh,[0.1 0.9],[1 1],'Hilbert'); % Hibertfilter
% zum Hilbertfilter passende Verzgerung:
bv = [zeros(1,gh/2),1,zeros(1,gh/2)];     % Koeffiz. der Verzgerung
%
% Signalerzeugung
% ===============
xanf = 1300;             % Darstellungsanfang
xend = xanf+m-1;         % Darstellungsende
xe= xanf+1023;           % Ende fr die 1024-FFT
n = xanf+max(1023,m)+200;% Sample-Lnge
t = 1:n;                 % Zeitbereich in Abtastschritten
z = (1024:-1:1)/512;     % Frequenzbereich 0..Abtastfrequenz entspricht 0..2
sn= 1+(f2-f1)*snr;       % SNR auf Bandbreite umrechnen
if length(fsin)>2
   x = filter(ba,aa,fsin);                      % direkter Input
   y = filter(bv,1,x)+i*filter(bh,1,x);         % analytisches Signal
   if length(x)<xe xend = length(x); end        % Darstellung anpassen
else
   if snr>999
      x = cos(pi*fsn*t+ph);                     % nur Cosinus
      y = x + i*sin(pi*fsn*t+ph);               % analytisches Signal
   else
      x = filter(ba,aa,sinnoise(pi*fsn*t,sn));  % Sinus + Rauschen
      y = filter(bv,1,x)+i*sign(fsn)*filter(bh,1,x); % analytisches Signal
   end
end
%
% Signaldarstellung
% =================
% Die Darstellung erfolgt in zwei Bildschirmen: 
% (a) Filterfrequenzgang Spektren (falls nur==0)
if nargin<7
   
   h0 = fullscreen('Filter-Frequenzgang','w',1,[2 2; 1 1]);
   filterplot({{ba;aa};bh})
   xlabel('Signalfrequenz und Rauschfilter','FontSize',fsz)
   line([abs(fsin),abs(fsin)],[0,0],'LineStyle','none','Color','r','Marker','.','MarkerSize',20);
   legend('Bandpass','Hilbertfilter','Signalfrequenz')
   
   h3 = fullscreen('Spektrum des Realteils','w',1,[2 2; 2 1]); 
   plot(z,abs(fft(real(y(xanf:xe)))))
   xlabel('Spektrum des Realteils','FontSize',fsz)
   
   h4 = fullscreen('Spektrum des Imaginrteils','w',1,[2 2; 2 2]); 
   plot(z,abs(fft(imag(y(xanf:xe)))))
   xlabel('Spektrum des Imaginrteils','FontSize',fsz)
   
   h5 = fullscreen('Spektrum des analytischen Signals','w',1,[2 2; 1 2]); 
   plot(z,abs(fft(y(xanf:xe))));
   xlabel('Spektrum des analytischen Signals','FontSize',fsz);
end

% (b) Signal im Zeitbereich (Animation)
komplexanimat(y(xanf:xanf+m),[1 1 0 0 0 1],velocity,blick);
