function x0 = kompop(f1,f2,dauer)
% x0 = kompop(f1,f2,dauer)
% Demo fr die arithmetischen Grundoperationen
% mit komplexen Sinus-Signalen.
% Es werden  x = exp(i*2*pi*f1) und  y = exp(i*2*pi*f2) 
% sowie  x+y, x-y, x*y und x/y in der komplexen Ebene 
% als Animation dargestellt. 
% Die Einheit von f1 und f2 ist die Nyquistfrequenz.
% dauer ist die Dauer der Animation in Sekunden (30 ist Default).
% Liegt das Bild "Operand x" oben, so kann die Animation mit der 
% Taste p angehalten werden (Fortfahren mit beliebiger Taste).
% Abbruch erfolgt auf dieselbe Weise mit der Taste s.
% Alle Parameter sind optional. Ihre Defaultwerte sind:
% f1 = 0.010;  f2 = 0.011;  dauer = 20;

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
if nargin<1 f1=0.010; end;
if nargin<2 f2=0.011; end;
if nargin<3 dauer=20; end;
nam = {'Operand x';'Operand y';'x * y';'x + y';'x - y';'x / y'};
for k = 1:6
   h(k) = fullscreen(nam{k},'w',1,[2 3; ceil(k/3) 1+mod(k-1,3)]);
   set(h(k),'KeyPressFcn','anicont','UserData',0);
   if (k==4)|(k==5) axis([-1.2,1.2,-1.2,1.2]*2);
               else axis([-1.2,1.2,-1.2,1.2]);
   end;
   axis square; axis manual; axis on;
   title(nam{k});
   xlabel('Realteil');
   ylabel('Imaginrteil');
   set(h(k),'CurrentAxes',gca);
   l1(k)=line('Color','r','EraseMode','background','Marker','.',...
      'LineStyle','-','xdata',[0,0],'ydata',[0,0]);
   l2(k)=line('Color','b','EraseMode','background',...
      'LineStyle','-','xdata',[0,0],'ydata',[0,0]);
   l3(k)=line('Color','g','EraseMode','background',...
      'LineStyle','-','xdata',[0,0],'ydata',[0,0]);
end;
if nargin<3  dauer = 30; end; 
n = round(15*dauer); % fr Pentium 133 stimmen die Zeiten etwa
t = 0;
stop = 0;
while (t<=n)&stop==0
   t = t+1;
   if get(h(1),'UserData')==2, stop = 1; end;
   x = exp(i*pi*f1*t);
   y = exp(i*pi*f2*t);
   d = [x,y,x*y,x+y,x-y,x/y];
   xd= real(d);
   yd= imag(d);
   for k = 1:6
      set(l1(k),'xdata',[0,xd(k)],'ydata',[0,yd(k)]);
      set(l2(k),'xdata',[0,xd(k)],'ydata',[0,0]);
      set(l3(k),'xdata',[0,0],'ydata',[0,yd(k)]);
   end;
   drawnow;
end;
for k=1:6 delete(h(k)); end;
