function mixdemo
% Graphik zur Demonstration der Faltung von Eingangs- und Mischeroszillatorsignal 
% im Frequenzbereich

% Author:  Klaus von der Heide,  v.d.heide@on-line.de

% Konstanten
% ==========
n  = 1024;                                      %  Anzahl der Abtastungen
m  = 100;                                       %  halbe Breite des Seitenbandes
f0 = 0.21;                                      %  Mischfrequenz
fb = 0.05;                                      %  Bandfiltermittenfrequenz
hb = 0.005;                                     %  halbe Bandfilterbreite
f1 = f0 + fb;                                   %  Nutzfrequenz
nf = 100;                                       %  Rauschebene in dB
t  = 0:n-1;                                     %  Zeitbereich
f  = (0:n-1)/n;                                 %  Frequenzbereich
w  = kaiser(n,0.1102*(nf-8.7))';                %  Kaiserfenster
fsiz = 12;                                      %  FontSize

% Signale
% =======
xa = [0.26   0.27   0.17   0.22  0.35;          %  mehrere Eingangs-Frequenzen
      0.001  1.00   0.01   0.03  0.75];         %  deren Amplituden
for k=1:n  x(k) = sum(xa(2,:).*exp(+i*2*pi*xa(1,:)*t(k))); end
   
ya = [0.17   0.19   0.30   f0    0.33   0.70;   %  Nebenfrequenzen
      0.0005 0.0001 0.0003 1.00  0.0001 0.0005; %  deren Amplituden
      rand   rand   rand   rand  rand   rand];  %  deren Phasen      
[u,v] = size(ya);
for k=1:m 
   ya(:,v+2*k-1) = [f0-k/n; 1/k^3; rand];       %  unteres Seitenband 
   ya(:,v+2*k)   = [f0+k/n; 1/k^3; rand];       %  oberes Seitenband
end
for k=1:n  y(k) = sum(ya(2,:).*exp(-i*2*pi*(ya(1,:)*t(k)+ya(3,:)))); end

% Mischung
% ========
z  = x.*y;                                      %  Mischung

% Transformation in den Frequenzbereich
% =====================================
X  = 20*log10(abs(fft(x.*w)));  X = X - max(X);
Y  = 20*log10(abs(fft(y.*w)));  Y = Y - max(Y);
Z  = 20*log10(abs(fft(z.*w)));  Z = Z - max(Z);

% Darstellung
% ===========
fh = fullscreen('MixDemo');
subplot(3,1,1); plot(f,X);  axis([0 1 -100 10]);
line([(f1-hb)*[1;1],(f1+hb)*[1;1]],[-100 -100; 10 10],'Color','r')
title('Spektrum des Eingangssignals','FontSize',fsiz)
subplot(3,1,2); plot(f,Y);  axis([0 1 -100 10]);
title('Spektrum des Mischeroszillators','FontSize',fsiz)
subplot(3,1,3); plot(f,Z);  axis([0 1 -100 10]);
line([(fb-hb)*[1;1],(fb+hb)*[1;1]],[-100 -100; 10 10],'Color','r')
title('Spektrum des Mischsignals','FontSize',fsiz)
xlabel('\Omega','FontSize',fsiz)

