function  mrfiltergraph
%  mrfiltergraph zeichnet das Blockschema eines Multiratenfilters

%  Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Konstanten
% ==========
lw = 1.5;               % LineWidth
fs = 18;                % FontSize
cd = 0.8*[0.7 1 1];     % Fllfarbe Dezimationsfilter
ci = 0.8*[1 0.7 1];     % Fllfarbe Interpolationsfilter
ca = 0.8*[1 1 1];       % Fllfarbe Abwrtstastung
ch = 0.8*[1 1 1];       % Fllfarbe Hochtastung
ck = 0.8*[1 1 0.7];     % Fllfarbe Kernfilter
cl = 'k';               % Linienfarbe
spl= 2;                 % Pfeilspitzenlnge

% Fenster und Achsen
% ==================
h = fullscreen('Multiratenfilter');
axis([0,130,-20,70]); 
a = gca;
set(a,'Visible','off')

% Dezimation
% ==========
drawsq([20,40],10,cd,'F',fs)
drawsq([40,40],10,ca,'/k',fs)
drawsq([80,40],10,cd,'F',fs)
drawsq([100,40],10,ca,'/k',fs)
drawarr([10,45],[20,45],cl,lw,spl);
drawarr([30,45],[40,45],cl,lw,spl);
drawarr([50,45],[60,45],cl,lw,spl);
drawarr([70,45],[80,45],cl,lw,spl);
drawarr([90,45],[100,45],cl,lw,spl);
line([60,70],[45,45],'Color',cl,'LineWidth',lw,'LineStyle',':')

% Kernfilter
% ==========
line([110,120],[45,45],'Color',cl,'LineWidth',lw)
drawarr([120,45],[120,35],cl,lw,spl);
drawsq([115,25],10,ck,'K',fs)
line([120,120],[25,15],'Color',cl,'LineWidth',lw)

% Keine Interpolation
% ===================
obj = findobj('parent',a);
drawarr([120,15],[10,15],cl,lw,spl)
set(setdiff(findobj('parent',a),obj),'visible','off')

% Interpolation
% =============
drawsq([20,10],10,ci,'F',fs)
drawsq([40,10],10,ch,'*k',fs)
drawsq([80,10],10,ci,'F',fs)
drawsq([100,10],10,ch,'*k',fs)
drawarr([20,15],[10,15],cl,lw,spl);
drawarr([40,15],[30,15],cl,lw,spl);
drawarr([60,15],[50,15],cl,lw,spl);
drawarr([80,15],[70,15],cl,lw,spl);
drawarr([100,15],[90,15],cl,lw,spl);
drawarr([120,15],[110,15],cl,lw,spl);
line([70,60],[15,15],'Color',cl,'LineWidth',lw,'LineStyle',':')
iob = setdiff(findobj('parent',a),obj);

% Legende
% =======
text(0,45,'Input','FontSize',fs)
text(-3,15,'Output','FontSize',fs)
text(33,60,'Schema eines Multiratenfilters','FontSize',fs+4)
text(0,0,'F :  Filter,    /k :  Abwrtstastung,    *k :  Hochtastung,    K :  Kernfilter',...
     'FontSize',fs)

% Interaktivitt
% ==============
fud = iob;
togglevis = {'if strcmp(get(select(get(gcf,''UserData''),1),''visible''),''off'')', 
             'set(select(get(gcf,''UserData''),1:2),''visible'',''on'');',
             'set(select(get(gcf,''UserData''),3:23),''visible'',''off'');',
             'else set(select(get(gcf,''UserData''),1:2),''visible'',''off'');',
             'set(select(get(gcf,''UserData''),3:23),''visible'',''on''); end'};
set(h,'UserData',fud,'ButtonDownFcn',cat(2,togglevis{:}))
          