function [koef,srate] = mrprototype(bw,typ,intpol)
% [koef,srate] = mrprototype(bw,typ,intpol)
% !!! berholt durch mrdesign und mrbpdesign !!!
% Entwurf eines Multiratenfilters mif folgenden Eigenschaften:
% bw               : Bandbreite des Filters relativ zur Nyquistfrequenz
% typ = 'lowpass'  : Tiefpass mit der Grenze des Durchlassbereiches bw.
%                    Die Abtastrate wird in Schritten von 1/2 dezimiert 
%                    unter Verwendung von Halbandtiefpssen sofern mglich.
% typ = 'bandpass' : Bandpass mit dem Durchlassbereich  0.5-bw ... 0.5+bw.
% !!noch nicht fertig !!  Die Abtastrate wird in Schritten von 1/3 dezimiert 
%                    unter Verwendung einfacher Halbandbandpsse.
% intpol = 0       : Das Multiratenfilter soll mit der tiefsten Abtastrate
%                    ausgeben.
% intpol = 1       : Das Multiratenfilter soll zurckinterpolieren auf die 
%                    Abtastrate des Eingangs. Dies erfolgt unter Verwendung 
%                    entsprechender Interpolationsfilter.
% Die Welligkeit im Durchlassbereich betrgt ca. 0.2 dB.
% Die Sperrdmpfung ist ca. 60 dB.
%
% Ausgabe:
% koef  = {b1; b2; ... bn};    b1 = Koeffizientenvektor des ersten Filters etc.
% srate = [sr1, sr2, ... srn]; Abtastratenfaktoren der einzelnen Filter,
%                              z.B. 1/2 fr ein Dezimationsfilter,
%                              2 fr ein Interpolationsfilter
%                              1 fr ein Kernfilter.
% Wird die Ausgabe nicht einer Variablen zugewiesen, so gibt es eine 
% graphische Darstellung des Frequenzganges.
% koef und srate sind direkt in der Funktion mrfilter verwendbar.
%
% Beispiel: 
% [koef,srate] = mrprototype(0.01);
% t = (1:8000)/2;
% x = 0.5*sin(2*pi*0.01*t) + randn(size(t));
% mrfilter(koef,srate,x);
%
% Hinweis: Bei  bw<0.004  wird die Filterverzgerung so gross, dass die 
% Student-Edition von MATLAB zum Filtern nicht mehr benutzt werden kann.

% Autor:  Klaus von der Heide; e-mail:  v.d.heide@on-line.de

if nargin<3 intpol = 1;         end
if nargin<2    typ = 'lowpass'; end
if nargin<1     bw = 0.08;      end
%
% Dezimationsfilter
% =================
r1   = 0.118; r2 = 0.25; r3 = 0.4;
b{1} = remez(6,[0,r1,1-r1,1],[1,1,0,0]);
b{2} = remez(14,[0,r2,1-r2,1],[1,1,0,0]);
b{3} = remez(34,[0,r3,1-r3,1],[1,1,0,0]);
r    = remezord([r3,0.125*4],[1,0],[0.0108,0.001],2,'cell');
b{4} = remez(r{1},r{2},r{3},r{4});
%
% Interpolationsfilter
% ====================
b{9} = b{1};
b{8} = b{2};
b{7} = b{3};
b{6} = b{4};
%
% Filterstruktur
% ==============
bb = bw;
df = [];
if strcmpi(typ,'lowpass')
   while bb<0.4
      if     bb<0.05,  df = [df 1];
      elseif bb<0.10,  df = [df 2];
      elseif bb<0.20,  df = [df 3];
      else             df = [df 4];
      end
      bb = bb*2;
   end
   sr = [1/2 1/2 1/2 1/2 1 2 2 2 2];
   f1 = 0;
   f2 = 1.2*bw;
end
if strcmpi(typ,'bandpass')
   while bb<0.5
      if     bb<0.05,  df = [df 1]; %!!!!!!!
      elseif bb<0.10,  df = [df 2];
      elseif bb<0.20,  df = [df 3];
      else             df = [df 4];
      end
      bb = bb*3;
   end
   sr = [1/3 1/3 1/3 1/3 1 3 3 3 3];
   f1 = 0.5 - 0.6*bw;
   f2 = 0.5 + 0.6*bw;
end
df = [df 5];
if intpol  df = [df 10-df(length(df)-1:-1:1)]; end
%
% Kernfilter
% ==========
if strcmpi(typ,'lowpass')
   r    = remezord([bb,bb+0.1],[1,0],[0.0108,0.001],2,'cell');
   if r{1}/2~=floor(r{1}/2) r{1} = r{1} + 1; end
   b{5} = remez(r{1},r{2},r{3},r{4});
end
if strcmpi(typ,'bandpass') %!!!!!!!! noch nicht fertig !!!!!!
   r  = remezord([bb,bb+0.1],[1,0],[0.0108,0.001],2,'cell');
   if r{1}/2~=floor(r{1}/2) r{1} = r{1} + 1; end
   b{5} = remez(r{1},r{2},r{3},r{4});
end
%
% Konstruktion
% ============
for k = 1:length(df)  
   koef{k} = b{df(k)}; 
   srate(k)= sr(df(k));   
end
koef = koef';
%
% Darstellung des Frequenzganges
% ==============================
if nargout<1
   t = (1:min([16000,round(100/bw)]))/2;
   x = 0.5*sin(2*pi*bw*t) + randn(size(t));
   mrfilter(koef,srate,x,f1,f2); 
end
