function mrvsiirdemo(f)
% mrvsiirdemo(f)
% Graphischer Vergleich von automatisch entworfenen 
% Tiefpassiltern mit sehr kleiner Grenzfrequenz.
% (1)  Multiraten-Tiefpass
% (2)  Drei gleiche Butterworth-Filter vom Grad 2 in Serie
% Alle Versuche mit IIR-Filtern hheren Grades schlugen fehl!

% Autor:  Klaus von der Heide; e-mail:  v.d.heide@on-line.de

% Defaults und Konstanten
% =======================
if nargin<1  f = 0.0003; end
fsiz = 15;

% Filterentwurf
% =============
[koef,dlmr] = mrdesign2(2*f,2*f,1,60,60);
[b,a] = butter(2,4*f);
%[b,a] = ellip(4,1,60,2*f);
dv  = cumprod(1./koef.r);
dv(1:floor((length(dv)-1)/2)) = dv(1:floor((length(dv)-1)/2))/dv(1);
dliir = 3*max(grpdelay(b,a,[f f],2));

% Simulation
% ==========
t = 1:16384;
x = 0.5*sin(2*pi*f*t)+randn(size(t));
y = mrfilter2(koef,x); 
z = filter(b,a,filter(b,a,filter(b,a,x)));

% Darstellung
% ===========
fh1 = fullscreen('MR-Frequenzgang');
filterplot(koef.c,0,10*f,0,-80,10,dv,32,1)
line(2*f*[1 1],get(gca,'YLim'),'Color','r','LineWidth',2)
title('Multiratenfilter','FontSize',fsiz)

fh2 = fullscreen('IIR-Frequenzgang');
filterplot({{b;a};{b;a};{b;a}},0,10*f,0,-80,10,[1 1 1],32,1)
line(2*f*[1 1],get(gca,'YLim'),'Color','r','LineWidth',2)
title('IIR-Filter: 3 Butterworth-Filter vom Grad 2 in Serie','FontSize',fsiz)

fh3 = fullscreen('MR-Filter');
axes('Position',[0 0 1 1])
line(t,x,'Color','b')
line(t-dlmr,y,'Color','r')
line(t-dliir,z,'Color','g')
axis([-round(1/f)  length(t)-dlmr  max(abs(x))*[-1 +1]]); axis off
legend('Input','MR-Output','IIR-Output',3)
