function newddsanimat(z,f)
% newddsanimat(z,f)
% animierte Graphik zur Direkten Digitalen Synthese von Kreisfunktionen 
% nach der Methode des Chinesischen Restsatzes.
% z  :  Vektor paarweise teilerfremder natrlicher Zahlen,
%       (bei mehr als 5 Zahlen wird das Bild trge)
% f  :  Ausgabefrequenz der DDS relativ zur Abtastfrequenz
% Defaults:  z = [3 4 5];  f = 1/prod(z) = kleinste positive Frequenz.
% Die Animation wird durch die Taste ENTF sowie durch Lschen des Fensters
% gestoppt.
% !!! Die Animation knnte verbessert werden durch Ersatz von drawnow durch 
% !!! Setzen der XData bzw YDate je eines Patch-Markers (weniger Flackern)

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1  z = [3 4 5];   end
if nargin<2  f = 1/prod(z); end

% Konstanten
% ==========
n  = length(z);              % Anzahl der Synthese-Komponenten
fsiz = 13;                   % FontSize
if n>5  fsiz = 60/n; end
ms0  = 12;                   % MarkerSize (blau)                   
ms1  = 30;                   % MarkerSize selektiert (rot)
mk = '.';                    % Marker
w  = (0:5:360)/360*2*pi;     % Winkel
c  = exp(i*w);               % Kreis
x  = real(c);                % Kreis, x
y  = imag(c);                % Kreis, y
M  = prod(z);                % der Vollkreis wird in diese Anzahl quantisiert
d  = diophant(z);            % Lsung der Diophantischen Gleichung
fi = round(f*M);             % Ist-Frequenz
r  = mod(fi*d,z);            % Koeffizienten

% Bild und Achsen
% ===============
fh = fullscreen('NewDDS');
axes('Position',[0 0 1 1])

% Darstellung
% ===========
for k=1:n
   line(x+3*k-1.5*(n+1),y+1.3)  % Kreis fr Komponente k
   for j=0:z(k)-1               % Kreisteilung mit z(k) Marker
      mh{k}(j+1) = line(cos(j*2*pi/z(k))+3*k-1.5*(n+1),sin(j*2*pi/z(k))+1.3,...
                        'Marker',mk,'LineStyle','none');
   end
   text(3*k-1.5*(n+1),1.5,['x = ' num2str(d(k))],...
        'HorizontalAlignment','center','VerticalAlignment','middle','FontSize',fsiz)               
   text(3*k-1.5*(n+1),1.1,['d = ' num2str(r(k))],...
        'HorizontalAlignment','center','VerticalAlignment','middle','FontSize',fsiz)               
end
line(x,y-1.3)                % Synthese-Kreis
for j=0:M-1                  % Kreisteilung mit M Marker
   mhs(j+1) = line(cos(j*2*pi/M),sin(j*2*pi/M)-1.3,...
                   'Marker',mk,'LineStyle','none');
end
text(0,0,'DDS nach dem Chinesischen Restsatz','FontSize',fsiz+5,...
     'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','middle')               
text(-1.5*n,-0.8,['z = [' num2str(z) ']'],'FontSize',fsiz)               
text(-1.5*n,-1.2,['Frequenzraster:  '   num2str(1/prod(z),8) '*f_s'],'FontSize',fsiz)               
text(-1.5*n,-1.6,['Soll-Frequenz:    '  num2str(f,8) '*f_s'],        'FontSize',fsiz)               
text(-1.5*n,-2.0,['Ist-Frequenz:      ' num2str(fi/M,8) '*f_s'],     'FontSize',fsiz)               
axis([1.75*n*[-1 +1] 1.2*n*[-1 +1]]);  axis off

% Animation
% =========
p  = zeros(1,n);             % Phasenakkumulatoren
ps = 0;                      % Phasensumme
while 1                      % fr immer und ewig                 
   for k=1:n                 % alle Komponenten
      set(mh{k}(1+p(k)),'Color','b','MarkerSize',ms0)  % Marker-Reset
      p(k) = mod(p(k)+r(k),z(k));                      % Phaseninkrement 
      set(mh{k}(1+p(k)),'Color','r','MarkerSize',ms1)  % Marker selektiert
   end
   set(mhs(1+ps),'Color','b','MarkerSize',ms0)         % Marker-Reset
   ps = round(mod(sum(p./z)*M,M));                     % Phasensumme 
   set(mhs(1+ps),'Color','r','MarkerSize',ms1)         % Marker selektiert
   drawnow                   % besser wre: set(XData,...,YData,...)
   pause(0.4)                % nachvollziehbare Geschwindigkeit
end