function y = notchfilter(f,bw,x)
% y = notchfilter(f,bw,x)
% Kerbfilter W.Hess: "Digitale Filter" S.292
% f  :  Kerbfrequenz (relativ zur Nyquistfrequenz)
% bw :  Bandbreite fr -10 dB
% x  :  Eingangssignal
% y  :  Ausgangssignal
% Falls die Ausgabe nicht zugewiesen oder x nicht angegeben 
% wird, gibt es eine Darstellung des Frequenzganges.

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
if nargin<2  bw = 0.02; end
if nargin<1   f = 0.3;  end
q  = exp(i*pi*f);
z  = [q; conj(q)];
k  = 1 - 4*bw;
p  = k*z;
[b,a] = zp2tf(z,p,k);
p2 = a(3);
p1 = a(2)/(p2+1);
%
% Darstellung des Frequenzganges
% ==============================
if nargout<1 | nargin<3
   fh = fullscreen('Kerbfilter');
   filterplot({{b;a}})
   y = 0;
   break
end
%
% Filtern
% =======
t1 = 0; 
t2 = 0;
for k = 1:length(x)
   h1 = p2*(x(k) - t1);
   u  = x(k) + h1;
   h2 = p2*(u - t2);
   v  = u + h2;
   y(k) = (x(k) + h1 + t1)*0.5;
   t1 = t2 + h2;
   t2 = v;
end