function x0 = plotzeitfreq(sigstr,fs,T)
% x0 = plotzeitfreq(sigstr,fs,T)
% plotZeitFreq tastet das im String  sigstr  als MATLAB-Ausdruck 
% angegebene Signal im Zeitbereich von 0 ... T  mit der
% Abtastrate  fs  ab.
% Die Zeit ist als Variable mit dem Identifier  t  fest vorgegeben.
% Das Signal wird im oberen Bild im Zeitbereich gezeichnet.
% Darunter wird die spektrale Leistungsdichte mit n/2 Punkten in dB geplottet.

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<3  T = 2;  end
if nargin<2  fs = 30; end
if nargin<1  sigstr = 'sin(2*pi*3.1*t)+0.7*sin(2*pi*5.3*t)'; end
fsiz = 12;                        % FontSize

% Rechnung
% ========
n  = round(T*fs);                 % Anzahl der Abtastpunkte im Zeitfenster                     
tt = T*(0:799)/800;               % "kontinuierlicher Zeitbereich"
t  = tt;
ss = eval(sigstr);                % "kontinuierliches Signal"
t  = T*(0:n-1)/n;                 % Abtastpunkte
s  = eval(sigstr);                % Abtastung des Signals
S = fft(s);                       % FFT
y = S.*conj(S)/n;                 % spektrale Leistungsdichte
ly= 10*log10(y);                  % dies in dB
f = (0:n-1)/T;                    % Frequenzbereich

% Darstellung
% ===========
h = fullscreen('Diskrete Fouriertransformation',0.85*[1 1 1]);
subplot(2,1,1);                   % zweiteiligen Plot festlegen
plot(tt,ss);                      % Plot Zeitbereich: kontinuierlich
line([0,T],[0,0],'Color','k');    % Null-Linie
for k=1:n  line([t(k),t(k)],[0,s(k)],'Color','r'); end
fmark=line('Color','r','LineStyle','.','MarkerSize',15);
set(fmark,'xdata',t,'ydata',s);
title(sprintf(['Signal:  ',sigstr,'  (eine Periode)  abgetastet mit  fs =%7.2f Hz'],fs),...
      'FontSize',fsiz);
xlabel('t [sec]','FontSize',fsiz);
set(gca,'xlim',[0,T])
set(gca,'ylim',1.1*get(gca,'ylim'))
subplot(2,1,2);
plot(f,ly);                       % Plot Frequenzbereich
yl = get(gca,'ylim');
for k=1:n  line([f(k),f(k)],[yl(1),ly(k)],'Color','g'); end
fmark=line('Color','g','LineStyle','.','MarkerSize',15);
set(fmark,'xdata',f,'ydata',ly);
title('Spektrale Leistungsdichte  (eine Periode)','FontSize',fsiz);
xlabel('Frequenz [Hz]','FontSize',fsiz);
ylabel('Dichte in dB','FontSize',fsiz);
set(gca,'xlim',[0,f(n)])
