function [pk,s] = polynomfit(fcn,g,m,n)
% [pk,s] = polynomfit(fcn,g,m,n)
% Ermittelt die skalierten Koeffizienten einer Polynomapproximation
% fcn  :    String der die Funktion angibt mit der Variablen x
%           Die Funktion wird im Bereich  0 <= x <= 1 ausgewertet.
% g    :    Polynomgrad
% m    :    Anzahl der Bits einer 2-Komplementdarstellung der 
%           Funktionswerte im Bereich [-1, +1] und der Koeffizienten
% n    :    Anzahl der zu berechnenden Punkte
% pk   :    Koeffizienten
% s    :    Skalierungsfaktor
% Die Koeffizienten werden so berechnet, dass sie und alle Zwischen-
% ergebnisse der Polynomberechnung kleiner sind als 1.0.  (s = 2^k).

% Defaults
% ========
if nargin<4   n = 1024; end
if nargin<3   m = 64;   end
if nargin<2   g = 8;    end
if nargin<1 fcn = 'sin(pi/2*x)'; end
fsiz = 13;                                  % FontSize
% 
% Ermittlung des Polynoms
% =======================
x  = (0:n-1)/(n-1);                         % quidistante Punkte
sn = eval(fcn);                             % zugehrige Funktionswerte
sn = round(sn*(1-2^(1-m))*2^(m-1))*2^(1-m); % Quantisierung
pk = polyfit(x,sn,g);                       % Polynomkoeffizienten
%
% Skalierung
% ==========
mx = max(abs(pk));
for k=1:length(pk) mx = max([mx,abs(polyval(pk(1:k),x))]); end
s = 2^ceil(log2(mx));
pk = pk/s;
%
% Quantisierung der Koeffizienten
% ===============================
pk = round(pk*(1-2^(1-m))*2^(m-1))*2^(1-m); % Quantisierung

if nargout>0  break; end                    % falls Zuweisung auf pk keine Graphik
%
% Fehlerberechnung
% ================
ee = abs(sn - s*polyval(pk,x));             % Fehler 
eem= max(ee);
fh = fullscreen('Fehler der Polynomentwicklung');
plot(x,ee)
title(sprintf('Fehler der Polynomentwicklung vom Grad %2d fr  %s',g,fcn),'FontSize',fsiz)
xlabel('x','FontSize',fsiz)
axis([0  1  0.01*eem  1.2*eem])
