function rectanalyt(anzk,gibbs)
% rectanalyt(anzk,gibbs)
% Animierte Darstellung des analytischen Rechtecks durch 
% roten Punkt in der kompexen Ebene. Die schwarzen Punkte 
% sind die einzelnen Komponenten.
% Zustzlich wird die Phase ber einer Periode dargestellt.
% anzk  :  das hchste darzustellende Vielfache der Grundschwingung
% gibbs :  die Amplitude der hchsten Komponente wird mit gibbs 
%          multipliziert, um den Gibbs-Effekt der berschwingung zu 
%          mildern. Sinvoll ist  0.5 <= gibbs <= 1.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults und Konstanten
% =======================
if nargin<2  gibbs = 1;  end
if nargin<1   anzk = 10; end
n  = 400;                       % Anzahl der Punkte im Kreis
w  = 2*pi*10;                   % Kreisfrequenz der Rechteckschwingung
ms = 15;                        % MarkerSize
fsiz = 13;                      % FontSize
av = 0.7;                       % Seitenverhltnis der Bildachsen
t  = (0:n)/n/10;                % Zeitbereich
xa = max([2,0.75*log(anzk)]);   % Lnge der halben x-Achse
ya = xa*av;                     % Lnge der halben y-Achse
%
% Analytisches Rechteck
% =====================
for k = 1:2:anzk  s(:,k) = exp(-i*k*w*t')/k; end
for k = 2:2:anzk  s(:,k) = zeros(n+1,1); end
%
% Darstellung der Phase
% =====================
fh1 = fullscreen('Phase');
ss  = sum(s');
plot(1:length(ss),unwrap(angle(ss)))
axis([1 n 0 2*pi])
xlabel('Zeit (eine Periode)','FontSize',fsiz)
ylabel('Phasenwinkel','FontSize',fsiz)
%
% Statisches Bild
% ===============
fh2 = fullscreen('Rechteck');
set(gca,'Units','normalized','Position',[0 0 1 1])
plot(real(s),imag(s))
line([0 0; -xa xa]',[-ya ya; 0 0]','LineStyle',':','Color',0.7*[1 1 1])
axis([-xa xa -ya ya]); axis off
text(1.1,0.05,'Imaginrteil','FontSize',fsiz)
text(-0.05,1.1,'Realteil','FontSize',fsiz,'Rotation',90)
th = text(-xa*0.98,-ya*0.95,'Abbruch durch Lschen des Bildes','FontSize',fsiz);
%
% Animation
% =========
for k = 1:2:anzk
   l(k) = line(0,0,'Color','k','EraseMode','background',...
               'LineStyle','none','Marker','.','MarkerSize',ms);
end
ls = line(0,0,'Color','r','EraseMode','background',...
              'LineStyle','none','Marker','.','MarkerSize',ms+5);        
z = 0;
while 1
   z = z + 0.000003*anzk;
   ss = 0;
   for k = 1:2:anzk
      r = exp(-i*k*w*z);
      q = (1/k + 0.027)*r;
      s = 1/k*r;
      set(l(k),'xdata',real(q),'ydata',imag(q));
      ss = ss + s;
   end;
   ss = ss + s*(gibbs-1);
   set(ls,'xdata',real(ss),'ydata',imag(ss));
   drawnow;
end;
