function spechochtast(f1,f2,r,g)
%  spechochtast(f1,f2,r,g)
%  spechochtast zeigt die Spektren vor und nach dem Einfgen von Nullen.
%  Bis auf die Verschiebung der Abtastfrequenz ergeben sich dieselben
%  Spektren.
%  Parameter:
%  f1 und f2 :  zwei Sinusfrequenzen  0 <= f1,f2 <= 1 (Nyquistfrequenz)
%  r :          Amplitude eines weissen Rauschens
%  g :          Grad des Halbbandfilters  fir1(g,1/2) zur Interpolation
%               Falls g > 6 (gerade) angegeben ist, wird auch das Ergebnis
%               des Filterns gezeigt.

%  Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
%  Defaults
%  ========
if nargin<4  g = 0;   end
if nargin<3  r = 0.5; end
if nargin<2  f2= 0.6; end
if nargin<1  f1= 0.2; end
%
%  Signalerzeugung, Nullen einfgen, FFT
%  =====================================
n = 256;
x = r*randn(1,n) + sin(pi*f1*(0:n-1)) + sin(pi*f2*(0:n-1));
y = [nullein(x,1),0];
X = fft(x);
Y = fft(y);
%
%  Darstellung
%  ===========
h = fullscreen('Nullen-Einfgen');
if g > 7 
   b = fir1(g,1/2);
   z = filter(b,1,y);
   Z = fft(z);
   plot(0:2*n-1,abs(Y),0:n-1,abs(X),0:2*n-1,abs(Z))
else plot(0:2*n-1,real(Y),0:n-1,real(X)); end
lineobj = get(gca,'Children');
set(lineobj(1),'LineWidth',1,'Color','r')
set(lineobj(2),'LineWidth',2,'Color','g')
if g > 7  legend('Input + Nullen','Input','nach Halbbandfilter')
else legend('Input + Nullen','Input'); end
set(gca,'XLim',[0,2*n],'XTick',[0,n/2,n,3*n/2,2*n],'YTick',[],...
    'XTickLabel',['  0   ';' Ny   ';'Fs=Ny''';'      ';' Fs''  '])
yl = get(gca,'YLim');
line([0,2*n],[0,0],'LineStyle','-','Color',0*[1 1 1])
line([n,n],yl,'LineStyle','-','Color',0.5*[1 1 1])
line([n/2,n/2],yl,'LineStyle',':','Color',0.5*[1 1 1])
line([3*n/2,3*n/2],yl,'LineStyle',':','Color',0.5*[1 1 1])
title('Die Spektren vor und nach dem Einfgen von Nullen sind gleich',...
      'FontSize',15)
