function syncumsetzgraph(f1,f2)
% syncumsetzgraph(f1,f2)
% Statisches Bild zur Darstellung der synchronen Abtastratenumsetzung
% von der Abtastrate f1 zur Abtastrate f2

% Autor: Klaus von der Heide,  e-mail:  v.d.heide@on-line.de

if f1<1 | f2<1 | f1~=round(f1) | f2~=round(f2)  error('f1 und f2 mssen ganze positive Zahlen sein'); end

% Defaults
% ========
if nargin<2  f2 = 32000; end
if nargin<1  f1 = 48000; end

% Konstanten
% ==========
if screen>1  fsiz = 20; else fsiz = 15; end
n  = 1000;                       % Anzahl der Punkte des zeitkontinuierlichen Signals
d  = gcd(f1,f2);                 % Reduktionsfaktor
fh  = lcm(f1,f2);                % Abtastrate der Hochtastung
r1 = d/f1;                       % Anzahl der Inputabtastungen pro Periode
r2 = d/f2;                       % Anzahl der Outputabtastungen pro Periode
rh = d/fh;                       % Anzahl der Abtastungen der Hochtastung pro Periode
rg = 1;                          % Lnge der Periode im Bild (wird noch gendert)                         
rm = min(r1,r2);
if rm>0.2       r1 = r1/4; r2 = r2/4; rh = rh/4; rg = rg/4;
elseif rm>0.05  r1 = r1/2; r2 = r2/2; rh = rh/2; rg = rg/2;
end
u  = 0.998;
r1 = u*r1;            r2 = u*r2;            rg = u*rg;            rh = u*rh;
d1 = n*r1;            d2 = n*r2;            dg = n*rg;
ri1= round(1:d1:n);  ri2 = round(1:d2:n);  rig = round(1:dg:n);
rh = max(rh,1/n);
tp = 0.02;                       % Textposition
tl = [0.02,0];                   % TickLength
figcol = [0.7,0.7,0.7];          % Bildrandfarbe

t  = (0:n+1)/n;                  % Zeitbereich
s  = 0.1 + 0.5*sin(15.7*t + 0.7) + 0.3*sin(23*t); % Beispiel-Signal

% Darstellung
% ===========
h = fullscreen('Umtastung');
axes('Position',[0.1,0.0,0.8,0.8],'Color','w',...
   'XColor',figcol,'XTick',(0.001:rg:1),'YColor','w','YTick',[],...
   'XGrid','on','XTickLabel',['';'';'';'';'';''])
text(tp,1.1,sprintf('Synchrone Abtastratenumsetzung von%7d Hz nach%7d Hz',f1,f2),'FontSize',fsiz,'FontWeight','bold')

axes('Position',[0.1,0.7,0.8,0.02],'LineWidth',2,...
   'TickDir','in','TickLength',tl,...
   'XColor','k','XTick',(0.001:r1:1),'XTickLabel',[],...
   'YColor','w','YTick',[])
text(tp,3,'Abtastpunkte des Inputs','FontSize',fsiz,'Color','k')

axes('Position',[0.1,0.55,0.8,0.02],'LineWidth',2,...
   'TickDir','in','TickLength',tl,...
   'XColor',figcol,'XTick',(0.001:rh:1),'XTickLabel',[],...
   'YColor','w','YTick',[])
text(tp,3,'Abtastpunkte der Hochtastung','FontSize',fsiz,'Color',figcol)

axes('Position',[0.1,0.4,0.8,0.02],'LineWidth',2,...
   'TickDir','in','TickLength',tl,...
   'XColor','r','XTick',(0.001:r2:1),'XTickLabel',[],...
   'YColor','w','YTick',[])
text(tp,3,'synchrone Abtastpunkte des Outputs','FontSize',fsiz,'Color','r')

axes('Position',[0.1,0.03,0.8,0.3])
line(t(1:n),s(1:n),'color',figcol)
line(t(ri1),s(ri1),'LineStyle','none','Marker','o','LineWidth',1,'color',figcol)
line(t(ri2),s(ri2),'LineStyle','none','Marker','o','LineWidth',3,'color','r')
line(t(rig),s(rig),'LineStyle','none','Marker','o','LineWidth',3,'color','k')
axis off
legend('zeitkontinuierliches Signal','Input-Abtastung','neu zu berechnende Punkte','zu bernehmende Punkte')