function x0 = umtast1demo(n,k,fi,ff)
% x0 = umtast1demo(n,k,fi,ff)
% Asynchrone Umtastung eines mit der Grenzfrequenz fi tiefpassbegrenzten
% Zufallssignals unter Benutzung eines Interpolationstiefpasses mit der 
% Grenzfrequenz ff und dem Grad k, dessen Impulsantwort in einer Tabelle 
% mit n Sttzstellen pro Abtastschritt der Inputsequenz gespeichert wird.
% Das umgetastete Signal wird danach wieder in die ursprngliche Taktung 
% umgetastet. Die Differenz nach zweimaliger Umtastung wird dargestellt 
% sowie alle Signale direkt. 
% Beispiel: umtast1demo(16,12,0.5,0.8)
% Siehe auch umtast2demo mit Hoch-Tastung und anschliessender Tieftastung.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Konstanten und Defaults
% =======================
if nargin<4 ff = 0.8; end
if nargin<3 fi = 0.3; end
if nargin<2  k = 60;  end
if nargin<1  n = 8;   end
fsiz = 12;                        % FontSize
m    = 200 + 2*k;                 % Lnge des Signals (Abtastpunkte)
r    = 1.181;                     % Umtastfaktor
q    = 0.7;                       % Umtastversatz
%
% Filterentwurf
% =============
[u,v] = ellip(6,1,60,fi);         % IIR-Filter zur Bandbegrenzung
b   = fir1(k,ff);                 % FIR-Filter zur Interpolation
%
% Signal und Umtastung
% ====================
x   = filter(u,v,randn(1,m));     % zufllige Eingabesequenz
t11 = floor(m/2) - k;
t12 = t11 + 2*k + 23;
t1  = t11:t12;                    % ursprngliche Abtastung
t2  = t11 + q + (0:1/r:floor((t12-t11)*r)); % mglichst schrge Neuabtastung
t3  = t1;                         % ursprngliche Abtastung 
t4  = t11+k:t12-k;                % zur Darstellung wegen Fehlern am Rand
y   = umtastung(x,1:length(x),t2,b,n); % Umtastung
z   = umtastung(y,t2,t3,b,n);     % Umtastung zurck auf ursprngliche
%
% Darstellung
% ===========
h = fullscreen('Fehler der Umtastung');
subplot(2,1,1);                   % Darstellung der Umtastung
plot(t3,x(t3),'or',t3,z,'b.');
axis([t4(1),t4(length(t4)),1.1*min([x,y,z]),1.1*max([x,y,z])]);
line(t2,y,'LineStyle','none','Marker','x','color','g','LineWidth',2.0)
title('Eingabeabtastung, Umtastung und zweite Umtastung','FontSize',16)
legend('Eingabeabtastung','zweite Umtastung','erste Umtastung')

subplot(2,1,2)                    % Differenz zwischen ursprnglichen und
plot(t3,z-x(t3),'or','LineWidth',2.0) % zweimal neu abgetsteten Werten
axis([t4(1),t4(length(t4)),-0.05,0.05]);
title('Fehler nach zweimaliger Umtastung','FontSize',16)
xlabel('Zeit','FontSize',fsiz);
ylabel('Fehler','FontSize',fsiz);

