function x0 = umtast2demo(n,k,fi,ff)
% x0 = umtast2demo(n,k,fi,ff)
% Asynchrone Umtastung eines mit der Grenzfrequenz fi tiefpassbegrenzten
% Zufallssignals unter Benutzung eines Interpolationstiefpasses mit der 
% Grenzfrequenz ff und dem Grad k, dessen Impulsantwort in einer Tabelle 
% mit n Sttzstellen pro Abtastschritt der Inputsequenz gespeichert wird.
% Das umgetastete Signal wird danach wieder in die ursprngliche Taktung 
% umgetastet. Die Differenz nach zweimaliger Umtastung wird dargestellt.
% Beispiel: umtast2demo(8,12,0.6,0.8)
% Siehe auch umtast1demo mit Umtastung auf fast dieselbe Frequenz.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
if nargin<4 ff = 0.8; end
if nargin<3 fi = 0.6; end
if nargin<2  k = 30;  end
if nargin<1  n = 8;   end
fsiz = 12;                        % FontSize
[u,v] = ellip(6,3,50,fi);         % IIR-Filter zur Bandbegrenzung
b   = fir1(k,ff);                 % FIR-Filter zur Interpolation 
x   = filter(u,v,randn(1,50));    % zufllige Eingabesequenz
t11 = 15;
t12 = 40;
t1  = t11:t12;                    % ursprngliche Abtastung
t2  = (1:300)/12.7 + 15.7;        % mglichst schrge Neuabtastung
t3  = (t11+1):(t12-1);            % ursprngliche Abtastung - 2 Schritte
t4  = (t11+4):(t12-4);            % zur Darstellung wegen Fehlern am Rand
y   = umtastung(x(t1),t1,t2,b,n); % Umtastung
z   = umtastung(y,t2,t3,b,n);     % Umtastung zurck auf ursprngliche
h = fullscreen('Fehler der Umtastung');
plot(t4,z(4:length(z)-3)-x(t4),'or','LineWidth',3.0) % Differenz 
title('Fehler nach zweimaliger Umtastung','FontSize',15)
xlabel('Zeit','FontSize',fsiz);
ylabel('Differenz','FontSize',fsiz);
