function [b,a] = z2koef(omegaz,radiusz,omegap,radiusp)
% [b,a] = z2koef(omegaz,radiusz,omegap,radiusp)
% Berechnung der Filterkoeffizienten aus den Nullstellen 
% und Polen. Die Nullstellen und Pole sind anzugeben in den 
% Spaltenvektoren omegaz und radiusz bzw. omegap und radiusp.
% Wird z2koef nur mit Nullstellen aufgerufen, so ergibt sich 
% ein FIR-Filter. Fehlt radiusz, so wird der Radius 1 angenommen.
% Die Verstrkung wird auf das Maximum 1.0 eingestellt.
% Wird das Resultat nicht zugewiesen, so gibt es ein Diagramm.

% K. von der Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<3  omegap = []; radiusp = []; end;
if nargin<2  radiusz = ones(size(omegaz)); end;

% Berechnung der Koeffizienten
% ============================
[xz,yz] = pol2cart(pi*omegaz,radiusz);
[xp,yp] = pol2cart(pi*omegap,radiusp);
[b,a]   = zp2tf(xz+i*yz,xp+i*yp,1);
maxim = max(freqz(b,a,256));
b = b/maxim;

if nargout>0  return; end

% Graphische Darstellung
% ======================
fh = fullscreen('P & N','w',0,[1 1.35; 1 1.35]);
zplane(b,a)
lineobj = findobj(get(get(fh,'CurrentAxes'),'Children'),'Type','line'); 
set(lineobj(2:3),'Color','r','MarkerSize',8,'LineWidth',2);
title('Nullstellen und Pole in der Z-Ebene','FontSize',13)
legend('Nullstellen','Pole')

